/*********************************************************************
*                SEGGER MICROCONTROLLER GmbH & Co. KG                *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 2003-2014     SEGGER Microcontroller GmbH & Co KG       *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File        : HW_TM4C129.h
Purpose     : CPU specific defines
----------------------------------------------------------------------
*/

#ifndef HW_TM4C129_H
#define HW_TM4C129_H

#include <stdint.h>
/*********************************************************************
*
*       Types
*
**********************************************************************
*/

typedef unsigned int bool;

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
//
// Bool comparison
//
#define false  0
#define true 1

//
// Constants for PID interface
//
#define WIDGET_MSG_PTR_DOWN 0x00000001
#define WIDGET_MSG_PTR_MOVE 0x00000001
#define WIDGET_MSG_PTR_UP   0x00000000

//
// Target definition (required for rom.h)
//
#define TARGET_IS_SNOWFLAKE_RA0

//
// Dummy
//
#define ASSERT(expr)

//*****************************************************************************
//
// Macros for hardware access, both direct and via the bit-band region.
//
//*****************************************************************************
#define HWREG(x)                                                              \
        (*((volatile uint32_t *)(x)))
#define HWREGH(x)                                                             \
        (*((volatile uint16_t *)(x)))
#define HWREGB(x)                                                             \
        (*((volatile uint8_t *)(x)))
#define HWREGBITW(x, b)                                                       \
        HWREG(((uint32_t)(x) & 0xF0000000) | 0x02000000 |                     \
              (((uint32_t)(x) & 0x000FFFFF) << 5) | ((b) << 2))
#define HWREGBITH(x, b)                                                       \
        HWREGH(((uint32_t)(x) & 0xF0000000) | 0x02000000 |                    \
               (((uint32_t)(x) & 0x000FFFFF) << 5) | ((b) << 2))
#define HWREGBITB(x, b)                                                       \
        HWREGB(((uint32_t)(x) & 0xF0000000) | 0x02000000 |                    \
               (((uint32_t)(x) & 0x000FFFFF) << 5) | ((b) << 2))

//*****************************************************************************
//
// The following are defines for the base address of the memories and
// peripherals.
//
//*****************************************************************************
#define FLASH_BASE              0x00000000  // FLASH memory
#define SRAM_BASE               0x20000000  // SRAM memory
#define WATCHDOG0_BASE          0x40000000  // Watchdog0
#define WATCHDOG1_BASE          0x40001000  // Watchdog1
#define GPIO_PORTA_BASE         0x40004000  // GPIO Port A
#define GPIO_PORTB_BASE         0x40005000  // GPIO Port B
#define GPIO_PORTC_BASE         0x40006000  // GPIO Port C
#define GPIO_PORTD_BASE         0x40007000  // GPIO Port D
#define SSI0_BASE               0x40008000  // SSI0
#define SSI1_BASE               0x40009000  // SSI1
#define SSI2_BASE               0x4000A000  // SSI2
#define SSI3_BASE               0x4000B000  // SSI3
#define UART0_BASE              0x4000C000  // UART0
#define UART1_BASE              0x4000D000  // UART1
#define UART2_BASE              0x4000E000  // UART2
#define UART3_BASE              0x4000F000  // UART3
#define UART4_BASE              0x40010000  // UART4
#define UART5_BASE              0x40011000  // UART5
#define UART6_BASE              0x40012000  // UART6
#define UART7_BASE              0x40013000  // UART7
#define I2C0_BASE               0x40020000  // I2C0
#define I2C1_BASE               0x40021000  // I2C1
#define I2C2_BASE               0x40022000  // I2C2
#define I2C3_BASE               0x40023000  // I2C3
#define GPIO_PORTE_BASE         0x40024000  // GPIO Port E
#define GPIO_PORTF_BASE         0x40025000  // GPIO Port F
#define GPIO_PORTG_BASE         0x40026000  // GPIO Port G
#define GPIO_PORTH_BASE         0x40027000  // GPIO Port H
#define PWM0_BASE               0x40028000  // Pulse Width Modulator (PWM)
#define PWM1_BASE               0x40029000  // Pulse Width Modulator (PWM)
#define QEI0_BASE               0x4002C000  // QEI0
#define QEI1_BASE               0x4002D000  // QEI1
#define TIMER0_BASE             0x40030000  // Timer0
#define TIMER1_BASE             0x40031000  // Timer1
#define TIMER2_BASE             0x40032000  // Timer2
#define TIMER3_BASE             0x40033000  // Timer3
#define TIMER4_BASE             0x40034000  // Timer4
#define TIMER5_BASE             0x40035000  // Timer5
#define WTIMER0_BASE            0x40036000  // Wide Timer0
#define WTIMER1_BASE            0x40037000  // Wide Timer1
#define ADC0_BASE               0x40038000  // ADC0
#define ADC1_BASE               0x40039000  // ADC1
#define COMP_BASE               0x4003C000  // Analog comparators
#define GPIO_PORTJ_BASE         0x4003D000  // GPIO Port J
#define CAN0_BASE               0x40040000  // CAN0
#define CAN1_BASE               0x40041000  // CAN1
#define WTIMER2_BASE            0x4004C000  // Wide Timer2
#define WTIMER3_BASE            0x4004D000  // Wide Timer3
#define WTIMER4_BASE            0x4004E000  // Wide Timer4
#define WTIMER5_BASE            0x4004F000  // Wide Timer5
#define USB0_BASE               0x40050000  // USB 0 Controller
#define GPIO_PORTA_AHB_BASE     0x40058000  // GPIO Port A (high speed)
#define GPIO_PORTB_AHB_BASE     0x40059000  // GPIO Port B (high speed)
#define GPIO_PORTC_AHB_BASE     0x4005A000  // GPIO Port C (high speed)
#define GPIO_PORTD_AHB_BASE     0x4005B000  // GPIO Port D (high speed)
#define GPIO_PORTE_AHB_BASE     0x4005C000  // GPIO Port E (high speed)
#define GPIO_PORTF_AHB_BASE     0x4005D000  // GPIO Port F (high speed)
#define GPIO_PORTG_AHB_BASE     0x4005E000  // GPIO Port G (high speed)
#define GPIO_PORTH_AHB_BASE     0x4005F000  // GPIO Port H (high speed)
#define GPIO_PORTJ_AHB_BASE     0x40060000  // GPIO Port J (high speed)
#define GPIO_PORTK_BASE         0x40061000  // GPIO Port K
#define GPIO_PORTL_BASE         0x40062000  // GPIO Port L
#define GPIO_PORTM_BASE         0x40063000  // GPIO Port M
#define GPIO_PORTN_BASE         0x40064000  // GPIO Port N
#define GPIO_PORTP_BASE         0x40065000  // GPIO Port P
#define GPIO_PORTQ_BASE         0x40066000  // GPIO Port Q
#define GPIO_PORTR_BASE         0x40067000  // General-Purpose Input/Outputs
                                            // (GPIOs)
#define GPIO_PORTS_BASE         0x40068000  // General-Purpose Input/Outputs
                                            // (GPIOs)
#define GPIO_PORTT_BASE         0x40069000  // General-Purpose Input/Outputs
                                            // (GPIOs)
#define FAN0_BASE               0x40084000  // Fan Control (FAN)
#define FAN1_BASE               0x40085000  // Fan Control (FAN)
#define EEPROM_BASE             0x400AF000  // EEPROM memory
#define ONEWIRE0_BASE           0x400B6000  // 1-Wire Master Module
#define HIM0_BASE               0x400B7000  // Human Interface Master (HIM)
#define I2C8_BASE               0x400B8000  // I2C8
#define I2C9_BASE               0x400B9000  // I2C9
#define I2C4_BASE               0x400C0000  // I2C4
#define I2C5_BASE               0x400C1000  // I2C5
#define I2C6_BASE               0x400C2000  // I2C6
#define I2C7_BASE               0x400C3000  // I2C7
#define EPI0_BASE               0x400D0000  // EPI0
#define TIMER6_BASE             0x400E0000  // General-Purpose Timers
#define TIMER7_BASE             0x400E1000  // General-Purpose Timers
#define EMAC0_BASE              0x400EC000  // Ethernet Controller
#define SYSEXC_BASE             0x400F9000  // System Exception Module
#define HIB_BASE                0x400FC000  // Hibernation Module
#define FLASH_CTRL_BASE         0x400FD000  // FLASH Controller
#define SYSCTL_BASE             0x400FE000  // System Control
#define UDMA_BASE               0x400FF000  // uDMA Controller
#define CCM0_BASE               0x44030000  // Cyclical Redundancy Check (CRC)
#define SHAMD5_BASE             0x44034000  // SHA/MD5 Accelerator
#define AES_BASE                0x44036000  // Advance Encryption
                                            // Hardware-Accelerated Module
#define DES_BASE                0x44038000  // Data Encryption Standard
                                            // Accelerator (DES)
#define LCD0_BASE               0x44050000  // LCD Controller
#define ITM_BASE                0xE0000000  // Instrumentation Trace Macrocell
#define DWT_BASE                0xE0001000  // Data Watchpoint and Trace
#define FPB_BASE                0xE0002000  // FLASH Patch and Breakpoint
#define NVIC_BASE               0xE000E000  // Nested Vectored Interrupt Ctrl
#define TPIU_BASE               0xE0040000  // Trace Port Interface Unit

//*****************************************************************************
//
// The following are values that can be passed to the
// SysCtlPeripheralPresent(), SysCtlPeripheralEnable(),
// SysCtlPeripheralDisable(), and SysCtlPeripheralReset() APIs as the
// ui32Peripheral parameter.  The peripherals in the fourth group (upper nibble
// is 3) can only be used with the SysCtlPeripheralPresent() API.
//
//*****************************************************************************
#define SYSCTL_PERIPH_ADC0      0xf0003800  // ADC 0
#define SYSCTL_PERIPH_ADC1      0xf0003801  // ADC 1
#define SYSCTL_PERIPH_CAN0      0xf0003400  // CAN 0
#define SYSCTL_PERIPH_CAN1      0xf0003401  // CAN 1
#define SYSCTL_PERIPH_CAN2      0xf0003402  // CAN 2
#define SYSCTL_PERIPH_COMP0     0xf0003c00  // Analog comparator 0
#define SYSCTL_PERIPH_COMP1     0xf0003c01  // Analog comparator 1
#define SYSCTL_PERIPH_COMP2     0xf0003c02  // Analog comparator 2
#define SYSCTL_PERIPH_EMAC0     0xf0009c00  // Ethernet MAC0
#define SYSCTL_PERIPH_EPHY0     0xf0003000  // Ethernet PHY0
#define SYSCTL_PERIPH_EPI0      0xf0001000  // EPI0
#define SYSCTL_PERIPH_GPIOA     0xf0000800  // GPIO A
#define SYSCTL_PERIPH_GPIOB     0xf0000801  // GPIO B
#define SYSCTL_PERIPH_GPIOC     0xf0000802  // GPIO C
#define SYSCTL_PERIPH_GPIOD     0xf0000803  // GPIO D
#define SYSCTL_PERIPH_GPIOE     0xf0000804  // GPIO E
#define SYSCTL_PERIPH_GPIOF     0xf0000805  // GPIO F
#define SYSCTL_PERIPH_GPIOG     0xf0000806  // GPIO G
#define SYSCTL_PERIPH_GPIOH     0xf0000807  // GPIO H
#define SYSCTL_PERIPH_GPIOJ     0xf0000808  // GPIO J
#define SYSCTL_PERIPH_HIBERNATE 0xf0001400  // Hibernation module
#define SYSCTL_PERIPH_CCM0      0xf0007400  // CCM 0
#define SYSCTL_PERIPH_EEPROM0   0xf0005800  // EEPROM 0
#define SYSCTL_PERIPH_FAN0      0xf0005400  // FAN 0
#define SYSCTL_PERIPH_FAN1      0xf0005401  // FAN 1
#define SYSCTL_PERIPH_GPIOK     0xf0000809  // GPIO K
#define SYSCTL_PERIPH_GPIOL     0xf000080a  // GPIO L
#define SYSCTL_PERIPH_GPIOM     0xf000080b  // GPIO M
#define SYSCTL_PERIPH_GPION     0xf000080c  // GPIO N
#define SYSCTL_PERIPH_GPIOP     0xf000080d  // GPIO P
#define SYSCTL_PERIPH_GPIOQ     0xf000080e  // GPIO Q
#define SYSCTL_PERIPH_GPIOR     0xf000080f  // GPIO R
#define SYSCTL_PERIPH_GPIOS     0xf0000810  // GPIO S
#define SYSCTL_PERIPH_GPIOT     0xf0000811  // GPIO T
#define SYSCTL_PERIPH_I2C0      0xf0002000  // I2C 0
#define SYSCTL_PERIPH_I2C1      0xf0002001  // I2C 1
#define SYSCTL_PERIPH_I2C2      0xf0002002  // I2C 2
#define SYSCTL_PERIPH_I2C3      0xf0002003  // I2C 3
#define SYSCTL_PERIPH_I2C4      0xf0002004  // I2C 4
#define SYSCTL_PERIPH_I2C5      0xf0002005  // I2C 5
#define SYSCTL_PERIPH_I2C6      0xf0002006  // I2C 6
#define SYSCTL_PERIPH_I2C7      0xf0002007  // I2C 7
#define SYSCTL_PERIPH_I2C8      0xf0002008  // I2C 8
#define SYSCTL_PERIPH_I2C9      0xf0002009  // I2C 9
#define SYSCTL_PERIPH_LCD0      0xf0009000  // LCD 0
#define SYSCTL_PERIPH_PWM0      0xf0004000  // PWM 0
#define SYSCTL_PERIPH_PWM1      0xf0004001  // PWM 1
#define SYSCTL_PERIPH_QEI0      0xf0004400  // QEI 0
#define SYSCTL_PERIPH_QEI1      0xf0004401  // QEI 1
#define SYSCTL_PERIPH_SSI0      0xf0001c00  // SSI 0
#define SYSCTL_PERIPH_SSI1      0xf0001c01  // SSI 1
#define SYSCTL_PERIPH_SSI2      0xf0001c02  // SSI 2
#define SYSCTL_PERIPH_SSI3      0xf0001c03  // SSI 3
#define SYSCTL_PERIPH_TIMER0    0xf0000400  // Timer 0
#define SYSCTL_PERIPH_TIMER1    0xf0000401  // Timer 1
#define SYSCTL_PERIPH_TIMER2    0xf0000402  // Timer 2
#define SYSCTL_PERIPH_TIMER3    0xf0000403  // Timer 3
#define SYSCTL_PERIPH_TIMER4    0xf0000404  // Timer 4
#define SYSCTL_PERIPH_TIMER5    0xf0000405  // Timer 5
#define SYSCTL_PERIPH_TIMER6    0xf0000406  // Timer 6
#define SYSCTL_PERIPH_TIMER7    0xf0000407  // Timer 7
#define SYSCTL_PERIPH_UART0     0xf0001800  // UART 0
#define SYSCTL_PERIPH_UART1     0xf0001801  // UART 1
#define SYSCTL_PERIPH_UART2     0xf0001802  // UART 2
#define SYSCTL_PERIPH_UART3     0xf0001803  // UART 3
#define SYSCTL_PERIPH_UART4     0xf0001804  // UART 4
#define SYSCTL_PERIPH_UART5     0xf0001805  // UART 5
#define SYSCTL_PERIPH_UART6     0xf0001806  // UART 6
#define SYSCTL_PERIPH_UART7     0xf0001807  // UART 7
#define SYSCTL_PERIPH_UDMA      0xf0000c00  // uDMA
#define SYSCTL_PERIPH_USB0      0xf0002800  // USB 0
#define SYSCTL_PERIPH_WDOG0     0xf0000000  // Watchdog 0
#define SYSCTL_PERIPH_WDOG1     0xf0000001  // Watchdog 1
#define SYSCTL_PERIPH_WTIMER0   0xf0005c00  // Wide Timer 0
#define SYSCTL_PERIPH_WTIMER1   0xf0005c01  // Wide Timer 1
#define SYSCTL_PERIPH_WTIMER2   0xf0005c02  // Wide Timer 2
#define SYSCTL_PERIPH_WTIMER3   0xf0005c03  // Wide Timer 3
#define SYSCTL_PERIPH_WTIMER4   0xf0005c04  // Wide Timer 4
#define SYSCTL_PERIPH_WTIMER5   0xf0005c05  // Wide Timer 5

//*****************************************************************************
//
// The following are values that can be passed to the SysCtlIntEnable(),
// SysCtlIntDisable(), and SysCtlIntClear() APIs, or returned in the bit mask
// by the SysCtlIntStatus() API.
//
//*****************************************************************************
#define SYSCTL_INT_MOSC_PUP     0x00000100  // MOSC power-up interrupt
#define SYSCTL_INT_USBPLL_LOCK  0x00000080  // USB PLL lock interrupt
#define SYSCTL_INT_PLL_LOCK     0x00000040  // PLL lock interrupt
#define SYSCTL_INT_CUR_LIMIT    0x00000020  // Current limit interrupt
#define SYSCTL_INT_IOSC_FAIL    0x00000010  // Internal oscillator failure int
#define SYSCTL_INT_MOSC_FAIL    0x00000008  // Main oscillator failure int
#define SYSCTL_INT_POR          0x00000004  // Power on reset interrupt
#define SYSCTL_INT_BOR          0x00000002  // Brown out interrupt
#define SYSCTL_INT_PLL_FAIL     0x00000001  // PLL failure interrupt

//*****************************************************************************
//
// The following are values that can be passed to the SysCtlResetCauseClear()
// API or returned by the SysCtlResetCauseGet() API.
//
//*****************************************************************************
#define SYSCTL_CAUSE_HSRVREQ    0x00001000  // Hardware System Service Request
#define SYSCTL_CAUSE_HIB        0x00000040  // Hibernate reset
#define SYSCTL_CAUSE_LDO        0x00000020  // LDO power not OK reset
#define SYSCTL_CAUSE_WDOG1      0x00000020  // Watchdog 1 reset
#define SYSCTL_CAUSE_SW         0x00000010  // Software reset
#define SYSCTL_CAUSE_WDOG0      0x00000008  // Watchdog 0 reset
#define SYSCTL_CAUSE_WDOG       0x00000008  // Watchdog reset
#define SYSCTL_CAUSE_BOR        0x00000004  // Brown-out reset
#define SYSCTL_CAUSE_POR        0x00000002  // Power on reset
#define SYSCTL_CAUSE_EXT        0x00000001  // External reset

//*****************************************************************************
//
// The following are values that can be passed to the SysCtlBrownOutConfigSet()
// API as the ui32Config parameter.
//
//*****************************************************************************
#define SYSCTL_BOR_RESET        0x00000002  // Reset instead of interrupting
#define SYSCTL_BOR_RESAMPLE     0x00000001  // Resample BOR before asserting

//*****************************************************************************
//
// The following are values that can be passed to the SysCtlPWMClockSet() API
// as the ui32Config parameter, and can be returned by the SysCtlPWMClockGet()
// API.
//
//*****************************************************************************
#define SYSCTL_PWMDIV_1         0x00000000  // PWM clock is processor clock /1
#define SYSCTL_PWMDIV_2         0x00100000  // PWM clock is processor clock /2
#define SYSCTL_PWMDIV_4         0x00120000  // PWM clock is processor clock /4
#define SYSCTL_PWMDIV_8         0x00140000  // PWM clock is processor clock /8
#define SYSCTL_PWMDIV_16        0x00160000  // PWM clock is processor clock /16
#define SYSCTL_PWMDIV_32        0x00180000  // PWM clock is processor clock /32
#define SYSCTL_PWMDIV_64        0x001A0000  // PWM clock is processor clock /64

//*****************************************************************************
//
// The following are values that can be passed to the SysCtlADCSpeedSet() API
// as the ui32Speed parameter, and can be returned by the SysCtlADCSpeedGet()
// API.
//
//*****************************************************************************
#define SYSCTL_ADCSPEED_1MSPS   0x00000F00  // 1,000,000 samples per second
#define SYSCTL_ADCSPEED_500KSPS 0x00000A00  // 500,000 samples per second
#define SYSCTL_ADCSPEED_250KSPS 0x00000500  // 250,000 samples per second
#define SYSCTL_ADCSPEED_125KSPS 0x00000000  // 125,000 samples per second

//*****************************************************************************
//
// The following are values that can be passed to the SysCtlClockSet() API as
// the ui32Config parameter.
//
//*****************************************************************************
#define SYSCTL_SYSDIV_1         0x07800000  // Processor clock is osc/pll /1
#define SYSCTL_SYSDIV_2         0x00C00000  // Processor clock is osc/pll /2
#define SYSCTL_SYSDIV_3         0x01400000  // Processor clock is osc/pll /3
#define SYSCTL_SYSDIV_4         0x01C00000  // Processor clock is osc/pll /4
#define SYSCTL_SYSDIV_5         0x02400000  // Processor clock is osc/pll /5
#define SYSCTL_SYSDIV_6         0x02C00000  // Processor clock is osc/pll /6
#define SYSCTL_SYSDIV_7         0x03400000  // Processor clock is osc/pll /7
#define SYSCTL_SYSDIV_8         0x03C00000  // Processor clock is osc/pll /8
#define SYSCTL_SYSDIV_9         0x04400000  // Processor clock is osc/pll /9
#define SYSCTL_SYSDIV_10        0x04C00000  // Processor clock is osc/pll /10
#define SYSCTL_SYSDIV_11        0x05400000  // Processor clock is osc/pll /11
#define SYSCTL_SYSDIV_12        0x05C00000  // Processor clock is osc/pll /12
#define SYSCTL_SYSDIV_13        0x06400000  // Processor clock is osc/pll /13
#define SYSCTL_SYSDIV_14        0x06C00000  // Processor clock is osc/pll /14
#define SYSCTL_SYSDIV_15        0x07400000  // Processor clock is osc/pll /15
#define SYSCTL_SYSDIV_16        0x07C00000  // Processor clock is osc/pll /16
#define SYSCTL_SYSDIV_17        0x88400000  // Processor clock is osc/pll /17
#define SYSCTL_SYSDIV_18        0x88C00000  // Processor clock is osc/pll /18
#define SYSCTL_SYSDIV_19        0x89400000  // Processor clock is osc/pll /19
#define SYSCTL_SYSDIV_20        0x89C00000  // Processor clock is osc/pll /20
#define SYSCTL_SYSDIV_21        0x8A400000  // Processor clock is osc/pll /21
#define SYSCTL_SYSDIV_22        0x8AC00000  // Processor clock is osc/pll /22
#define SYSCTL_SYSDIV_23        0x8B400000  // Processor clock is osc/pll /23
#define SYSCTL_SYSDIV_24        0x8BC00000  // Processor clock is osc/pll /24
#define SYSCTL_SYSDIV_25        0x8C400000  // Processor clock is osc/pll /25
#define SYSCTL_SYSDIV_26        0x8CC00000  // Processor clock is osc/pll /26
#define SYSCTL_SYSDIV_27        0x8D400000  // Processor clock is osc/pll /27
#define SYSCTL_SYSDIV_28        0x8DC00000  // Processor clock is osc/pll /28
#define SYSCTL_SYSDIV_29        0x8E400000  // Processor clock is osc/pll /29
#define SYSCTL_SYSDIV_30        0x8EC00000  // Processor clock is osc/pll /30
#define SYSCTL_SYSDIV_31        0x8F400000  // Processor clock is osc/pll /31
#define SYSCTL_SYSDIV_32        0x8FC00000  // Processor clock is osc/pll /32
#define SYSCTL_SYSDIV_33        0x90400000  // Processor clock is osc/pll /33
#define SYSCTL_SYSDIV_34        0x90C00000  // Processor clock is osc/pll /34
#define SYSCTL_SYSDIV_35        0x91400000  // Processor clock is osc/pll /35
#define SYSCTL_SYSDIV_36        0x91C00000  // Processor clock is osc/pll /36
#define SYSCTL_SYSDIV_37        0x92400000  // Processor clock is osc/pll /37
#define SYSCTL_SYSDIV_38        0x92C00000  // Processor clock is osc/pll /38
#define SYSCTL_SYSDIV_39        0x93400000  // Processor clock is osc/pll /39
#define SYSCTL_SYSDIV_40        0x93C00000  // Processor clock is osc/pll /40
#define SYSCTL_SYSDIV_41        0x94400000  // Processor clock is osc/pll /41
#define SYSCTL_SYSDIV_42        0x94C00000  // Processor clock is osc/pll /42
#define SYSCTL_SYSDIV_43        0x95400000  // Processor clock is osc/pll /43
#define SYSCTL_SYSDIV_44        0x95C00000  // Processor clock is osc/pll /44
#define SYSCTL_SYSDIV_45        0x96400000  // Processor clock is osc/pll /45
#define SYSCTL_SYSDIV_46        0x96C00000  // Processor clock is osc/pll /46
#define SYSCTL_SYSDIV_47        0x97400000  // Processor clock is osc/pll /47
#define SYSCTL_SYSDIV_48        0x97C00000  // Processor clock is osc/pll /48
#define SYSCTL_SYSDIV_49        0x98400000  // Processor clock is osc/pll /49
#define SYSCTL_SYSDIV_50        0x98C00000  // Processor clock is osc/pll /50
#define SYSCTL_SYSDIV_51        0x99400000  // Processor clock is osc/pll /51
#define SYSCTL_SYSDIV_52        0x99C00000  // Processor clock is osc/pll /52
#define SYSCTL_SYSDIV_53        0x9A400000  // Processor clock is osc/pll /53
#define SYSCTL_SYSDIV_54        0x9AC00000  // Processor clock is osc/pll /54
#define SYSCTL_SYSDIV_55        0x9B400000  // Processor clock is osc/pll /55
#define SYSCTL_SYSDIV_56        0x9BC00000  // Processor clock is osc/pll /56
#define SYSCTL_SYSDIV_57        0x9C400000  // Processor clock is osc/pll /57
#define SYSCTL_SYSDIV_58        0x9CC00000  // Processor clock is osc/pll /58
#define SYSCTL_SYSDIV_59        0x9D400000  // Processor clock is osc/pll /59
#define SYSCTL_SYSDIV_60        0x9DC00000  // Processor clock is osc/pll /60
#define SYSCTL_SYSDIV_61        0x9E400000  // Processor clock is osc/pll /61
#define SYSCTL_SYSDIV_62        0x9EC00000  // Processor clock is osc/pll /62
#define SYSCTL_SYSDIV_63        0x9F400000  // Processor clock is osc/pll /63
#define SYSCTL_SYSDIV_64        0x9FC00000  // Processor clock is osc/pll /64
#define SYSCTL_SYSDIV_2_5       0xC1000000  // Processor clock is pll / 2.5
#define SYSCTL_SYSDIV_3_5       0xC1800000  // Processor clock is pll / 3.5
#define SYSCTL_SYSDIV_4_5       0xC2000000  // Processor clock is pll / 4.5
#define SYSCTL_SYSDIV_5_5       0xC2800000  // Processor clock is pll / 5.5
#define SYSCTL_SYSDIV_6_5       0xC3000000  // Processor clock is pll / 6.5
#define SYSCTL_SYSDIV_7_5       0xC3800000  // Processor clock is pll / 7.5
#define SYSCTL_SYSDIV_8_5       0xC4000000  // Processor clock is pll / 8.5
#define SYSCTL_SYSDIV_9_5       0xC4800000  // Processor clock is pll / 9.5
#define SYSCTL_SYSDIV_10_5      0xC5000000  // Processor clock is pll / 10.5
#define SYSCTL_SYSDIV_11_5      0xC5800000  // Processor clock is pll / 11.5
#define SYSCTL_SYSDIV_12_5      0xC6000000  // Processor clock is pll / 12.5
#define SYSCTL_SYSDIV_13_5      0xC6800000  // Processor clock is pll / 13.5
#define SYSCTL_SYSDIV_14_5      0xC7000000  // Processor clock is pll / 14.5
#define SYSCTL_SYSDIV_15_5      0xC7800000  // Processor clock is pll / 15.5
#define SYSCTL_SYSDIV_16_5      0xC8000000  // Processor clock is pll / 16.5
#define SYSCTL_SYSDIV_17_5      0xC8800000  // Processor clock is pll / 17.5
#define SYSCTL_SYSDIV_18_5      0xC9000000  // Processor clock is pll / 18.5
#define SYSCTL_SYSDIV_19_5      0xC9800000  // Processor clock is pll / 19.5
#define SYSCTL_SYSDIV_20_5      0xCA000000  // Processor clock is pll / 20.5
#define SYSCTL_SYSDIV_21_5      0xCA800000  // Processor clock is pll / 21.5
#define SYSCTL_SYSDIV_22_5      0xCB000000  // Processor clock is pll / 22.5
#define SYSCTL_SYSDIV_23_5      0xCB800000  // Processor clock is pll / 23.5
#define SYSCTL_SYSDIV_24_5      0xCC000000  // Processor clock is pll / 24.5
#define SYSCTL_SYSDIV_25_5      0xCC800000  // Processor clock is pll / 25.5
#define SYSCTL_SYSDIV_26_5      0xCD000000  // Processor clock is pll / 26.5
#define SYSCTL_SYSDIV_27_5      0xCD800000  // Processor clock is pll / 27.5
#define SYSCTL_SYSDIV_28_5      0xCE000000  // Processor clock is pll / 28.5
#define SYSCTL_SYSDIV_29_5      0xCE800000  // Processor clock is pll / 29.5
#define SYSCTL_SYSDIV_30_5      0xCF000000  // Processor clock is pll / 30.5
#define SYSCTL_SYSDIV_31_5      0xCF800000  // Processor clock is pll / 31.5
#define SYSCTL_SYSDIV_32_5      0xD0000000  // Processor clock is pll / 32.5
#define SYSCTL_SYSDIV_33_5      0xD0800000  // Processor clock is pll / 33.5
#define SYSCTL_SYSDIV_34_5      0xD1000000  // Processor clock is pll / 34.5
#define SYSCTL_SYSDIV_35_5      0xD1800000  // Processor clock is pll / 35.5
#define SYSCTL_SYSDIV_36_5      0xD2000000  // Processor clock is pll / 36.5
#define SYSCTL_SYSDIV_37_5      0xD2800000  // Processor clock is pll / 37.5
#define SYSCTL_SYSDIV_38_5      0xD3000000  // Processor clock is pll / 38.5
#define SYSCTL_SYSDIV_39_5      0xD3800000  // Processor clock is pll / 39.5
#define SYSCTL_SYSDIV_40_5      0xD4000000  // Processor clock is pll / 40.5
#define SYSCTL_SYSDIV_41_5      0xD4800000  // Processor clock is pll / 41.5
#define SYSCTL_SYSDIV_42_5      0xD5000000  // Processor clock is pll / 42.5
#define SYSCTL_SYSDIV_43_5      0xD5800000  // Processor clock is pll / 43.5
#define SYSCTL_SYSDIV_44_5      0xD6000000  // Processor clock is pll / 44.5
#define SYSCTL_SYSDIV_45_5      0xD6800000  // Processor clock is pll / 45.5
#define SYSCTL_SYSDIV_46_5      0xD7000000  // Processor clock is pll / 46.5
#define SYSCTL_SYSDIV_47_5      0xD7800000  // Processor clock is pll / 47.5
#define SYSCTL_SYSDIV_48_5      0xD8000000  // Processor clock is pll / 48.5
#define SYSCTL_SYSDIV_49_5      0xD8800000  // Processor clock is pll / 49.5
#define SYSCTL_SYSDIV_50_5      0xD9000000  // Processor clock is pll / 50.5
#define SYSCTL_SYSDIV_51_5      0xD9800000  // Processor clock is pll / 51.5
#define SYSCTL_SYSDIV_52_5      0xDA000000  // Processor clock is pll / 52.5
#define SYSCTL_SYSDIV_53_5      0xDA800000  // Processor clock is pll / 53.5
#define SYSCTL_SYSDIV_54_5      0xDB000000  // Processor clock is pll / 54.5
#define SYSCTL_SYSDIV_55_5      0xDB800000  // Processor clock is pll / 55.5
#define SYSCTL_SYSDIV_56_5      0xDC000000  // Processor clock is pll / 56.5
#define SYSCTL_SYSDIV_57_5      0xDC800000  // Processor clock is pll / 57.5
#define SYSCTL_SYSDIV_58_5      0xDD000000  // Processor clock is pll / 58.5
#define SYSCTL_SYSDIV_59_5      0xDD800000  // Processor clock is pll / 59.5
#define SYSCTL_SYSDIV_60_5      0xDE000000  // Processor clock is pll / 60.5
#define SYSCTL_SYSDIV_61_5      0xDE800000  // Processor clock is pll / 61.5
#define SYSCTL_SYSDIV_62_5      0xDF000000  // Processor clock is pll / 62.5
#define SYSCTL_SYSDIV_63_5      0xDF800000  // Processor clock is pll / 63.5
#define SYSCTL_CFG_VCO_480      0xF1000000  // VCO is 480 MHz
#define SYSCTL_CFG_VCO_320      0xF0000000  // VCO is 320 MHz
#define SYSCTL_USE_PLL          0x00000000  // System clock is the PLL clock
#define SYSCTL_USE_OSC          0x00003800  // System clock is the osc clock
#define SYSCTL_XTAL_1MHZ        0x00000000  // External crystal is 1MHz
#define SYSCTL_XTAL_1_84MHZ     0x00000040  // External crystal is 1.8432MHz
#define SYSCTL_XTAL_2MHZ        0x00000080  // External crystal is 2MHz
#define SYSCTL_XTAL_2_45MHZ     0x000000C0  // External crystal is 2.4576MHz
#define SYSCTL_XTAL_3_57MHZ     0x00000100  // External crystal is 3.579545MHz
#define SYSCTL_XTAL_3_68MHZ     0x00000140  // External crystal is 3.6864MHz
#define SYSCTL_XTAL_4MHZ        0x00000180  // External crystal is 4MHz
#define SYSCTL_XTAL_4_09MHZ     0x000001C0  // External crystal is 4.096MHz
#define SYSCTL_XTAL_4_91MHZ     0x00000200  // External crystal is 4.9152MHz
#define SYSCTL_XTAL_5MHZ        0x00000240  // External crystal is 5MHz
#define SYSCTL_XTAL_5_12MHZ     0x00000280  // External crystal is 5.12MHz
#define SYSCTL_XTAL_6MHZ        0x000002C0  // External crystal is 6MHz
#define SYSCTL_XTAL_6_14MHZ     0x00000300  // External crystal is 6.144MHz
#define SYSCTL_XTAL_7_37MHZ     0x00000340  // External crystal is 7.3728MHz
#define SYSCTL_XTAL_8MHZ        0x00000380  // External crystal is 8MHz
#define SYSCTL_XTAL_8_19MHZ     0x000003C0  // External crystal is 8.192MHz
#define SYSCTL_XTAL_10MHZ       0x00000400  // External crystal is 10 MHz
#define SYSCTL_XTAL_12MHZ       0x00000440  // External crystal is 12 MHz
#define SYSCTL_XTAL_12_2MHZ     0x00000480  // External crystal is 12.288 MHz
#define SYSCTL_XTAL_13_5MHZ     0x000004C0  // External crystal is 13.56 MHz
#define SYSCTL_XTAL_14_3MHZ     0x00000500  // External crystal is 14.31818 MHz
#define SYSCTL_XTAL_16MHZ       0x00000540  // External crystal is 16 MHz
#define SYSCTL_XTAL_16_3MHZ     0x00000580  // External crystal is 16.384 MHz
#define SYSCTL_XTAL_18MHZ       0x000005C0  // External crystal is 18.0 MHz
#define SYSCTL_XTAL_20MHZ       0x00000600  // External crystal is 20.0 MHz
#define SYSCTL_XTAL_24MHZ       0x00000640  // External crystal is 24.0 MHz
#define SYSCTL_XTAL_25MHZ       0x00000680  // External crystal is 25.0 MHz
#define SYSCTL_OSC_MAIN         0x00000000  // Osc source is main osc
#define SYSCTL_OSC_INT          0x00000010  // Osc source is int. osc
#define SYSCTL_OSC_INT4         0x00000020  // Osc source is int. osc /4
#define SYSCTL_OSC_INT30        0x00000030  // Osc source is int. 30 KHz
#define SYSCTL_OSC_EXT4_19      0x80000028  // Osc source is ext. 4.19 MHz
#define SYSCTL_OSC_EXT32        0x80000038  // Osc source is ext. 32 KHz
#define SYSCTL_INT_OSC_DIS      0x00000002  // Disable internal oscillator
#define SYSCTL_MAIN_OSC_DIS     0x00000001  // Disable main oscillator

//*****************************************************************************
//
// The following are values that can be passed to the SysCtlDeepSleepClockSet()
// API as the ui32Config parameter.
//
//*****************************************************************************
#define SYSCTL_DSLP_DIV_1       0x00000000  // Deep-sleep clock is osc /1
#define SYSCTL_DSLP_DIV_2       0x00800000  // Deep-sleep clock is osc /2
#define SYSCTL_DSLP_DIV_3       0x01000000  // Deep-sleep clock is osc /3
#define SYSCTL_DSLP_DIV_4       0x01800000  // Deep-sleep clock is osc /4
#define SYSCTL_DSLP_DIV_5       0x02000000  // Deep-sleep clock is osc /5
#define SYSCTL_DSLP_DIV_6       0x02800000  // Deep-sleep clock is osc /6
#define SYSCTL_DSLP_DIV_7       0x03000000  // Deep-sleep clock is osc /7
#define SYSCTL_DSLP_DIV_8       0x03800000  // Deep-sleep clock is osc /8
#define SYSCTL_DSLP_DIV_9       0x04000000  // Deep-sleep clock is osc /9
#define SYSCTL_DSLP_DIV_10      0x04800000  // Deep-sleep clock is osc /10
#define SYSCTL_DSLP_DIV_11      0x05000000  // Deep-sleep clock is osc /11
#define SYSCTL_DSLP_DIV_12      0x05800000  // Deep-sleep clock is osc /12
#define SYSCTL_DSLP_DIV_13      0x06000000  // Deep-sleep clock is osc /13
#define SYSCTL_DSLP_DIV_14      0x06800000  // Deep-sleep clock is osc /14
#define SYSCTL_DSLP_DIV_15      0x07000000  // Deep-sleep clock is osc /15
#define SYSCTL_DSLP_DIV_16      0x07800000  // Deep-sleep clock is osc /16
#define SYSCTL_DSLP_DIV_17      0x08000000  // Deep-sleep clock is osc /17
#define SYSCTL_DSLP_DIV_18      0x08800000  // Deep-sleep clock is osc /18
#define SYSCTL_DSLP_DIV_19      0x09000000  // Deep-sleep clock is osc /19
#define SYSCTL_DSLP_DIV_20      0x09800000  // Deep-sleep clock is osc /20
#define SYSCTL_DSLP_DIV_21      0x0A000000  // Deep-sleep clock is osc /21
#define SYSCTL_DSLP_DIV_22      0x0A800000  // Deep-sleep clock is osc /22
#define SYSCTL_DSLP_DIV_23      0x0B000000  // Deep-sleep clock is osc /23
#define SYSCTL_DSLP_DIV_24      0x0B800000  // Deep-sleep clock is osc /24
#define SYSCTL_DSLP_DIV_25      0x0C000000  // Deep-sleep clock is osc /25
#define SYSCTL_DSLP_DIV_26      0x0C800000  // Deep-sleep clock is osc /26
#define SYSCTL_DSLP_DIV_27      0x0D000000  // Deep-sleep clock is osc /27
#define SYSCTL_DSLP_DIV_28      0x0D800000  // Deep-sleep clock is osc /28
#define SYSCTL_DSLP_DIV_29      0x0E000000  // Deep-sleep clock is osc /29
#define SYSCTL_DSLP_DIV_30      0x0E800000  // Deep-sleep clock is osc /30
#define SYSCTL_DSLP_DIV_31      0x0F000000  // Deep-sleep clock is osc /31
#define SYSCTL_DSLP_DIV_32      0x0F800000  // Deep-sleep clock is osc /32
#define SYSCTL_DSLP_DIV_33      0x10000000  // Deep-sleep clock is osc /33
#define SYSCTL_DSLP_DIV_34      0x10800000  // Deep-sleep clock is osc /34
#define SYSCTL_DSLP_DIV_35      0x11000000  // Deep-sleep clock is osc /35
#define SYSCTL_DSLP_DIV_36      0x11800000  // Deep-sleep clock is osc /36
#define SYSCTL_DSLP_DIV_37      0x12000000  // Deep-sleep clock is osc /37
#define SYSCTL_DSLP_DIV_38      0x12800000  // Deep-sleep clock is osc /38
#define SYSCTL_DSLP_DIV_39      0x13000000  // Deep-sleep clock is osc /39
#define SYSCTL_DSLP_DIV_40      0x13800000  // Deep-sleep clock is osc /40
#define SYSCTL_DSLP_DIV_41      0x14000000  // Deep-sleep clock is osc /41
#define SYSCTL_DSLP_DIV_42      0x14800000  // Deep-sleep clock is osc /42
#define SYSCTL_DSLP_DIV_43      0x15000000  // Deep-sleep clock is osc /43
#define SYSCTL_DSLP_DIV_44      0x15800000  // Deep-sleep clock is osc /44
#define SYSCTL_DSLP_DIV_45      0x16000000  // Deep-sleep clock is osc /45
#define SYSCTL_DSLP_DIV_46      0x16800000  // Deep-sleep clock is osc /46
#define SYSCTL_DSLP_DIV_47      0x17000000  // Deep-sleep clock is osc /47
#define SYSCTL_DSLP_DIV_48      0x17800000  // Deep-sleep clock is osc /48
#define SYSCTL_DSLP_DIV_49      0x18000000  // Deep-sleep clock is osc /49
#define SYSCTL_DSLP_DIV_50      0x18800000  // Deep-sleep clock is osc /50
#define SYSCTL_DSLP_DIV_51      0x19000000  // Deep-sleep clock is osc /51
#define SYSCTL_DSLP_DIV_52      0x19800000  // Deep-sleep clock is osc /52
#define SYSCTL_DSLP_DIV_53      0x1A000000  // Deep-sleep clock is osc /53
#define SYSCTL_DSLP_DIV_54      0x1A800000  // Deep-sleep clock is osc /54
#define SYSCTL_DSLP_DIV_55      0x1B000000  // Deep-sleep clock is osc /55
#define SYSCTL_DSLP_DIV_56      0x1B800000  // Deep-sleep clock is osc /56
#define SYSCTL_DSLP_DIV_57      0x1C000000  // Deep-sleep clock is osc /57
#define SYSCTL_DSLP_DIV_58      0x1C800000  // Deep-sleep clock is osc /58
#define SYSCTL_DSLP_DIV_59      0x1D000000  // Deep-sleep clock is osc /59
#define SYSCTL_DSLP_DIV_60      0x1D800000  // Deep-sleep clock is osc /60
#define SYSCTL_DSLP_DIV_61      0x1E000000  // Deep-sleep clock is osc /61
#define SYSCTL_DSLP_DIV_62      0x1E800000  // Deep-sleep clock is osc /62
#define SYSCTL_DSLP_DIV_63      0x1F000000  // Deep-sleep clock is osc /63
#define SYSCTL_DSLP_DIV_64      0x1F800000  // Deep-sleep clock is osc /64
#define SYSCTL_DSLP_OSC_MAIN    0x00000000  // Osc source is main osc
#define SYSCTL_DSLP_OSC_INT     0x00000010  // Osc source is int. osc
#define SYSCTL_DSLP_OSC_INT30   0x00000030  // Osc source is int. 30 KHz
#define SYSCTL_DSLP_OSC_EXT32   0x00000070  // Osc source is ext. 32 KHz
#define SYSCTL_DSLP_PIOSC_PD    0x00000002  // Power down PIOSC in deep-sleep
#define SYSCTL_DSLP_MOSC_PD     0x40000000  // Power down MOSC in deep-sleep

//*****************************************************************************
//
// The following are values that can be passed to the SysCtlPIOSCCalibrate()
// API as the ui32Type parameter.
//
//*****************************************************************************
#define SYSCTL_PIOSC_CAL_AUTO   0x00000200  // Automatic calibration
#define SYSCTL_PIOSC_CAL_FACT   0x00000100  // Factory calibration
#define SYSCTL_PIOSC_CAL_USER   0x80000100  // User-supplied calibration

//*****************************************************************************
//
// The following are values that can be passed to the SysCtlMOSCConfigSet() API
// as the ui32Config parameter.
//
//*****************************************************************************
#define SYSCTL_MOSC_VALIDATE    0x00000001  // Enable MOSC validation
#define SYSCTL_MOSC_INTERRUPT   0x00000002  // Generate interrupt on MOSC fail
#define SYSCTL_MOSC_NO_XTAL     0x00000004  // No crystal is attached to MOSC
#define SYSCTL_MOSC_PWR_DIS     0x00000008  // Power down the MOSC.
#define SYSCTL_MOSC_LOWFREQ     0x00000000  // MOSC is less than 10MHz
#define SYSCTL_MOSC_HIGHFREQ    0x00000010  // MOSC is greater than 10MHz
#define SYSCTL_MOSC_SESRC       0x00000020  // Singled ended oscillator source.

//*****************************************************************************
//
// Defines for the SysCtlResetBehaviorSet() and SysCtlResetBehaviorGet() APIs.
//
//*****************************************************************************
#define SYSCTL_ONRST_WDOG0_POR  0x00000030
#define SYSCTL_ONRST_WDOG0_SYS  0x00000020
#define SYSCTL_ONRST_WDOG1_POR  0x000000C0
#define SYSCTL_ONRST_WDOG1_SYS  0x00000080
#define SYSCTL_ONRST_BOR_POR    0x0000000C
#define SYSCTL_ONRST_BOR_SYS    0x00000008
#define SYSCTL_ONRST_EXT_POR    0x00000003
#define SYSCTL_ONRST_EXT_SYS    0x00000002

//*****************************************************************************
//
// The valid settings for the ui32Config parameter of the
// SysCtlLPCLowPowerConfigSet() function.
//
//*****************************************************************************
#define SYSCTL_LPCLPWR_SRAM_OFF                                               \
                                0x00000000
#define SYSCTL_LPCLPWR_SRAM_RETENTION                                         \
                                0x00000001
#define SYSCTL_LPCLPWR_SRAM_ON  0x00000003

//*****************************************************************************
//
// The return values from the SysCtlLPCLowPowerStatusGet() function.
//
//*****************************************************************************
#define SYSCTL_LPCLPWRS_PD_OFF  0x00000000
#define SYSCTL_LPCLPWRS_SRAM_OFF                                              \
                                0x00000033
#define SYSCTL_LPCLPWRS_SRAM_RETENTION                                        \
                                0x00000037
#define SYSCTL_LPCLPWRS_SRAM_ON 0x0000003F

//*****************************************************************************
//
// Values used with the SysCtlVoltageEventConfig() API.
//
//*****************************************************************************
#define SYSCTL_VEVENT_VDDCBO_NONE                                             \
                                0x00000000
#define SYSCTL_VEVENT_VDDCBO_INT                                              \
                                0x00001000
#define SYSCTL_VEVENT_VDDCBO_NMI                                              \
                                0x00002000
#define SYSCTL_VEVENT_VDDCBO_RST                                              \
                                0x00003000
#define SYSCTL_VEVENT_VDDABO_NONE                                             \
                                0x00000000
#define SYSCTL_VEVENT_VDDABO_INT                                              \
                                0x00000100
#define SYSCTL_VEVENT_VDDABO_NMI                                              \
                                0x00000200
#define SYSCTL_VEVENT_VDDABO_RST                                              \
                                0x00000300
#define SYSCTL_VEVENT_VDDBO_NONE                                              \
                                0x00000000
#define SYSCTL_VEVENT_VDDBO_INT 0x00000001
#define SYSCTL_VEVENT_VDDBO_NMI 0x00000002
#define SYSCTL_VEVENT_VDDBO_RST 0x00000003

//*****************************************************************************
//
// Values used with the SysCtlVoltageEventStatus() and
// SysCtlVoltageEventClear() APIs.
//
//*****************************************************************************
#define SYSCTL_VESTAT_VDDBOR    0x00000040
#define SYSCTL_VESTAT_VDDABOR   0x00000010
#define SYSCTL_VESTAT_VDDCBOR   0x00000001

//*****************************************************************************
//
// Values used with the SysCtlNMIStatus() API.
//
//*****************************************************************************
#define SYSCTL_NMI_MOSCFAIL     0x00010000
#define SYSCTL_NMI_TAMPER       0x00000200
#define SYSCTL_NMI_WDT1         0x00000020
#define SYSCTL_NMI_WDT0         0x00000008
#define SYSCTL_NMI_POWER        0x00000004
#define SYSCTL_NMI_EXTERNAL     0x00000001

//*****************************************************************************
//
// The defines for the SysCtlClockOutConfig() API.
//
//*****************************************************************************
#define SYSCTL_CLKOUT_EN        0x80000000
#define SYSCTL_CLKOUT_DIS       0x00000000
#define SYSCTL_CLKOUT_SYSCLK    0x00000000
#define SYSCTL_CLKOUT_PIOSC     0x00010000
#define SYSCTL_CLKOUT_MOSC      0x00020000

//*****************************************************************************
//
// The following defines are used with the SysCtlAltClkConfig() function.
//
//*****************************************************************************
#define SYSCTL_ALTCLK_PIOSC     0x00000000
#define SYSCTL_ALTCLK_PIOSC48   0x00000001
#define SYSCTL_ALTCLK_LFIOSC    0x00000002
#define SYSCTL_ALTCLK_HIB       0x00000004

//*****************************************************************************
//
// The base addresses of the various peripheral control registers.
//
//*****************************************************************************
#define SYSCTL_PPBASE           0x400fe300
#define SYSCTL_SRBASE           0x400fe500
#define SYSCTL_RCGCBASE         0x400fe600
#define SYSCTL_SCGCBASE         0x400fe700
#define SYSCTL_DCGCBASE         0x400fe800
#define SYSCTL_PCBASE           0x400fe900
#define SYSCTL_PRBASE           0x400fea00

//*****************************************************************************
//
// Prototypes for the APIs.
//
//*****************************************************************************
extern void SysCtlPeripheralEnable(uint32_t ui32Peripheral);

//*****************************************************************************
//
// The following values define the bit field for the ui8Pins argument to
// several of the APIs.
//
//*****************************************************************************
#define GPIO_PIN_0              0x00000001  // GPIO pin 0
#define GPIO_PIN_1              0x00000002  // GPIO pin 1
#define GPIO_PIN_2              0x00000004  // GPIO pin 2
#define GPIO_PIN_3              0x00000008  // GPIO pin 3
#define GPIO_PIN_4              0x00000010  // GPIO pin 4
#define GPIO_PIN_5              0x00000020  // GPIO pin 5
#define GPIO_PIN_6              0x00000040  // GPIO pin 6
#define GPIO_PIN_7              0x00000080  // GPIO pin 7

//*****************************************************************************
//
// Values that can be passed to GPIODirModeSet as the ui32PinIO parameter, and
// returned from GPIODirModeGet.
//
//*****************************************************************************
#define GPIO_DIR_MODE_IN        0x00000000  // Pin is a GPIO input
#define GPIO_DIR_MODE_OUT       0x00000001  // Pin is a GPIO output
#define GPIO_DIR_MODE_HW        0x00000002  // Pin is a peripheral function

//*****************************************************************************
//
// Values that can be passed to GPIOIntTypeSet as the ui32IntType parameter,
// and returned from GPIOIntTypeGet.
//
//*****************************************************************************
#define GPIO_FALLING_EDGE       0x00000000  // Interrupt on falling edge
#define GPIO_RISING_EDGE        0x00000004  // Interrupt on rising edge
#define GPIO_BOTH_EDGES         0x00000001  // Interrupt on both edges
#define GPIO_LOW_LEVEL          0x00000002  // Interrupt on low level
#define GPIO_HIGH_LEVEL         0x00000006  // Interrupt on high level
#define GPIO_DISCRETE_INT       0x00010000  // Interrupt for individual pins

//*****************************************************************************
//
// Values that can be passed to GPIOPadConfigSet as the ui32Strength parameter,
// and returned by GPIOPadConfigGet in the *pui32Strength parameter.
//
//*****************************************************************************
#define GPIO_STRENGTH_2MA       0x00000001  // 2mA drive strength
#define GPIO_STRENGTH_4MA       0x00000002  // 4mA drive strength
#define GPIO_STRENGTH_6MA       0x00000065  // 6mA drive strength
#define GPIO_STRENGTH_8MA       0x00000004  // 8mA drive strength
#define GPIO_STRENGTH_8MA_SC    0x0000000C  // 8mA drive with slew rate control
#define GPIO_STRENGTH_10MA      0x00000075  // 10mA drive strength
#define GPIO_STRENGTH_12MA      0x00000077  // 12mA drive strength

//*****************************************************************************
//
// Values that can be passed to GPIOPadConfigSet as the ui32PadType parameter,
// and returned by GPIOPadConfigGet in the *pui32PadType parameter.
//
//*****************************************************************************
#define GPIO_PIN_TYPE_STD       0x00000008  // Push-pull
#define GPIO_PIN_TYPE_STD_WPU   0x0000000A  // Push-pull with weak pull-up
#define GPIO_PIN_TYPE_STD_WPD   0x0000000C  // Push-pull with weak pull-down
#define GPIO_PIN_TYPE_OD        0x00000009  // Open-drain
#define GPIO_PIN_TYPE_ANALOG    0x00000000  // Analog comparator
#define GPIO_PIN_TYPE_WAKE_HIGH 0x00000208  // Hibernate wake, high
#define GPIO_PIN_TYPE_WAKE_LOW  0x00000108  // Hibernate wake, low

//*****************************************************************************
//
// Values that can be passed to GPIOIntEnable() and GPIOIntDisable() functions
// in the ui32IntFlags parameter.
//
//*****************************************************************************
#define GPIO_INT_PIN_0          0x00000001
#define GPIO_INT_PIN_1          0x00000002
#define GPIO_INT_PIN_2          0x00000004
#define GPIO_INT_PIN_3          0x00000008
#define GPIO_INT_PIN_4          0x00000010
#define GPIO_INT_PIN_5          0x00000020
#define GPIO_INT_PIN_6          0x00000040
#define GPIO_INT_PIN_7          0x00000080
#define GPIO_INT_DMA            0x00000100

//*****************************************************************************
//
// Prototypes for the APIs.
//
//*****************************************************************************
extern void GPIOPinTypeEthernetLED(uint32_t ui32Port, uint8_t ui8Pins); /**///TBD: Not required?

//*****************************************************************************
//
// The following are defines for the GPIO register offsets.
//
//*****************************************************************************
#define GPIO_O_DATA             0x00000000  // GPIO Data
#define GPIO_O_DIR              0x00000400  // GPIO Direction
#define GPIO_O_IS               0x00000404  // GPIO Interrupt Sense
#define GPIO_O_IBE              0x00000408  // GPIO Interrupt Both Edges
#define GPIO_O_IEV              0x0000040C  // GPIO Interrupt Event
#define GPIO_O_IM               0x00000410  // GPIO Interrupt Mask
#define GPIO_O_RIS              0x00000414  // GPIO Raw Interrupt Status
#define GPIO_O_MIS              0x00000418  // GPIO Masked Interrupt Status
#define GPIO_O_ICR              0x0000041C  // GPIO Interrupt Clear
#define GPIO_O_AFSEL            0x00000420  // GPIO Alternate Function Select
#define GPIO_O_DR2R             0x00000500  // GPIO 2-mA Drive Select
#define GPIO_O_DR4R             0x00000504  // GPIO 4-mA Drive Select
#define GPIO_O_DR8R             0x00000508  // GPIO 8-mA Drive Select
#define GPIO_O_ODR              0x0000050C  // GPIO Open Drain Select
#define GPIO_O_PUR              0x00000510  // GPIO Pull-Up Select
#define GPIO_O_PDR              0x00000514  // GPIO Pull-Down Select
#define GPIO_O_SLR              0x00000518  // GPIO Slew Rate Control Select
#define GPIO_O_DEN              0x0000051C  // GPIO Digital Enable
#define GPIO_O_LOCK             0x00000520  // GPIO Lock
#define GPIO_O_CR               0x00000524  // GPIO Commit
#define GPIO_O_AMSEL            0x00000528  // GPIO Analog Mode Select
#define GPIO_O_PCTL             0x0000052C  // GPIO Port Control
#define GPIO_O_ADCCTL           0x00000530  // GPIO ADC Control
#define GPIO_O_DMACTL           0x00000534  // GPIO DMA Control
#define GPIO_O_SI               0x00000538  // GPIO Select Interrupt
#define GPIO_O_DR12R            0x0000053C  // GPIO 12-mA Drive Select
#define GPIO_O_WAKEPEN          0x00000540  // GPIO Wake Pin Enable
#define GPIO_O_WAKELVL          0x00000544  // GPIO Wake Level
#define GPIO_O_WAKESTAT         0x00000548  // GPIO Wake Status
#define GPIO_O_PP               0x00000FC0  // GPIO Peripheral Property
#define GPIO_O_PC               0x00000FC4  // GPIO Peripheral Configuration

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_IM register.
//
//*****************************************************************************
#define GPIO_IM_DMAIME          0x00000100  // GPIO uDMA Interrupt Mask Enable
#define GPIO_IM_GPIO_M          0x000000FF  // GPIO Interrupt Mask Enable
#define GPIO_IM_GPIO_S          0

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_RIS register.
//
//*****************************************************************************
#define GPIO_RIS_DMARIS         0x00000100  // GPIO uDMA Interrupt Raw Status
#define GPIO_RIS_GPIO_M         0x000000FF  // GPIO Interrupt Raw Status
#define GPIO_RIS_GPIO_S         0

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_MIS register.
//
//*****************************************************************************
#define GPIO_MIS_DMAMIS         0x00000100  // GPIO uDMA Masked Interrupt
                                            // Status
#define GPIO_MIS_GPIO_M         0x000000FF  // GPIO Masked Interrupt Status
#define GPIO_MIS_GPIO_S         0

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_ICR register.
//
//*****************************************************************************
#define GPIO_ICR_DMAIC          0x00000100  // GPIO uDMA Interrupt Clear
#define GPIO_ICR_GPIO_M         0x000000FF  // GPIO Interrupt Clear
#define GPIO_ICR_GPIO_S         0

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_LOCK register.
//
//*****************************************************************************
#define GPIO_LOCK_M             0xFFFFFFFF  // GPIO Lock
#define GPIO_LOCK_UNLOCKED      0x00000000  // The GPIOCR register is unlocked
                                            // and may be modified
#define GPIO_LOCK_LOCKED        0x00000001  // The GPIOCR register is locked
                                            // and may not be modified
#define GPIO_LOCK_KEY           0x4C4F434B  // Unlocks the GPIO_CR register

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_SI register.
//
//*****************************************************************************
#define GPIO_SI_SUM             0x00000001  // Summary Interrupt

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_DR12R register.
//
//*****************************************************************************
#define GPIO_DR12R_DRV12_M      0x000000FF  // Output Pad 12-mA Drive Enable
#define GPIO_DR12R_DRV12_12MA   0x00000001  // The corresponding GPIO pin has
                                            // 12-mA drive. This encoding is
                                            // only valid if the GPIOPP EDE bit
                                            // is set and the appropriate
                                            // GPIOPC EDM bit field is
                                            // programmed to 0x3

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_WAKEPEN register.
//
//*****************************************************************************
#define GPIO_WAKEPEN_WAKEP4     0x00000010  // P[4] Wake Enable

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_WAKELVL register.
//
//*****************************************************************************
#define GPIO_WAKELVL_WAKELVL4   0x00000010  // P[4] Wake Level

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_WAKESTAT
// register.
//
//*****************************************************************************
#define GPIO_WAKESTAT_STAT4     0x00000010  // P[4] Wake State

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_PP register.
//
//*****************************************************************************
#define GPIO_PP_EDE             0x00000001  // Extended Drive Enable

//*****************************************************************************
//
// The following are defines for the bit fields in the GPIO_O_PC register.
//
//*****************************************************************************
#define GPIO_PC_EDM7_M          0x0000C000  // Extended Drive Mode Bit 7
#define GPIO_PC_EDM6_M          0x00003000  // Extended Drive Mode Bit 6
#define GPIO_PC_EDM5_M          0x00000C00  // Extended Drive Mode Bit 5
#define GPIO_PC_EDM4_M          0x00000300  // Extended Drive Mode Bit 4
#define GPIO_PC_EDM3_M          0x000000C0  // Extended Drive Mode Bit 3
#define GPIO_PC_EDM2_M          0x00000030  // Extended Drive Mode Bit 2
#define GPIO_PC_EDM1_M          0x0000000C  // Extended Drive Mode Bit 1
#define GPIO_PC_EDM0_M          0x00000003  // Extended Drive Mode Bit 0
#define GPIO_PC_EDM0_DISABLE    0x00000000  // Drive values of 2, 4 and 8 mA
                                            // are maintained. GPIO n Drive
                                            // Select (GPIODRnR) registers
                                            // function as normal
#define GPIO_PC_EDM0_6MA        0x00000001  // An additional 6 mA option is
                                            // provided
#define GPIO_PC_EDM0_PLUS2MA    0x00000003  // A 2 mA driver is always enabled;
                                            // setting the corresponding
                                            // GPIODR4R register bit adds 2 mA
                                            // and setting the corresponding
                                            // GPIODR8R of GPIODR12R register
                                            // bit adds an additional 4 mA
#define GPIO_PC_EDM7_S          14
#define GPIO_PC_EDM6_S          12
#define GPIO_PC_EDM5_S          10
#define GPIO_PC_EDM4_S          8
#define GPIO_PC_EDM3_S          6
#define GPIO_PC_EDM2_S          4
#define GPIO_PC_EDM1_S          2

//*****************************************************************************
//
// Prototypes for the APIs.
//
//*****************************************************************************
extern void GPIOPinWrite(uint32_t ui32Port, uint8_t ui8Pins, uint8_t ui8Val);

//*****************************************************************************
//
// Pin mapping for TM4C129XNCZAD
//
//*****************************************************************************
#define GPIO_PA0_U0RX           0x00000001
#define GPIO_PA0_I2C9SCL        0x00000002
#define GPIO_PA0_T0CCP0         0x00000003
#define GPIO_PA0_FAN1PWM5       0x00000004
#define GPIO_PA0_KBCOUT08       0x00000005
#define GPIO_PA0_CAN0RX         0x00000007

#define GPIO_PA1_U0TX           0x00000401
#define GPIO_PA1_I2C9SDA        0x00000402
#define GPIO_PA1_T0CCP1         0x00000403
#define GPIO_PA1_FAN1TACH5      0x00000404
#define GPIO_PA1_KBCOUT09       0x00000405
#define GPIO_PA1_CAN0TX         0x00000407

#define GPIO_PA2_U4RX           0x00000801
#define GPIO_PA2_I2C8SCL        0x00000802
#define GPIO_PA2_T1CCP0         0x00000803
#define GPIO_PA2_SSI0CLK        0x0000080F

#define GPIO_PA3_U4TX           0x00000C01
#define GPIO_PA3_I2C8SDA        0x00000C02
#define GPIO_PA3_T1CCP1         0x00000C03
#define GPIO_PA3_SSI0FSS        0x00000C0F

#define GPIO_PA4_U3RX           0x00001001
#define GPIO_PA4_T2CCP0         0x00001003
#define GPIO_PA4_I2C7SCL        0x00001002
#define GPIO_PA4_SSI0XDAT0      0x0000100F

#define GPIO_PA5_U3TX           0x00001401
#define GPIO_PA5_T2CCP1         0x00001403
#define GPIO_PA5_I2C7SDA        0x00001402
#define GPIO_PA5_SSI0XDAT1      0x0000140F

#define GPIO_PA6_U2RX           0x00001801
#define GPIO_PA6_I2C6SCL        0x00001802
#define GPIO_PA6_T3CCP0         0x00001803
#define GPIO_PA6_PS2CLK0        0x00001804
#define GPIO_PA6_USB0EPEN       0x00001805
#define GPIO_PA6_SSI0XDAT2      0x0000180D
#define GPIO_PA6_EN0RXCK        0x0000180E
#define GPIO_PA6_EPI0S8         0x0000180F

#define GPIO_PA7_U2TX           0x00001C01
#define GPIO_PA7_I2C6SDA        0x00001C02
#define GPIO_PA7_T3CCP1         0x00001C03
#define GPIO_PA7_PS2DAT0        0x00001C04
#define GPIO_PA7_USB0PFLT       0x00001C05
#define GPIO_PA7_USB0EPEN       0x00001C0B
#define GPIO_PA7_SSI0XDAT3      0x00001C0D
#define GPIO_PA7_EPI0S9         0x00001C0F

#define GPIO_PB0_U1RX           0x00010001
#define GPIO_PB0_I2C5SCL        0x00010002
#define GPIO_PB0_PS2CLK1        0x00010004
#define GPIO_PB0_LPC0COMYRX     0x00010005
#define GPIO_PB0_CAN1RX         0x00010007
#define GPIO_PB0_T4CCP0         0x00010003

#define GPIO_PB1_U1TX           0x00010401
#define GPIO_PB1_I2C5SDA        0x00010402
#define GPIO_PB1_PS2DAT1        0x00010404
#define GPIO_PB1_LPC0COMYTX     0x00010405
#define GPIO_PB1_CAN1TX         0x00010407
#define GPIO_PB1_T4CCP1         0x00010403

#define GPIO_PB2_T5CCP0         0x00010803
#define GPIO_PB2_I2C0SCL        0x00010802
#define GPIO_PB2_PS2CLK2        0x00010804
#define GPIO_PB2_EN0MDC         0x00010805
#define GPIO_PB2_LPC0A20        0x0001080D
#define GPIO_PB2_USB0STP        0x0001080E
#define GPIO_PB2_EPI0S27        0x0001080F

#define GPIO_PB3_I2C0SDA        0x00010C02
#define GPIO_PB3_T5CCP1         0x00010C03
#define GPIO_PB3_PS2DAT2        0x00010C04
#define GPIO_PB3_EN0MDIO        0x00010C05
#define GPIO_PB3_LPC0RESET_N    0x00010C0D
#define GPIO_PB3_USB0CLK        0x00010C0E
#define GPIO_PB3_EPI0S28        0x00010C0F

#define GPIO_PB4_U0CTS          0x00011001
#define GPIO_PB4_I2C5SCL        0x00011002
#define GPIO_PB4_SSI1FSS        0x0001100F

#define GPIO_PB5_U0RTS          0x00011401
#define GPIO_PB5_I2C5SDA        0x00011402
#define GPIO_PB5_SSI1CLK        0x0001140F

#define GPIO_PB6_I2C6SCL        0x00011802
#define GPIO_PB6_T6CCP0         0x00011803
#define GPIO_PB6_PS2CLK3        0x00011804

#define GPIO_PB7_I2C6SDA        0x00011C02
#define GPIO_PB7_T6CCP1         0x00011C03
#define GPIO_PB7_PS2DAT3        0x00011C04

#define GPIO_PC0_TCK            0x00020001
#define GPIO_PC0_SWCLK          0x00020001
#define GPIO_PC0_HLED0          0x00020004
#define GPIO_PC0_KBCOUT00       0x00020005

#define GPIO_PC1_TMS            0x00020401
#define GPIO_PC1_SWDIO          0x00020401
#define GPIO_PC1_HLED1          0x00020404
#define GPIO_PC1_KBCOUT01       0x00020405

#define GPIO_PC2_TDI            0x00020801
#define GPIO_PC2_HLED2          0x00020804
#define GPIO_PC2_KBCOUT02       0x00020805

#define GPIO_PC3_SWO            0x00020C01
#define GPIO_PC3_TDO            0x00020C01
#define GPIO_PC3_KBCOUT03       0x00020C05
#define GPIO_PC3_HLED3          0x00020C04

#define GPIO_PC4_U7RX           0x00021001
#define GPIO_PC4_T7CCP0         0x00021003
#define GPIO_PC4_FAN0PWM0       0x00021004
#define GPIO_PC4_EPI0S7         0x0002100F

#define GPIO_PC5_U7TX           0x00021401
#define GPIO_PC5_T7CCP1         0x00021403
#define GPIO_PC5_FAN0TACH0      0x00021404
#define GPIO_PC5_RTCCLK         0x00021407
#define GPIO_PC5_EPI0S6         0x0002140F

#define GPIO_PC6_U5RX           0x00021801
#define GPIO_PC6_FAN0PWM1       0x00021804
#define GPIO_PC6_EPI0S5         0x0002180F

#define GPIO_PC7_U5TX           0x00021C01
#define GPIO_PC7_FAN0TACH1      0x00021C04
#define GPIO_PC7_EPI0S4         0x00021C0F

#define GPIO_PD0_I2C7SCL        0x00030002
#define GPIO_PD0_T0CCP0         0x00030003
#define GPIO_PD0_FAN0PWM4       0x00030004
#define GPIO_PD0_C0O            0x00030005
#define GPIO_PD0_SSI2XDAT1      0x0003000F

#define GPIO_PD1_I2C7SDA        0x00030402
#define GPIO_PD1_T0CCP1         0x00030403
#define GPIO_PD1_FAN0TACH4      0x00030404
#define GPIO_PD1_C1O            0x00030405
#define GPIO_PD1_SSI2XDAT0      0x0003040F

#define GPIO_PD2_I2C8SCL        0x00030802
#define GPIO_PD2_T1CCP0         0x00030803
#define GPIO_PD2_C2O            0x00030805
#define GPIO_PD2_SSI2FSS        0x0003080F

#define GPIO_PD3_I2C8SDA        0x00030C02
#define GPIO_PD3_T1CCP1         0x00030C03
#define GPIO_PD3_SSI2CLK        0x00030C0F

#define GPIO_PD4_U2RX           0x00031001
#define GPIO_PD4_T3CCP0         0x00031003
#define GPIO_PD4_KBCOUT19       0x00031004
#define GPIO_PD4_SSI1XDAT2      0x0003100F

#define GPIO_PD5_U2TX           0x00031401
#define GPIO_PD5_T3CCP1         0x00031403
#define GPIO_PD5_KBCOUT18       0x00031404
#define GPIO_PD5_SSI1XDAT3      0x0003140F

#define GPIO_PD6_U2RTS          0x00031801
#define GPIO_PD6_T4CCP0         0x00031803
#define GPIO_PD6_USB0EPEN       0x00031805
#define GPIO_PD6_SSI2XDAT3      0x0003180F

#define GPIO_PD7_U2CTS          0x00031C01
#define GPIO_PD7_T4CCP1         0x00031C03
#define GPIO_PD7_USB0PFLT       0x00031C05
#define GPIO_PD7_NMI            0x00031C08
#define GPIO_PD7_SSI2XDAT2      0x00031C0F

#define GPIO_PE0_U1RTS          0x00040001

#define GPIO_PE1_U1DSR          0x00040401

#define GPIO_PE2_U1DCD          0x00040801

#define GPIO_PE3_U1DTR          0x00040C01

#define GPIO_PE4_U1RI           0x00041001
#define GPIO_PE4_FAN0TACH7      0x00041004
#define GPIO_PE4_SSI1XDAT0      0x0004100F

#define GPIO_PE5_FAN0PWM7       0x00041404
#define GPIO_PE5_SSI1XDAT1      0x0004140F

#define GPIO_PE6_U0CTS          0x00041801
#define GPIO_PE6_I2C9SCL        0x00041802
#define GPIO_PE6_HLED2          0x00041804

#define GPIO_PE7_U0RTS          0x00041C01
#define GPIO_PE7_I2C9SDA        0x00041C02
#define GPIO_PE7_HLED3          0x00041C04
#define GPIO_PE7_NMI            0x00041C08

#define GPIO_PF0_KBCOUT00       0x00050003
#define GPIO_PF0_FAN0PWM2       0x00050004
#define GPIO_PF0_EN0LED0        0x00050005
#define GPIO_PF0_M0PWM0         0x00050006
#define GPIO_PF0_KBCOUT07       0x00050007
#define GPIO_PF0_SSI3XDAT1      0x0005000E
#define GPIO_PF0_TRD2           0x0005000F

#define GPIO_PF1_KBCOUT01       0x00050403
#define GPIO_PF1_FAN0TACH2      0x00050404
#define GPIO_PF1_EN0LED2        0x00050405
#define GPIO_PF1_M0PWM1         0x00050406
#define GPIO_PF1_KBCOUT06       0x00050407
#define GPIO_PF1_SSI3XDAT0      0x0005040E
#define GPIO_PF1_TRD1           0x0005040F

#define GPIO_PF2_KBCOUT02       0x00050803
#define GPIO_PF2_FAN0PWM3       0x00050804
#define GPIO_PF2_EN0MDC         0x00050805
#define GPIO_PF2_M0PWM2         0x00050806
#define GPIO_PF2_KBCOUT05       0x00050807
#define GPIO_PF2_SSI3FSS        0x0005080E
#define GPIO_PF2_TRD0           0x0005080F

#define GPIO_PF3_KBCOUT03       0x00050C03
#define GPIO_PF3_FAN0TACH3      0x00050C04
#define GPIO_PF3_EN0MDIO        0x00050C05
#define GPIO_PF3_M0PWM3         0x00050C06
#define GPIO_PF3_KBCOUT04       0x00050C07
#define GPIO_PF3_SSI3CLK        0x00050C0E
#define GPIO_PF3_TRCLK          0x00050C0F

#define GPIO_PF4_KBCOUT16       0x00051003
#define GPIO_PF4_FAN0PWM4       0x00051004
#define GPIO_PF4_EN0LED1        0x00051005
#define GPIO_PF4_M0FAULT0       0x00051006
#define GPIO_PF4_SSI3XDAT2      0x0005100E
#define GPIO_PF4_TRD3           0x0005100F

#define GPIO_PF5_KBCOUT17       0x00051403
#define GPIO_PF5_FAN0TACH4      0x00051404
#define GPIO_PF5_SSI3XDAT3      0x0005140E

#define GPIO_PF6_FAN0PWM5       0x00051804
#define GPIO_PF6_LCDMCLK        0x0005180F

#define GPIO_PF7_FAN0TACH5      0x00051C04
#define GPIO_PF7_LCDDATA02      0x00051C0F

#define GPIO_PG0_I2C1SCL        0x00060002
#define GPIO_PG0_FAN1PWM0       0x00060003
#define GPIO_PG0_FAN0PWM6       0x00060004
#define GPIO_PG0_EN0PPS         0x00060005
#define GPIO_PG0_M0PWM4         0x00060006
#define GPIO_PG0_EPI0S11        0x0006000F

#define GPIO_PG1_I2C1SDA        0x00060402
#define GPIO_PG1_KBRST_N        0x00060403
#define GPIO_PG1_FAN0TACH6      0x00060404
#define GPIO_PG1_FAN1TACH0      0x00060405
#define GPIO_PG1_M0PWM5         0x00060406
#define GPIO_PG1_EPI0S10        0x0006040F

#define GPIO_PG2_I2C2SCL        0x00060802
#define GPIO_PG2_KBCOUT00       0x00060803
#define GPIO_PG2_FAN0PWM7       0x00060804
#define GPIO_PG2_FAN1PWM1       0x00060805
#define GPIO_PG2_EN0TXCK        0x0006080E
#define GPIO_PG2_SSI2XDAT3      0x0006080F

#define GPIO_PG3_I2C2SDA        0x00060C02
#define GPIO_PG3_KBCOUT01       0x00060C03
#define GPIO_PG3_FAN0TACH7      0x00060C04
#define GPIO_PG3_FAN1TACH1      0x00060C05
#define GPIO_PG3_EN0TXEN        0x00060C0E
#define GPIO_PG3_SSI2XDAT2      0x00060C0F

#define GPIO_PG4_U0CTS          0x00061001
#define GPIO_PG4_I2C3SCL        0x00061002
#define GPIO_PG4_OWIRE          0x00061005
#define GPIO_PG4_EN0TXD0        0x0006100E
#define GPIO_PG4_SSI2XDAT1      0x0006100F

#define GPIO_PG5_U0RTS          0x00061401
#define GPIO_PG5_I2C3SDA        0x00061402
#define GPIO_PG5_KBRST_N        0x00061404
#define GPIO_PG5_OWALT          0x00061405
#define GPIO_PG5_EN0TXD1        0x0006140E
#define GPIO_PG5_SSI2XDAT0      0x0006140F

#define GPIO_PG6_I2C4SCL        0x00061802
#define GPIO_PG6_KBCOUT00       0x00061804
#define GPIO_PG6_EN0RXER        0x0006180E
#define GPIO_PG6_SSI2FSS        0x0006180F

#define GPIO_PG7_I2C4SDA        0x00061C02
#define GPIO_PG7_KBCOUT01       0x00061C04
#define GPIO_PG7_EN0RXDV        0x00061C0E
#define GPIO_PG7_SSI2CLK        0x00061C0F

#define GPIO_PH0_U0RTS          0x00070001
#define GPIO_PH0_LPC0COMXRTS    0x00070002
#define GPIO_PH0_KBCIN04        0x00070004
#define GPIO_PH0_FAN1PWM3       0x00070005
#define GPIO_PH0_EPI0S0         0x0007000F

#define GPIO_PH1_U0CTS          0x00070401
#define GPIO_PH1_LPC0COMXCTS    0x00070402
#define GPIO_PH1_KBCIN05        0x00070404
#define GPIO_PH1_FAN1TACH3      0x00070405
#define GPIO_PH1_EPI0S1         0x0007040F

#define GPIO_PH2_U0DCD          0x00070801
#define GPIO_PH2_LPC0COMXDCD    0x00070802
#define GPIO_PH2_KBCIN06        0x00070804
#define GPIO_PH2_FAN0PWM4       0x00070805
#define GPIO_PH2_EPI0S2         0x0007080F

#define GPIO_PH3_U0DSR          0x00070C01
#define GPIO_PH3_LPC0COMXDSR    0x00070C02
#define GPIO_PH3_KBCIN07        0x00070C04
#define GPIO_PH3_FAN0TACH4      0x00070C05
#define GPIO_PH3_EPI0S3         0x00070C0F

#define GPIO_PH4_U0DTR          0x00071001
#define GPIO_PH4_LPC0COMXDTR    0x00071002
#define GPIO_PH4_LPC0COMXRTS    0x00071003
#define GPIO_PH4_PS2CLK0        0x00071004

#define GPIO_PH5_U0RI           0x00071401
#define GPIO_PH5_LPC0COMXRI     0x00071402
#define GPIO_PH5_LPC0COMXCTS    0x00071403
#define GPIO_PH5_PS2DAT0        0x00071404
#define GPIO_PH5_EN0PPS         0x00071405

#define GPIO_PH6_U5RX           0x00071801
#define GPIO_PH6_U7RX           0x00071802
#define GPIO_PH6_LPC0COMXDCD    0x00071803
#define GPIO_PH6_FAN1PWM0       0x00071804
#define GPIO_PH6_KBCIN04        0x00071805

#define GPIO_PH7_U5TX           0x00071C01
#define GPIO_PH7_U7TX           0x00071C02
#define GPIO_PH7_LPC0COMXDSR    0x00071C03
#define GPIO_PH7_FAN1TACH0      0x00071C04
#define GPIO_PH7_KBCIN05        0x00071C05

#define GPIO_PJ0_U3RX           0x00080001
#define GPIO_PJ0_EN0PPS         0x00080005

#define GPIO_PJ1_U3TX           0x00080401

#define GPIO_PJ2_U2RTS          0x00080801
#define GPIO_PJ2_KBCOUT02       0x00080804
#define GPIO_PJ2_FAN1PWM1       0x00080805
#define GPIO_PJ2_LCDDATA14      0x0008080F

#define GPIO_PJ3_U2CTS          0x00080C01
#define GPIO_PJ3_KBCOUT03       0x00080C04
#define GPIO_PJ3_FAN1TACH1      0x00080C05
#define GPIO_PJ3_LCDDATA15      0x00080C0F

#define GPIO_PJ4_U3RTS          0x00081001
#define GPIO_PJ4_KBCOUT04       0x00081004
#define GPIO_PJ4_FAN1PWM5       0x00081005
#define GPIO_PJ4_LCDDATA16      0x0008100F

#define GPIO_PJ5_U3CTS          0x00081401
#define GPIO_PJ5_KBCOUT05       0x00081404
#define GPIO_PJ5_FAN1TACH5      0x00081405
#define GPIO_PJ5_LCDDATA17      0x0008140F

#define GPIO_PJ6_U4RTS          0x00081801
#define GPIO_PJ6_KBCOUT06       0x00081804
#define GPIO_PJ6_LCDAC          0x0008180F

#define GPIO_PJ7_U4CTS          0x00081C01
#define GPIO_PJ7_KBCOUT07       0x00081C04

#define GPIO_PK0_U4RX           0x00090001
#define GPIO_PK0_KBCIN06        0x00090003
#define GPIO_PK0_FAN1PWM6       0x00090004
#define GPIO_PK0_EPI0S0         0x0009000F

#define GPIO_PK1_U4TX           0x00090401
#define GPIO_PK1_KBCIN07        0x00090403
#define GPIO_PK1_FAN1TACH6      0x00090404
#define GPIO_PK1_EPI0S1         0x0009040F

#define GPIO_PK2_U4RTS          0x00090801
#define GPIO_PK2_KBCOUT05       0x00090803
#define GPIO_PK2_FAN1PWM7       0x00090804
#define GPIO_PK2_EPI0S2         0x0009080F

#define GPIO_PK3_U4CTS          0x00090C01
#define GPIO_PK3_KBCOUT06       0x00090C03
#define GPIO_PK3_FAN1TACH7      0x00090C04
#define GPIO_PK3_EPI0S3         0x00090C0F

#define GPIO_PK4_I2C3SCL        0x00091002
#define GPIO_PK4_KBCIN00        0x00091004
#define GPIO_PK4_EN0LED0        0x00091005
#define GPIO_PK4_M0PWM6         0x00091006
#define GPIO_PK4_EN0INTRN       0x00091007
#define GPIO_PK4_EN0RXD3        0x0009100E
#define GPIO_PK4_EPI0S32        0x0009100F

#define GPIO_PK5_I2C3SDA        0x00091402
#define GPIO_PK5_KBCIN01        0x00091404
#define GPIO_PK5_EN0LED2        0x00091405
#define GPIO_PK5_M0PWM7         0x00091406
#define GPIO_PK5_EN0RXD2        0x0009140E
#define GPIO_PK5_EPI0S31        0x0009140F

#define GPIO_PK6_I2C4SCL        0x00091802
#define GPIO_PK6_KBCIN02        0x00091804
#define GPIO_PK6_EN0LED1        0x00091805
#define GPIO_PK6_M0FAULT1       0x00091806
#define GPIO_PK6_EN0TXD2        0x0009180E
#define GPIO_PK6_EPI0S25        0x0009180F

#define GPIO_PK7_U0RI           0x00091C01
#define GPIO_PK7_I2C4SDA        0x00091C02
#define GPIO_PK7_KBCIN03        0x00091C04
#define GPIO_PK7_RTCCLK         0x00091C05
#define GPIO_PK7_M0FAULT2       0x00091C06
#define GPIO_PK7_EN0TXD3        0x00091C0E
#define GPIO_PK7_EPI0S24        0x00091C0F

#define GPIO_PL0_I2C2SDA        0x000A0002
#define GPIO_PL0_M0FAULT3       0x000A0006
#define GPIO_PL0_LPC0FRAME_N    0x000A000D
#define GPIO_PL0_USB0D0         0x000A000E
#define GPIO_PL0_EPI0S16        0x000A000F

#define GPIO_PL1_I2C2SCL        0x000A0402
#define GPIO_PL1_PHA0           0x000A0406
#define GPIO_PL1_LPC0CLK        0x000A040D
#define GPIO_PL1_USB0D1         0x000A040E
#define GPIO_PL1_EPI0S17        0x000A040F

#define GPIO_PL2_C0O            0x000A0805
#define GPIO_PL2_PHB0           0x000A0806
#define GPIO_PL2_LPC0CLKRUN_N   0x000A080D
#define GPIO_PL2_USB0D2         0x000A080E
#define GPIO_PL2_EPI0S18        0x000A080F

#define GPIO_PL3_C1O            0x000A0C05
#define GPIO_PL3_IDX0           0x000A0C06
#define GPIO_PL3_LPC0SERIRQ     0x000A0C0D
#define GPIO_PL3_USB0D3         0x000A0C0E
#define GPIO_PL3_EPI0S19        0x000A0C0F

#define GPIO_PL4_T0CCP0         0x000A1003
#define GPIO_PL4_LPC0SCI_N      0x000A100D
#define GPIO_PL4_USB0D4         0x000A100E
#define GPIO_PL4_EPI0S26        0x000A100F

#define GPIO_PL5_T0CCP1         0x000A1403
#define GPIO_PL5_EPI0S33        0x000A140F
#define GPIO_PL5_LPC0PD_N       0x000A140D
#define GPIO_PL5_USB0D5         0x000A140E

#define GPIO_PL6_T1CCP0         0x000A1803
#define GPIO_PL6_FAN1PWM4       0x000A1804

#define GPIO_PL7_T1CCP1         0x000A1C03
#define GPIO_PL7_FAN1TACH4      0x000A1C04

#define GPIO_PM0_T2CCP0         0x000B0003
#define GPIO_PM0_FAN0PWM5       0x000B0005
#define GPIO_PM0_LPC0AD3        0x000B000D
#define GPIO_PM0_EPI0S15        0x000B000F

#define GPIO_PM1_T2CCP1         0x000B0403
#define GPIO_PM1_FAN0TACH5      0x000B0405
#define GPIO_PM1_LPC0AD2        0x000B040D
#define GPIO_PM1_EPI0S14        0x000B040F

#define GPIO_PM2_T3CCP0         0x000B0803
#define GPIO_PM2_FAN1PWM4       0x000B0805
#define GPIO_PM2_LPC0AD1        0x000B080D
#define GPIO_PM2_EPI0S13        0x000B080F

#define GPIO_PM3_T3CCP1         0x000B0C03
#define GPIO_PM3_FAN1TACH4      0x000B0C05
#define GPIO_PM3_LPC0AD0        0x000B0C0D
#define GPIO_PM3_EPI0S12        0x000B0C0F

#define GPIO_PM4_U0CTS          0x000B1001
#define GPIO_PM4_T4CCP0         0x000B1003
#define GPIO_PM4_KBCIN04        0x000B1004
#define GPIO_PM4_EN0RREF_CLK    0x000B100E

#define GPIO_PM5_U0DCD          0x000B1401
#define GPIO_PM5_T4CCP1         0x000B1403
#define GPIO_PM5_KBCIN05        0x000B1404

#define GPIO_PM6_U0DSR          0x000B1801
#define GPIO_PM6_LPC0COMXRTS    0x000B1802
#define GPIO_PM6_KBCIN06        0x000B1804
#define GPIO_PM6_T5CCP0         0x000B1803
#define GPIO_PM6_EN0CRS         0x000B180E

#define GPIO_PM7_U0RI           0x000B1C01
#define GPIO_PM7_LPC0COMXCTS    0x000B1C02
#define GPIO_PM7_KBCIN07        0x000B1C04
#define GPIO_PM7_T5CCP1         0x000B1C03
#define GPIO_PM7_EN0COL         0x000B1C0E

#define GPIO_PN0_U1RTS          0x000C0001
#define GPIO_PN0_LPC0COMYRTS    0x000C0002
#define GPIO_PN0_KBCOUT11       0x000C0003
#define GPIO_PN0_PS2CLK1        0x000C0004
#define GPIO_PN0_FAN0PWM5       0x000C0005

#define GPIO_PN1_U1CTS          0x000C0401
#define GPIO_PN1_LPC0COMYCTS    0x000C0402
#define GPIO_PN1_KBCOUT12       0x000C0403
#define GPIO_PN1_PS2DAT1        0x000C0404
#define GPIO_PN1_FAN0TACH5      0x000C0405

#define GPIO_PN2_U1DCD          0x000C0801
#define GPIO_PN2_U2RTS          0x000C0802
#define GPIO_PN2_LPC0COMXDTR    0x000C0803
#define GPIO_PN2_FAN1PWM4       0x000C0805
#define GPIO_PN2_EPI0S29        0x000C080F

#define GPIO_PN3_U1DSR          0x000C0C01
#define GPIO_PN3_U2CTS          0x000C0C02
#define GPIO_PN3_LPC0COMXRI     0x000C0C03
#define GPIO_PN3_KBCOUT17       0x000C0C04
#define GPIO_PN3_FAN1TACH4      0x000C0C05
#define GPIO_PN3_EPI0S30        0x000C0C0F

#define GPIO_PN4_U1DTR          0x000C1001
#define GPIO_PN4_U3RTS          0x000C1002
#define GPIO_PN4_I2C2SDA        0x000C1003
#define GPIO_PN4_KBCOUT14       0x000C1004
#define GPIO_PN4_EPI0S34        0x000C100F

#define GPIO_PN5_U1RI           0x000C1401
#define GPIO_PN5_U3CTS          0x000C1402
#define GPIO_PN5_I2C2SCL        0x000C1403
#define GPIO_PN5_KBCOUT15       0x000C1404
#define GPIO_PN5_EPI0S35        0x000C140F

#define GPIO_PN6_U4RTS          0x000C1802
#define GPIO_PN6_KBCOUT07       0x000C1803
#define GPIO_PN6_FAN1PWM3       0x000C1804
#define GPIO_PN6_PS2CLK2        0x000C1805
#define GPIO_PN6_EN0TXER        0x000C180E
#define GPIO_PN6_LCDDATA13      0x000C180F

#define GPIO_PN7_U1RTS          0x000C1C01
#define GPIO_PN7_U4CTS          0x000C1C02
#define GPIO_PN7_FAN1TACH3      0x000C1C04
#define GPIO_PN7_PS2DAT2        0x000C1C05
#define GPIO_PN7_LCDDATA12      0x000C1C0F

#define GPIO_PP0_U6RX           0x000D0001
#define GPIO_PP0_KBCOUT18       0x000D0003
#define GPIO_PP0_HLED0          0x000D0004
#define GPIO_PP0_T6CCP0         0x000D0005
#define GPIO_PP0_EN0INTRN       0x000D0007
#define GPIO_PP0_SSI3XDAT2      0x000D000F

#define GPIO_PP1_U6TX           0x000D0401
#define GPIO_PP1_KBCOUT19       0x000D0403
#define GPIO_PP1_HLED1          0x000D0404
#define GPIO_PP1_T6CCP1         0x000D0405
#define GPIO_PP1_SSI3XDAT3      0x000D040F

#define GPIO_PP2_U0DTR          0x000D0801
#define GPIO_PP2_FAN1PWM2       0x000D0804
#define GPIO_PP2_USB0NXT        0x000D080E
#define GPIO_PP2_EPI0S29        0x000D080F

#define GPIO_PP3_U1CTS          0x000D0C01
#define GPIO_PP3_U0DCD          0x000D0C02
#define GPIO_PP3_KBCOUT08       0x000D0C03
#define GPIO_PP3_FAN1TACH2      0x000D0C04
#define GPIO_PP3_RTCCLK         0x000D0C07
#define GPIO_PP3_USB0DIR        0x000D0C0E
#define GPIO_PP3_EPI0S30        0x000D0C0F

#define GPIO_PP4_U3RTS          0x000D1001
#define GPIO_PP4_U0DSR          0x000D1002
#define GPIO_PP4_KBCOUT09       0x000D1003
#define GPIO_PP4_OWIRE          0x000D1004
#define GPIO_PP4_USB0D7         0x000D100E

#define GPIO_PP5_U3CTS          0x000D1401
#define GPIO_PP5_I2C2SCL        0x000D1402
#define GPIO_PP5_KBCOUT10       0x000D1403
#define GPIO_PP5_OWALT          0x000D1404
#define GPIO_PP5_USB0D6         0x000D140E

#define GPIO_PP6_U1DCD          0x000D1801
#define GPIO_PP6_I2C2SDA        0x000D1802
#define GPIO_PP6_KBCOUT11       0x000D1803

#define GPIO_PP7_KBCOUT12       0x000D1C03

#define GPIO_PQ0_T6CCP0         0x000E0003
#define GPIO_PQ0_KBCOUT04       0x000E0004
#define GPIO_PQ0_KBCOUT00       0x000E0005
#define GPIO_PQ0_FAN1PWM1       0x000E0006
#define GPIO_PQ0_SSI3CLK        0x000E000E
#define GPIO_PQ0_EPI0S20        0x000E000F

#define GPIO_PQ1_T6CCP1         0x000E0403
#define GPIO_PQ1_KBCOUT05       0x000E0404
#define GPIO_PQ1_KBCOUT01       0x000E0405
#define GPIO_PQ1_FAN1TACH1      0x000E0406
#define GPIO_PQ1_SSI3FSS        0x000E040E
#define GPIO_PQ1_EPI0S21        0x000E040F

#define GPIO_PQ2_T7CCP0         0x000E0803
#define GPIO_PQ2_KBCOUT06       0x000E0804
#define GPIO_PQ2_KBCOUT02       0x000E0805
#define GPIO_PQ2_SSI3XDAT0      0x000E080E
#define GPIO_PQ2_EPI0S22        0x000E080F

#define GPIO_PQ3_T7CCP1         0x000E0C03
#define GPIO_PQ3_KBCOUT07       0x000E0C04
#define GPIO_PQ3_KBCOUT03       0x000E0C05
#define GPIO_PQ3_SSI3XDAT1      0x000E0C0E
#define GPIO_PQ3_EPI0S23        0x000E0C0F

#define GPIO_PQ4_U1RX           0x000E1001
#define GPIO_PQ4_KBCOUT13       0x000E1003
#define GPIO_PQ4_FAN1PWM0       0x000E1004
#define GPIO_PQ4_LPC0COMYRX     0x000E1005
#define GPIO_PQ4_DIVSCLK        0x000E1007

#define GPIO_PQ5_U1TX           0x000E1401
#define GPIO_PQ5_KBCOUT14       0x000E1403
#define GPIO_PQ5_FAN1TACH0      0x000E1404
#define GPIO_PQ5_LPC0COMYTX     0x000E1405
#define GPIO_PQ5_EN0RXD0        0x000E140E

#define GPIO_PQ6_U1DTR          0x000E1801
#define GPIO_PQ6_KBCOUT15       0x000E1803
#define GPIO_PQ6_FAN1PWM1       0x000E1804
#define GPIO_PQ6_EN0RXD1        0x000E180E

#define GPIO_PQ7_U1RI           0x000E1C01
#define GPIO_PQ7_FAN1TACH1      0x000E1C04

#define GPIO_PR0_U4TX           0x000F0001
#define GPIO_PR0_I2C1SCL        0x000F0002
#define GPIO_PR0_KBCOUT08       0x000F0004
#define GPIO_PR0_M0PWM0         0x000F0006
#define GPIO_PR0_LCDCP          0x000F000F

#define GPIO_PR1_U4RX           0x000F0401
#define GPIO_PR1_I2C1SDA        0x000F0402
#define GPIO_PR1_KBCOUT09       0x000F0404
#define GPIO_PR1_M0PWM1         0x000F0406
#define GPIO_PR1_LCDFP          0x000F040F

#define GPIO_PR2_I2C2SCL        0x000F0802
#define GPIO_PR2_KBCOUT10       0x000F0804
#define GPIO_PR2_M0PWM2         0x000F0806
#define GPIO_PR2_LCDLP          0x000F080F

#define GPIO_PR3_I2C2SDA        0x000F0C02
#define GPIO_PR3_KBCOUT11       0x000F0C04
#define GPIO_PR3_M0PWM3         0x000F0C06
#define GPIO_PR3_LCDDATA03      0x000F0C0F

#define GPIO_PR4_I2C3SCL        0x000F1002
#define GPIO_PR4_T0CCP0         0x000F1003
#define GPIO_PR4_KBCOUT12       0x000F1004
#define GPIO_PR4_M0PWM4         0x000F1006
#define GPIO_PR4_LCDDATA00      0x000F100F

#define GPIO_PR5_U1RX           0x000F1401
#define GPIO_PR5_I2C3SDA        0x000F1402
#define GPIO_PR5_T0CCP1         0x000F1403
#define GPIO_PR5_KBCOUT13       0x000F1404
#define GPIO_PR5_LPC0COMYRX     0x000F1405
#define GPIO_PR5_M0PWM5         0x000F1406
#define GPIO_PR5_LCDDATA01      0x000F140F

#define GPIO_PR6_U1TX           0x000F1801
#define GPIO_PR6_I2C4SCL        0x000F1802
#define GPIO_PR6_T1CCP0         0x000F1803
#define GPIO_PR6_KBCOUT14       0x000F1804
#define GPIO_PR6_LPC0COMYTX     0x000F1805
#define GPIO_PR6_M0PWM6         0x000F1806
#define GPIO_PR6_LCDDATA04      0x000F180F

#define GPIO_PR7_I2C4SDA        0x000F1C02
#define GPIO_PR7_T1CCP1         0x000F1C03
#define GPIO_PR7_KBCOUT15       0x000F1C04
#define GPIO_PR7_M0PWM7         0x000F1C06
#define GPIO_PR7_EN0TXEN        0x000F1C0E
#define GPIO_PR7_LCDDATA05      0x000F1C0F

#define GPIO_PS0_T2CCP0         0x00100003
#define GPIO_PS0_KBCOUT16       0x00100004
#define GPIO_PS0_M0FAULT0       0x00100006
#define GPIO_PS0_LPC0A20        0x0010000D
#define GPIO_PS0_LCDDATA20      0x0010000F

#define GPIO_PS1_T2CCP1         0x00100403
#define GPIO_PS1_KBCOUT17       0x00100404
#define GPIO_PS1_M0FAULT1       0x00100406
#define GPIO_PS1_LPC0RESET_N    0x0010040D
#define GPIO_PS1_LCDDATA21      0x0010040F

#define GPIO_PS2_U1DSR          0x00100801
#define GPIO_PS2_T3CCP0         0x00100803
#define GPIO_PS2_KBCOUT18       0x00100804
#define GPIO_PS2_M0FAULT2       0x00100806
#define GPIO_PS2_LCDDATA22      0x0010080F

#define GPIO_PS3_T3CCP1         0x00100C03
#define GPIO_PS3_KBCOUT19       0x00100C04
#define GPIO_PS3_M0FAULT3       0x00100C06
#define GPIO_PS3_LCDDATA23      0x00100C0F

#define GPIO_PS4_T4CCP0         0x00101003
#define GPIO_PS4_KBCIN07        0x00101004
#define GPIO_PS4_PHA0           0x00101006
#define GPIO_PS4_EN0TXD0        0x0010100E
#define GPIO_PS4_LCDDATA06      0x0010100F

#define GPIO_PS5_T4CCP1         0x00101403
#define GPIO_PS5_KBCIN06        0x00101404
#define GPIO_PS5_PHB0           0x00101406
#define GPIO_PS5_EN0TXD1        0x0010140E
#define GPIO_PS5_LCDDATA07      0x0010140F

#define GPIO_PS6_T5CCP0         0x00101803
#define GPIO_PS6_KBCIN05        0x00101804
#define GPIO_PS6_IDX0           0x00101806
#define GPIO_PS6_EN0RXER        0x0010180E
#define GPIO_PS6_LCDDATA08      0x0010180F

#define GPIO_PS7_T5CCP1         0x00101C03
#define GPIO_PS7_KBCIN04        0x00101C04
#define GPIO_PS7_EN0RXDV        0x00101C0E
#define GPIO_PS7_LCDDATA09      0x00101C0F

#define GPIO_PT0_T6CCP0         0x00110003
#define GPIO_PT0_KBCIN03        0x00110004
#define GPIO_PT0_CAN0RX         0x00110007
#define GPIO_PT0_EN0RXD0        0x0011000E
#define GPIO_PT0_LCDDATA10      0x0011000F

#define GPIO_PT1_T6CCP1         0x00110403
#define GPIO_PT1_KBCIN02        0x00110404
#define GPIO_PT1_CAN0TX         0x00110407
#define GPIO_PT1_EN0RXD1        0x0011040E
#define GPIO_PT1_LCDDATA11      0x0011040F

#define GPIO_PT2_T7CCP0         0x00110803
#define GPIO_PT2_KBCIN01        0x00110804
#define GPIO_PT2_CAN1RX         0x00110807
#define GPIO_PT2_LCDDATA18      0x0011080F

#define GPIO_PT3_T7CCP1         0x00110C03
#define GPIO_PT3_KBCIN00        0x00110C04
#define GPIO_PT3_CAN1TX         0x00110C07
#define GPIO_PT3_LCDDATA19      0x00110C0F

//*****************************************************************************
//
//! This macro can be used to convert a 24-bit RGB color value as used by the
//! TivaWare Graphics Library into a 12-bit LCD controller color palette
//! entry.
//
//*****************************************************************************
#define PAL_FROM_RGB(ui32RGBColor) (((ui32RGBColor & 0xF0) >> 4) |            \
                                    ((ui32RGBColor & 0xF000) >> 8) |          \
                                    ((ui32RGBColor & 0xF00000) >> 12))

//*****************************************************************************
//
//! This macro can be used to convert from time in microseconds to periods of
//! the supplied clock in Hertz as required when setting up the LIDD and raster
//! timing structures.  The calculation will round such that the number of
//! cycles returned represents no longer a time than specified in the
//! ui32Time_uS parameter.  Values of ui32Time_uS less than or equal to
//! 4294967uS (4.29 seconds) are supported by the macro.  Larger values will
//! cause arithmetic overflow and yield incorrect values.  It is further
//! assumed that ui32ClockFreq is a non-zero multiple of 1000000 (1MHz).
//
//*****************************************************************************
#define CYCLES_FROM_TIME_US(ui32ClockFreq, ui32Time_uS)                       \
    (((ui32Time_uS) == 0) ? 0 :                                               \
    (((ui32ClockFreq) / 1000000) * ((((ui32Time_uS) * 1000) - 1) / 1000)) + 1)

//*****************************************************************************
//
//! This macro can be used to convert from time in nanoseconds to periods of
//! the supplied clock in Hertz as required when setting up the LIDD and raster
//! timing structures.  The calculation will round such that the number of
//! cycles returned represents no longer a time than specified in the
//! ui32Time_nS parameter.  Values of ui32Time_nS less than or equal to
//! 35791394 (35.79 milliseconds) are supported by the macro.  Larger values
//! will cause arithmetic overflow and yield incorrect values.  It is further
//! assumed that ui32ClockFreq is a non-zero multiple of 1000000 (1MHz).
//
//*****************************************************************************
#define CYCLES_FROM_TIME_NS(ui32ClockFreq, ui32Time_nS)                       \
    (((ui32Time_nS) == 0) ? 0 :                                               \
    ((((((ui32ClockFreq) / 1000000) * ((ui32Time_nS) - 1)) / 1000)) + 1))

//*****************************************************************************
//
//! A structure containing timing parameters for the LIDD (LCD Interface
//! Display Driver) interface.  This is used with the LCDIDDTimingSet function.
//
//*****************************************************************************
typedef struct
{
    //
    //! Write Strobe Set-Up cycles.  When performing a write access, this
    //! field defines the number of MCLK cycles that Data Bus/Pad Output
    //! Enable, ALE, the Direction bit, and Chip Select have to be ready before
    //! the Write Strobe is asserted.  Valid values are from 0 to 31.
    //
    uint8_t ui8WSSetup;

    //
    //! Write Strobe Duration cycles.  Field value defines the number of MCLK
    //! cycles for which the Write Strobe is held active when performing a
    //! write access.  Valid values are from 1 to 63.
    //
    uint8_t ui8WSDuration;

    //
    //! Write Strobe Hold cycles.  Field value defines the number of MCLK
    //! cycles for which Data Bus/Pad Output Enable, ALE, the Direction bit,
    //! and Chip Select are held after the Write Strobe is deasserted when
    //! performing a write access.  Valid values are from 1 to 15.
    //
    uint8_t ui8WSHold;

    //
    //! Read Strobe Set-Up cycles.  When performing a read access, this field
    //! defines the number of MCLK cycles that Data Bus/Pad Output Enable, ALE,
    //! the Direction bit, and Chip Select have to be ready before the Read
    //! Strobe is asserted.  Valid values are from 0 to 31.
    //
    uint8_t ui8RSSetup;

    //
    //! Read Strobe Duration cycles.  Field value defines the number of MCLK
    //! cycles for which the Read Strobe is held active when performing a read
    //! access.  Valid values are from 1 to 63.
    //
    uint8_t ui8RSDuration;

    //
    //! Read Strobe Hold cycles.  Field value defines the number of MCLK cycles
    //! for which Data Bus/Pad Output Enable, ALE, the Direction bit, and Chip
    //! Select are held after the Read Strobe is deasserted when performing a
    //! read access.  Valid values are from 1 to 15.
    //
    uint8_t ui8RSHold;

    //
    //! Field value defines the number of MCLK cycles between the end of one
    //! device access and the start of another device access using the same
    //! Chip Select unless the two accesses are both Reads.  In this case,
    //! this delay is not incurred.  Valid vales are from 1 to 4.
    //
    uint8_t ui8DelayCycles;
}
tLCDIDDTiming;

//
// Values which can be ORed together within the ui32Flags field of the
// tLCDRasterTiming structure.
//
#define RASTER_TIMING_SYNCS_OPPOSITE_PIXCLK                                   \
                                0x00000000
#define RASTER_TIMING_SYNCS_ON_RISING_PIXCLK                                  \
                                0x02000000
#define RASTER_TIMING_SYNCS_ON_FALLING_PIXCLK                                 \
                                0x03000000
#define RASTER_TIMING_ACTIVE_HIGH_OE                                          \
                                0x00000000
#define RASTER_TIMING_ACTIVE_LOW_OE                                           \
                                0x00800000
#define RASTER_TIMING_ACTIVE_HIGH_PIXCLK                                      \
                                0x00000000
#define RASTER_TIMING_ACTIVE_LOW_PIXCLK                                       \
                                0x00400000
#define RASTER_TIMING_ACTIVE_HIGH_HSYNC                                       \
                                0x00000000
#define RASTER_TIMING_ACTIVE_LOW_HSYNC                                        \
                                0x00200000
#define RASTER_TIMING_ACTIVE_HIGH_VSYNC                                       \
                                0x00000000
#define RASTER_TIMING_ACTIVE_LOW_VSYNC                                        \
                                0x00100000

//
//! A structure containing timing parameters for the raster interface.  This is
//! used with the LCDRasterTimingSet function.
//
typedef struct
{
    //
    //! Flags configuring the polarity and active edges of the various signals
    //! in the raster interface.  This field is comprised of a logical OR of
    //! the labels with prefix  ``RASTER_TIMING_''.
    //
    uint32_t ui32Flags;

    //
    //! The number of pixels contained within each line on the LCD display.
    //! Valid values are multiple of 16 less than or equal to 2048.
    //
    uint16_t ui16PanelWidth;

    //
    //! The number of lines on the LCD display.  Valid values are from 1 to
    //! 2048.
    //
    uint16_t ui16PanelHeight;

    //
    //! A value from 1 to 1024 that specifies the number of pixel clock periods
    //! to add to the beginning of a line transmission before the first set of
    //! pixels is output to the display.
    //
    uint16_t ui16HFrontPorch;

    //
    //! A value from 1 to 1024 that specifies the number of pixel clock periods
    //! to add to the end of a line transmission before line clock is asserted.
    //
    uint16_t ui16HBackPorch;

    //
    //! A value from 1 to 1024 that specifies the number of pixel clock periods
    //! to pulse the line clock at the end of each line.
    //
    uint16_t ui16HSyncWidth;

    //
    //! A value from 0 to 255 that specifies the number of line clock periods
    //! to add to the beginning of a frame before the first set of pixels is
    //! output to the display.
    //
    uint8_t ui8VFrontPorch;

    //
    //! A value from 0 to 255 that specifies the number of line clock periods
    //! to add to the end of each frame.
    //
    uint8_t ui8VBackPorch;

    //
    //! In active mode, a value from 1 to 64 that specifies the number of
    //! line clock periods to set the lcd_fp pin active at the end of each
    //! frame after the vertical front porch period elapses.  The number of
    //! The frame clock is used as the VSYNC signal in active mode.
    //!
    //! In passive mode, a value from 1 to 64 that specifies the number of
    //! extra line clock periods to insert after the vertical front porch
    //! period has elapsed.  Note that the width of lcd_fp is not affected by
    //! this value in passive mode.
    //
    uint8_t ui8VSyncWidth;

    //
    //! A value from 0 to 255 that specifies the number of line clocks to
    //! count before transitioning the AC Bias pin.  This pin is used to
    //! periodically invert the polarity of the power supply to prevent DC
    //! charge build-up within the display.
    //
    uint8_t ui8ACBiasLineCount;
}
tLCDRasterTiming;

//*****************************************************************************
//
// Possible values for the ui8Mode parameter to LCDModeSet().  The label
// LCD_MODE_AUTO_UFLOW_RESTART may be ORed with either of the other two.
//
//*****************************************************************************
#define LCD_MODE_LIDD           ((uint8_t)0x00)
#define LCD_MODE_RASTER         ((uint8_t)0x01)
#define LCD_MODE_AUTO_UFLOW_RESTART                                           \
                                ((uint8_t)0x02)

//*****************************************************************************
//
// Values used to construct the ui32Config parameter to LCDIDDConfigSet().
//
//*****************************************************************************
#define LIDD_CONFIG_SYNC_MPU68  0x00000000
#define LIDD_CONFIG_ASYNC_MPU68 0x00000001
#define LIDD_CONFIG_SYNC_MPU80  0x00000002
#define LIDD_CONFIG_ASYNC_MPU80 0x00000003
#define LIDD_CONFIG_ASYNC_HITACHI                                             \
                                0x00000004
#define LIDD_CONFIG_INVERT_ALE  0x00000008
#define LIDD_CONFIG_INVERT_RS_EN                                              \
                                0x00000010
#define LIDD_CONFIG_INVERT_WS_DIR                                             \
                                0x00000020
#define LIDD_CONFIG_INVERT_CS0  0x00000040
#define LIDD_CONFIG_INVERT_CS1  0x00000080

//*****************************************************************************
//
// Values used to construct the ui32Config parameter to
// LCDRasterConfigSet().  Valid parameters contain one of the RASTER_FMT_xxx
// labels optionally ORed with the other flags.  Only one of
// RASTER_LOAD_DATA_ONLY and RASTER_LOAD_PALETTE_ONLY may be specified (if
// neither is specified, the controller will load both palette and data when
// scanning out the frame buffer).
//
//*****************************************************************************
#define RASTER_FMT_ACTIVE_24BPP_PACKED                                        \
                                0x02000080
#define RASTER_FMT_ACTIVE_24BPP_UNPACKED                                      \
                                0x06000080
#define RASTER_FMT_ACTIVE_PALETTIZED_12BIT                                    \
                                0x00000080
#define RASTER_FMT_ACTIVE_PALETTIZED_16BIT                                    \
                                0x00800080
#define RASTER_FMT_PASSIVE_MONO_4PIX                                          \
                                0x00000002
#define RASTER_FMT_PASSIVE_MONO_8PIX                                          \
                                0x00000202
#define RASTER_FMT_PASSIVE_PALETTIZED                                         \
                                0x00000000
#define RASTER_FMT_PASSIVE_COLOR_12BIT                                        \
                                0x00000000
#define RASTER_FMT_PASSIVE_COLOR_16BIT                                        \
                                0x01000000
#define RASTER_ACTVID_DURING_BLANK                                            \
                                0x08000000
#define RASTER_NIBBLE_MODE_ENABLED                                            \
                                0x00400000
#define RASTER_LOAD_DATA_ONLY   0x00200000
#define RASTER_LOAD_PALETTE_ONLY                                              \
                                0x00100000
#define RASTER_READ_ORDER_REVERSED                                            \
                                0x00000100

//*****************************************************************************
//
// Interrupt sources for the LCD controller.  These may be ORed together and
// passed to LCDIntEnable(), LCDIntDisable() and LCDIntClear().  They are also
// returned by LCDIntStatus().
//
//*****************************************************************************
#define LCD_INT_DMA_DONE        0x00000001
#define LCD_INT_RASTER_FRAME_DONE                                             \
                                0x00000002
#define LCD_INT_SYNC_LOST       0x00000004
#define LCD_INT_AC_BIAS_CNT     0x00000008
#define LCD_INT_UNDERFLOW       0x00000020
#define LCD_INT_PAL_LOAD        0x00000040
#define LCD_INT_EOF0            0x00000100
#define LCD_INT_EOF1            0x00000200

//*****************************************************************************
//
// Configuration values used with LCDDMAConfigSet().
//
//*****************************************************************************
#define LCD_DMA_PRIORITY_0      0x00000000
#define LCD_DMA_PRIORITY_1      0x00010000
#define LCD_DMA_PRIORITY_2      0x00020000
#define LCD_DMA_PRIORITY_3      0x00030000
#define LCD_DMA_PRIORITY_4      0x00040000
#define LCD_DMA_PRIORITY_5      0x00050000
#define LCD_DMA_PRIORITY_6      0x00060000
#define LCD_DMA_PRIORITY_7      0x00070000
#define LCD_DMA_FIFORDY_8_WORDS 0x00000000
#define LCD_DMA_FIFORDY_16_WORDS                                              \
                                0x00000100
#define LCD_DMA_FIFORDY_32_WORDS                                              \
                                0x00000200
#define LCD_DMA_FIFORDY_64_WORDS                                              \
                                0x00000300
#define LCD_DMA_FIFORDY_128_WORDS                                             \
                                0x00000400
#define LCD_DMA_FIFORDY_256_WORDS                                             \
                                0x00000500
#define LCD_DMA_FIFORDY_512_WORDS                                             \
                                0x00000600
#define LCD_DMA_BURST_1         0x00000010
#define LCD_DMA_BURST_2         0x00000010
#define LCD_DMA_BURST_4         0x00000020
#define LCD_DMA_BURST_8         0x00000030
#define LCD_DMA_BURST_16        0x00000040
#define LCD_DMA_BYTE_ORDER_0123 0x00000000
#define LCD_DMA_BYTE_ORDER_1023 0x00000008
#define LCD_DMA_BYTE_ORDER_3210 0x00000002
#define LCD_DMA_BYTE_ORDER_2301 0x0000000A
#define LCD_DMA_PING_PONG       0x00000001

//*****************************************************************************
//
// Type values used with LCDRasterPaletteSet().
//
//*****************************************************************************
#define LCD_PALETTE_TYPE_1BPP   0x00000000
#define LCD_PALETTE_TYPE_2BPP   0x00001000
#define LCD_PALETTE_TYPE_4BPP   0x00002000
#define LCD_PALETTE_TYPE_8BPP   0x00003000
#define LCD_PALETTE_TYPE_DIRECT 0x00004000
#define LCD_PALETTE_SRC_24BIT   0x80000000

//*****************************************************************************
//
// Flags used in the ui32Clocks parameter to LCDClockReset().
//
//*****************************************************************************
#define LCD_CLOCK_MAIN          0x00000008
#define LCD_CLOCK_DMA           0x00000004
#define LCD_CLOCK_LIDD          0x00000002
#define LCD_CLOCK_CORE          0x00000001

//*****************************************************************************
//
// Flags used in with LCDSubPanelConfigSet().
//
//*****************************************************************************
#define LCD_SUBPANEL_AT_TOP     0x20000000
#define LCD_SUBPANEL_AT_BOTTOM  0x00000000

//*****************************************************************************
//
// The following are defines for the LCD register offsets.
//
//*****************************************************************************
#define LCD_O_PID               0x00000000  // PID Register Format
#define LCD_O_CTL               0x00000004  // LCD Control
#define LCD_O_LIDDCTL           0x0000000C  // LCD LIDD Control
#define LCD_O_LIDDCS0CFG        0x00000010  // LCD LIDD CS0 Configuration
#define LCD_O_LIDDCS0ADDR       0x00000014  // LIDD CS0 Read/Write Address
#define LCD_O_LIDDCS0DATA       0x00000018  // LIDD CS0 Data Read/Write
                                            // Initiation
#define LCD_O_LIDDCS1CFG        0x0000001C  // LIDD CS1 Configuration
#define LCD_O_LIDDCS1ADDR       0x00000020  // LIDD CS1 Address Read/Write
                                            // Initiation
#define LCD_O_LIDDCS1DATA       0x00000024  // LIDD CS1 Data Read/Write
                                            // Initiation
#define LCD_O_RASTRCTL          0x00000028  // LCD Raster Control
#define LCD_O_RASTRTIM0         0x0000002C  // LCD Raster Timing 0
#define LCD_O_RASTRTIM1         0x00000030  // LCD Raster Timing 1
#define LCD_O_RASTRTIM2         0x00000034  // LCD Raster Timing 2
#define LCD_O_RASTRSUBP1        0x00000038  // LCD Raster Subpanel Display 1
#define LCD_O_RASTRSUBP2        0x0000003C  // LCD Raster Subpanel Display 2
#define LCD_O_DMACTL            0x00000040  // LCD DMA Control
#define LCD_O_DMABAFB0          0x00000044  // LCD DMA Frame Buffer 0 Base
                                            // Address
#define LCD_O_DMACAFB0          0x00000048  // LCD DMA Frame Buffer 0 Ceiling
                                            // Address
#define LCD_O_DMABAFB1          0x0000004C  // LCD DMA Frame Buffer 1 Base
                                            // Address
#define LCD_O_DMACAFB1          0x00000050  // LCD DMA Frame Buffer 1 Ceiling
                                            // Address
#define LCD_O_SYSCFG            0x00000054  // LCD System Configuration
                                            // Register
#define LCD_O_RISSET            0x00000058  // LCD Interrupt Raw Status and Set
                                            // Register
#define LCD_O_MISCLR            0x0000005C  // LCD Interrupt Status and Clear
#define LCD_O_IM                0x00000060  // LCD Interrupt Interrupt Mask
#define LCD_O_IENC              0x00000064  // LCD Interrupt Enable Clear
#define LCD_O_CLKEN             0x0000006C  // LCD Clock Enable
#define LCD_O_CLKRESET          0x00000070  // LCD Clock Resets

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_PID register.
//
//*****************************************************************************
#define LCD_PID_MAJOR_M         0x00000700  // Major Release Number
#define LCD_PID_MINOR_M         0x0000003F  // Minor Release Number
#define LCD_PID_MAJOR_S         8
#define LCD_PID_MINOR_S         0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_CTL register.
//
//*****************************************************************************
#define LCD_CTL_CLKDIV_M        0x0000FF00  // Clock Divisor
#define LCD_CTL_UFLOWRST        0x00000002  // Underflow Restart
#define LCD_CTL_LCDMODE         0x00000001  // LCD Mode Select
#define LCD_CTL_CLKDIV_S        8

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_LIDDCTL register.
//
//*****************************************************************************
#define LCD_LIDDCTL_DMACS       0x00000200  // CS0/CS1 Select for LIDD DMA
                                            // Writes
#define LCD_LIDDCTL_DMAEN       0x00000100  // LIDD DMA Enable
#define LCD_LIDDCTL_CS1E1       0x00000080  // Chip Select 1 (CS1)/Enable 1(E1)
                                            // Polarity Control
#define LCD_LIDDCTL_CS0E0       0x00000040  // Chip Select 0 (CS0)/Enable 0
                                            // (E0) Polarity Control
#define LCD_LIDDCTL_WRDIRINV    0x00000020  // Write Strobe (WR) /Direction
                                            // (DIR) Polarity Control
#define LCD_LIDDCTL_RDEN        0x00000010  // Read Strobe (RD) /Direct Enable
                                            // (EN) Polarity Control
#define LCD_LIDDCTL_ALE         0x00000008  // Address Latch Enable (ALE)
                                            // Polarity Control
#define LCD_LIDDCTL_MODE_M      0x00000007  // LIDD Mode Select
#define LCD_LIDDCTL_MODE_SYNCM68                                              \
                                0x00000000  // Sync MPU68
#define LCD_LIDDCTL_MODE_ASYNCM68                                             \
                                0x00000001  // Async MPU68
#define LCD_LIDDCTL_MODE_SYNCM80                                              \
                                0x00000002  // Sync MPU80
#define LCD_LIDDCTL_MODE_ASYNCM80                                             \
                                0x00000003  // Async MPU80
#define LCD_LIDDCTL_MODE_ASYNCHIT                                             \
                                0x00000004  // Hitachi (Async)

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_LIDDCS0CFG
// register.
//
//*****************************************************************************
#define LCD_LIDDCS0CFG_WRSU_M   0xF8000000  // Write Strobe (WR) Set-Up Cycles
#define LCD_LIDDCS0CFG_WRDUR_M  0x07E00000  // Write Strobe (WR) Duration
                                            // Cycles
#define LCD_LIDDCS0CFG_WRHOLD_M 0x001E0000  // Write Strobe (WR) Hold cycles
#define LCD_LIDDCS0CFG_RDSU_M   0x0001F000  // Read Strobe (RD) Set-Up cycles
#define LCD_LIDDCS0CFG_RDDUR_M  0x00000FC0  // Read Strobe (RD) Duration cycles
#define LCD_LIDDCS0CFG_RDHOLD_M 0x0000003C  // Read Strobe (RD) Hold cycles
#define LCD_LIDDCS0CFG_GAP_M    0x00000003  // Field value defines the number
                                            // of LCDMCLK (ta+1) cycles between
                                            // the end of one CS0 (LCDAC)
                                            // device access and the start of
                                            // another CS0 (LCDAC) device
                                            // access unless the two accesses
                                            // are both Reads
#define LCD_LIDDCS0CFG_WRSU_S   27
#define LCD_LIDDCS0CFG_WRDUR_S  21
#define LCD_LIDDCS0CFG_WRHOLD_S 17
#define LCD_LIDDCS0CFG_RDSU_S   12
#define LCD_LIDDCS0CFG_RDDUR_S  6
#define LCD_LIDDCS0CFG_RDHOLD_S 2
#define LCD_LIDDCS0CFG_GAP_S    0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_LIDDCS0ADDR
// register.
//
//*****************************************************************************
#define LCD_LIDDCS0ADDR_CS0ADDR_M                                             \
                                0x0000FFFF  // LCD Address Bus Initiation
#define LCD_LIDDCS0ADDR_CS0ADDR_S                                             \
                                0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_LIDDCS0DATA
// register.
//
//*****************************************************************************
#define LCD_LIDDCS0DATA_CS0DATA_M                                             \
                                0x0000FFFF  // LCD Data Read/Write Initiation
#define LCD_LIDDCS0DATA_CS0DATA_S                                             \
                                0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_LIDDCS1CFG
// register.
//
//*****************************************************************************
#define LCD_LIDDCS1CFG_WRSU_M   0xF8000000  // Write Strobe (WR) Set-Up Cycles
#define LCD_LIDDCS1CFG_WRDUR_M  0x07E00000  // Write Strobe (WR) Duration
                                            // Cycles
#define LCD_LIDDCS1CFG_WRHOLD_M 0x001E0000  // Write Strobe (WR) Hold cycles
#define LCD_LIDDCS1CFG_RDSU_M   0x0001F000  // Read Strobe (RD) Set-Up cycles
#define LCD_LIDDCS1CFG_RDDUR_M  0x00000FC0  // Read Strobe (RD) Duration cycles
#define LCD_LIDDCS1CFG_RDHOLD_M 0x0000003C  // Read Strobe (RD) Hold cycles
#define LCD_LIDDCS1CFG_GAP_M    0x00000003  // Field value defines the number
                                            // of LCDMCLK (ta+1) cycles between
                                            // the end of one CS1 (LCDAC)
                                            // device access and the start of
                                            // another CS0 (LCDAC) device
                                            // access unless the two accesses
                                            // are both Reads
#define LCD_LIDDCS1CFG_WRSU_S   27
#define LCD_LIDDCS1CFG_WRDUR_S  21
#define LCD_LIDDCS1CFG_WRHOLD_S 17
#define LCD_LIDDCS1CFG_RDSU_S   12
#define LCD_LIDDCS1CFG_RDDUR_S  6
#define LCD_LIDDCS1CFG_RDHOLD_S 2
#define LCD_LIDDCS1CFG_GAP_S    0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_LIDDCS1ADDR
// register.
//
//*****************************************************************************
#define LCD_LIDDCS1ADDR_CS1ADDR_M                                             \
                                0x0000FFFF  // LCD Address Bus Initiation
#define LCD_LIDDCS1ADDR_CS1ADDR_S                                             \
                                0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_LIDDCS1DATA
// register.
//
//*****************************************************************************
#define LCD_LIDDCS1DATA_CS0DATA_M                                             \
                                0x0000FFFF  // LCD Data Read/Write Initiation
#define LCD_LIDDCS1DATA_CS0DATA_S                                             \
                                0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_RASTRCTL register.
//
//*****************************************************************************
#define LCD_RASTRCTL_TFT24UPCK  0x04000000  // 24-bit TFT Mode Packing
#define LCD_RASTRCTL_TFT24      0x02000000  // 24-Bit TFT Mode
#define LCD_RASTRCTL_FRMBUFSZ   0x01000000  // Frame Buffer Select
#define LCD_RASTRCTL_TFTMAP     0x00800000  // TFT Mode Alternate Signal
                                            // Mapping for Palettized
                                            // Framebuffer
#define LCD_RASTRCTL_NIBMODE    0x00400000  // Nibble Mode
#define LCD_RASTRCTL_PALMODE_M  0x00300000  // Pallette Loading Mode
#define LCD_RASTRCTL_PALMODE_PALDAT                                           \
                                0x00000000  // Palette and data loading, reset
                                            // value
#define LCD_RASTRCTL_PALMODE_PAL                                              \
                                0x00100000  // Palette loading only
#define LCD_RASTRCTL_PALMODE_DAT                                              \
                                0x00200000  // Data loading only
#define LCD_RASTRCTL_REQDLY_M   0x000FF000  // Palette Loading Delay
#define LCD_RASTRCTL_MONO8B     0x00000200  // Mono 8-Bit
#define LCD_RASTRCTL_RDORDER    0x00000100  // Raster Data Order Select
#define LCD_RASTRCTL_LCDTFT     0x00000080  // LCD TFT
#define LCD_RASTRCTL_LCDBW      0x00000002  // LCD Monochrome
#define LCD_RASTRCTL_LCDEN      0x00000001  // LCD Controller Enable for Raster
                                            // Operations
#define LCD_RASTRCTL_REQDLY_S   12

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_RASTRTIM0
// register.
//
//*****************************************************************************
#define LCD_RASTRTIM0_HBP_M     0xFF000000  // Horizontal Back Porch Lowbits
#define LCD_RASTRTIM0_HFP_M     0x00FF0000  // Horizontal Front Porch Lowbits
#define LCD_RASTRTIM0_HSW_M     0x0000FC00  // Horizontal Sync Pulse Width
                                            // Lowbits
#define LCD_RASTRTIM0_PPL_M     0x000003F0  // Pixels-per-line LSB[9:4]
#define LCD_RASTRTIM0_MSBPPL    0x00000008  // Pixels-per-line MSB[10]
#define LCD_RASTRTIM0_HBP_S     24
#define LCD_RASTRTIM0_HFP_S     16
#define LCD_RASTRTIM0_HSW_S     10
#define LCD_RASTRTIM0_PPL_S     4

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_RASTRTIM1
// register.
//
//*****************************************************************************
#define LCD_RASTRTIM1_VBP_M     0xFF000000  // Vertical Back Porch
#define LCD_RASTRTIM1_VFP_M     0x00FF0000  // Vertical Front Porch
#define LCD_RASTRTIM1_VSW_M     0x0000FC00  // Vertical Sync Width Pulse
#define LCD_RASTRTIM1_LPP_M     0x000003FF  // Lines Per Panel
#define LCD_RASTRTIM1_VBP_S     24
#define LCD_RASTRTIM1_VFP_S     16
#define LCD_RASTRTIM1_VSW_S     10
#define LCD_RASTRTIM1_LPP_S     0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_RASTRTIM2
// register.
//
//*****************************************************************************
#define LCD_RASTRTIM2_HSW_M     0x78000000  // Bits 9:6 of the horizontal sync
                                            // width field
#define LCD_RASTRTIM2_MSBLPP    0x04000000  // MSB of Lines Per Panel
#define LCD_RASTRTIM2_PXLCLKCTL 0x02000000  // Hsync/Vsync Pixel Clock Control
                                            // On/Off
#define LCD_RASTRTIM2_PSYNCRF   0x01000000  // Program HSYNC/VSYNC Rise or Fall
#define LCD_RASTRTIM2_INVOE     0x00800000  // Invert Output Enable
#define LCD_RASTRTIM2_INVPXLCLK 0x00400000  // Invert Pixel Clock
#define LCD_RASTRTIM2_IHS       0x00200000  // Invert Hysync
#define LCD_RASTRTIM2_IVS       0x00100000  // Invert Vsync
#define LCD_RASTRTIM2_ACBI_M    0x000F0000  // AC Bias Pins Transitions per
                                            // Interrupt
#define LCD_RASTRTIM2_ACBF_M    0x0000FF00  // AC Bias Pin Frequency
#define LCD_RASTRTIM2_MSBHBP_M  0x00000030  // Bits 9:8 of the horizontal back
                                            // porch field
#define LCD_RASTRTIM2_MSBHFP_M  0x00000003  // Bits 9:8 of the horizontal front
                                            // porch field
#define LCD_RASTRTIM2_HSW_S     27
#define LCD_RASTRTIM2_ACBI_S    16
#define LCD_RASTRTIM2_ACBF_S    8
#define LCD_RASTRTIM2_MSBHBP_S  4
#define LCD_RASTRTIM2_MSBHFP_S  0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_RASTRSUBP1
// register.
//
//*****************************************************************************
#define LCD_RASTRSUBP1_SPEN     0x80000000  // Sub Panel Enable
#define LCD_RASTRSUBP1_HOLS     0x20000000  // High or Low Signal
#define LCD_RASTRSUBP1_LPPT_M   0x03FF0000  // Line Per Panel Threshold
#define LCD_RASTRSUBP1_DPDLSB_M 0x0000FFFF  // Default Pixel Data LSB[15:0]
#define LCD_RASTRSUBP1_LPPT_S   16
#define LCD_RASTRSUBP1_DPDLSB_S 0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_RASTRSUBP2
// register.
//
//*****************************************************************************
#define LCD_RASTRSUBP2_LPPTMSB  0x00000100  // Lines Per Panel Threshold Bit 10
#define LCD_RASTRSUBP2_DPDMSB_M 0x000000FF  // Default Pixel Data MSB [23:16]
#define LCD_RASTRSUBP2_DPDMSB_S 0

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_DMACTL register.
//
//*****************************************************************************
#define LCD_DMACTL_DMAMSTRP_M   0x00070000  // Priority for the L3 OCP Master
                                            // Bus
#define LCD_DMACTL_FIFORDY_M    0x00000700  // DMA FIFO threshold
#define LCD_DMACTL_FIFORDY_8    0x00000000  // 8 words
#define LCD_DMACTL_FIFORDY_16   0x00000100  // 16 words
#define LCD_DMACTL_FIFORDY_32   0x00000200  // 32 words
#define LCD_DMACTL_FIFORDY_64   0x00000300  // 64 words
#define LCD_DMACTL_FIFORDY_128  0x00000400  // 128 words
#define LCD_DMACTL_FIFORDY_256  0x00000500  // 256 words
#define LCD_DMACTL_FIFORDY_512  0x00000600  // 512 words
#define LCD_DMACTL_BURSTSZ_M    0x00000070  // Burst Size setting for DMA
                                            // transfers (all DMA transfers are
                                            // 32 bits wide):
#define LCD_DMACTL_BURSTSZ_4    0x00000020  // burst size of 4
#define LCD_DMACTL_BURSTSZ_8    0x00000030  // burst size of 8
#define LCD_DMACTL_BURSTSZ_16   0x00000040  // burst size of 16
#define LCD_DMACTL_BYTESWAP     0x00000008  // This bit controls the bytelane
                                            // ordering of the data on the
                                            // output of the DMA module
#define LCD_DMACTL_BIGDEND      0x00000002  // The BIGEND and BYTESWAP bits
                                            // control the bytelane ordering of
                                            // the data on the output of the
                                            // DMA module
#define LCD_DMACTL_FMODE        0x00000001  // Frame Mode
#define LCD_DMACTL_DMAMSTRP_S   16

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_DMABAFB0 register.
//
//*****************************************************************************
#define LCD_DMABAFB0_FB0BA_M    0xFFFFFFFC  // Frame Buffer 0 Base Address
                                            // pointer
#define LCD_DMABAFB0_FB0BA_S    2

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_DMACAFB0 register.
//
//*****************************************************************************
#define LCD_DMACAFB0_FB0CA_M    0xFFFFFFFC  // Frame Buffer 0 Ceiling Address
                                            // pointer
#define LCD_DMACAFB0_FB0CA_S    2

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_DMABAFB1 register.
//
//*****************************************************************************
#define LCD_DMABAFB1_FB1BA_M    0xFFFFFFFC  // Frame Buffer 1 Base Address
                                            // pointer
#define LCD_DMABAFB1_FB1BA_S    2

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_DMACAFB1 register.
//
//*****************************************************************************
#define LCD_DMACAFB1_FB1CA_M    0xFFFFFFFC  // Frame Buffer 1 Ceiling Address
                                            // pointer
#define LCD_DMACAFB1_FB1CA_S    2

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_SYSCFG register.
//
//*****************************************************************************
#define LCD_SYSCFG_STDBY_M      0x00000030  // Configuration of the local
                                            // initiator state management mode
#define LCD_SYSCFG_STDBY_FORCE  0x00000000  // Force-standby mode: local
                                            // initiator is unconditionally
                                            // placed in standby state. Backup
                                            // mode, for debug only
#define LCD_SYSCFG_STDBY_NONE   0x00000010  // No-standby mode: local initiator
                                            // is unconditionally placed out of
                                            // standby state. Backup mode, for
                                            // debug only
#define LCD_SYSCFG_STDBY_SMART  0x00000020  // Smart-standby mode: local
                                            // initiator standby status depends
                                            // on local conditions, i.e. the
                                            // module's functional requirement
                                            // from the initiator. IP module
                                            // shall not generate
                                            // (initiator-related) wakeup
                                            // events
#define LCD_SYSCFG_STDBY_SMWAKE 0x00000030  // Smart-Standby wakeup-capable
                                            // mode: local initiator standby
                                            // status depends on local
                                            // conditions, i.e. the module's
                                            // functional requirement from the
                                            // initiator
#define LCD_SYSCFG_IDLEMODE_M   0x0000000C  // Configuration of the local
                                            // target state management mode
#define LCD_SYSCFG_IDLEMODE_FORCE                                             \
                                0x00000000  // Force-idle mode: local target's
                                            // idle state follows
                                            // (acknowledges) the system's idle
                                            // requests unconditionally, i.e.
                                            // regardless of the IP module's
                                            // internal requirements. Backup
                                            // mode, for debug only
#define LCD_SYSCFG_IDLEMODE_NONE                                              \
                                0x00000004  // No-idle mode: local target never
                                            // enters idle state. Backup mode,
                                            // for debug only
#define LCD_SYSCFG_IDLEMODE_SMART                                             \
                                0x00000008  // Smart-idle mode: local target's
                                            // idle state eventually follows
                                            // (acknowledges) the system's idle
                                            // requests, depending on the IP
                                            // module's internal requirements.
                                            // IP module shall not generate
                                            // (IRQ- or DMA-requestrelated)
                                            // wakeup events
#define LCD_SYSCFG_IDLEMODE_SMWAKE                                            \
                                0x0000000C  // Smart-idle wakeup-capable mode:
                                            // local target's idle state
                                            // eventually follows
                                            // (acknowledges) the system's idle
                                            // requests, depending on the IP
                                            // module's internal requirements

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_RISSET register.
//
//*****************************************************************************
#define LCD_RISSET_EOF1         0x00000200  // DMA End-of-Frame 1 Raw Interrupt
                                            // Status and Set
#define LCD_RISSET_EOF0         0x00000100  // DMA End-of-Frame 0 Raw Interrupt
                                            // Status and Set
#define LCD_RISSET_PALLOAD      0x00000040  // DMA Palette Loaded Raw Interrupt
                                            // Status and Set
#define LCD_RISSET_FIFOU        0x00000020  // DMA FIFO Underflow Raw Interrupt
                                            // Status and Set
#define LCD_RISSET_ACBS         0x00000008  // AC Bias Count Raw Interrupt
                                            // Status and Set
#define LCD_RISSET_SYNCS        0x00000004  // Frame Synchronization Lost Raw
                                            // Interrupt Status and Set
#define LCD_RISSET_RRASTRDONE   0x00000002  // Raster Mode Frame Done interrupt
#define LCD_RISSET_DONE         0x00000001  // Raster or LIDD Frame Done
                                            // (shared, depends on whether
                                            // Raster or LIDD mode enabled) Raw
                                            // Interrupt Status and Set

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_MISCLR register.
//
//*****************************************************************************
#define LCD_MISCLR_EOF1         0x00000200  // DMA End-of-Frame 1 Enabled
                                            // Interrupt and Clear
#define LCD_MISCLR_EOF0         0x00000100  // DMA End-of-Frame 0 Raw Interrupt
                                            // and Clear
#define LCD_MISCLR_PALLOAD      0x00000040  // DMA Palette Loaded Enabled
                                            // Interrupt and Clear
#define LCD_MISCLR_FIFOU        0x00000020  // DMA FIFO Underflow Enabled
                                            // Interrupt and Clear
#define LCD_MISCLR_ACBS         0x00000008  // AC Bias Count Enabled Interrupt
                                            // and Clear
#define LCD_MISCLR_SYNCS        0x00000004  // Frame Synchronization Lost
                                            // Enabled Interrupt and Clear
#define LCD_MISCLR_RRASTRDONE   0x00000002  // Raster Mode Frame Done interrupt
#define LCD_MISCLR_DONE         0x00000001  // Raster or LIDD Frame Done
                                            // (shared, depends on whether
                                            // Raster or LIDD mode enabled)
                                            // Enabled Interrupt and Clear

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_IM register.
//
//*****************************************************************************
#define LCD_IM_EOF1             0x00000200  // DMA End-of-Frame 1 Interrupt
                                            // Enable Set
#define LCD_IM_EOF0             0x00000100  // DMA End-of-Frame 0 Interrupt
                                            // Enable Set
#define LCD_IM_PALLOAD          0x00000040  // DMA Palette Loaded Interrupt
                                            // Enable Set
#define LCD_IM_FIFOU            0x00000020  // DMA FIFO Underflow Interrupt
                                            // Enable Set
#define LCD_IM_ACBS             0x00000008  // AC Bias Count Interrupt Enable
                                            // Set
#define LCD_IM_SYNCS            0x00000004  // Frame Synchronization Lost
                                            // Interrupt Enable Set
#define LCD_IM_RRASTRDONE       0x00000002  // Raster Mode Frame Done Interrupt
                                            // Enable Set
#define LCD_IM_DONE             0x00000001  // Raster or LIDD Frame Done
                                            // (shared, depends on whether
                                            // Raster or LIDD mode enabled)
                                            // Interrupt Enable Set

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_IENC register.
//
//*****************************************************************************
#define LCD_IENC_EOF1           0x00000200  // DMA End-of-Frame 1 Interrupt
                                            // Enable Clear
#define LCD_IENC_EOF0           0x00000100  // DMA End-of-Frame 0 Interrupt
                                            // Enable Clear
#define LCD_IENC_PALLOAD        0x00000040  // DMA Palette Loaded Interrupt
                                            // Enable Clear
#define LCD_IENC_FIFOU          0x00000020  // DMA FIFO Underflow Interrupt
                                            // Enable Clear
#define LCD_IENC_ACBS           0x00000008  // AC Bias Count Interrupt Enable
                                            // Clear
#define LCD_IENC_SYNCS          0x00000004  // Frame Synchronization Lost
                                            // Interrupt Enable Clear
#define LCD_IENC_RRASTRDONE     0x00000002  // Raster Mode Frame Done Interrupt
                                            // Enable Clear
#define LCD_IENC_DONE           0x00000001  // Raster or LIDD Frame Done
                                            // (shared, depends on whether
                                            // Raster or LIDD mode enabled)
                                            // Interrupt Enable Clear

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_CLKEN register.
//
//*****************************************************************************
#define LCD_CLKEN_DMA           0x00000004  // Software Clock Enable for the
                                            // DMA submodule
#define LCD_CLKEN_LIDD          0x00000002  // Software Clock Enable for the
                                            // LIDD submodule (character
                                            // displays)
#define LCD_CLKEN_CORE          0x00000001  // Software Clock Enable for the
                                            // Core, which encompasses the
                                            // Raster Active Matrix and Passive
                                            // Matrix logic

//*****************************************************************************
//
// The following are defines for the bit fields in the LCD_O_CLKRESET register.
//
//*****************************************************************************
#define LCD_CLKRESET_MAIN       0x00000008  // Software Reset for the entire
                                            // LCD module
#define LCD_CLKRESET_DMA        0x00000004  // Software Reset for the DMA
                                            // submodule
#define LCD_CLKRESET_LIDD       0x00000002  // Software Reset for the LIDD
                                            // submodule (character displays)
#define LCD_CLKRESET_CORE       0x00000001  // Software Reset for the Core,
                                            // which encompasses the Raster
                                            // Active Matrix and Passive Matrix
                                            // logic

//*****************************************************************************
//
// Values that can be passed to ADCSequenceConfigure as the ui32Trigger
// parameter.
//
//*****************************************************************************
#define ADC_TRIGGER_PROCESSOR   0x00000000  // Processor event
#define ADC_TRIGGER_COMP0       0x00000001  // Analog comparator 0 event
#define ADC_TRIGGER_COMP1       0x00000002  // Analog comparator 1 event
#define ADC_TRIGGER_COMP2       0x00000003  // Analog comparator 2 event
#define ADC_TRIGGER_EXTERNAL    0x00000004  // External event
#define ADC_TRIGGER_TIMER       0x00000005  // Timer event
#define ADC_TRIGGER_PWM0        0x00000006  // PWM0 event
#define ADC_TRIGGER_PWM1        0x00000007  // PWM1 event
#define ADC_TRIGGER_PWM2        0x00000008  // PWM2 event
#define ADC_TRIGGER_PWM3        0x00000009  // PWM3 event
#define ADC_TRIGGER_NEVER       0x0000000E  // Never Trigger
#define ADC_TRIGGER_ALWAYS      0x0000000F  // Always event

//*****************************************************************************
//
// Values that can be passed to ADCSequenceStepConfigure as the ui32Config
// parameter.
//
//*****************************************************************************
#define ADC_CTL_TS              0x00000080  // Temperature sensor select
#define ADC_CTL_IE              0x00000040  // Interrupt enable
#define ADC_CTL_END             0x00000020  // Sequence end select
#define ADC_CTL_D               0x00000010  // Differential select
#define ADC_CTL_CH0             0x00000000  // Input channel 0
#define ADC_CTL_CH1             0x00000001  // Input channel 1
#define ADC_CTL_CH2             0x00000002  // Input channel 2
#define ADC_CTL_CH3             0x00000003  // Input channel 3
#define ADC_CTL_CH4             0x00000004  // Input channel 4
#define ADC_CTL_CH5             0x00000005  // Input channel 5
#define ADC_CTL_CH6             0x00000006  // Input channel 6
#define ADC_CTL_CH7             0x00000007  // Input channel 7
#define ADC_CTL_CH8             0x00000008  // Input channel 8
#define ADC_CTL_CH9             0x00000009  // Input channel 9
#define ADC_CTL_CH10            0x0000000A  // Input channel 10
#define ADC_CTL_CH11            0x0000000B  // Input channel 11
#define ADC_CTL_CH12            0x0000000C  // Input channel 12
#define ADC_CTL_CH13            0x0000000D  // Input channel 13
#define ADC_CTL_CH14            0x0000000E  // Input channel 14
#define ADC_CTL_CH15            0x0000000F  // Input channel 15
#define ADC_CTL_CH16            0x00000100  // Input channel 16
#define ADC_CTL_CH17            0x00000101  // Input channel 17
#define ADC_CTL_CH18            0x00000102  // Input channel 18
#define ADC_CTL_CH19            0x00000103  // Input channel 19
#define ADC_CTL_CH20            0x00000104  // Input channel 20
#define ADC_CTL_CH21            0x00000105  // Input channel 21
#define ADC_CTL_CH22            0x00000106  // Input channel 22
#define ADC_CTL_CH23            0x00000107  // Input channel 23
#define ADC_CTL_CMP0            0x00080000  // Select Comparator 0
#define ADC_CTL_CMP1            0x00090000  // Select Comparator 1
#define ADC_CTL_CMP2            0x000A0000  // Select Comparator 2
#define ADC_CTL_CMP3            0x000B0000  // Select Comparator 3
#define ADC_CTL_CMP4            0x000C0000  // Select Comparator 4
#define ADC_CTL_CMP5            0x000D0000  // Select Comparator 5
#define ADC_CTL_CMP6            0x000E0000  // Select Comparator 6
#define ADC_CTL_CMP7            0x000F0000  // Select Comparator 7

//*****************************************************************************
//
// Values that can be passed to ADCComparatorConfigure as part of the
// ui32Config parameter.
//
//*****************************************************************************
#define ADC_COMP_TRIG_NONE      0x00000000  // Trigger Disabled
#define ADC_COMP_TRIG_LOW_ALWAYS \
                                0x00001000  // Trigger Low Always
#define ADC_COMP_TRIG_LOW_ONCE  0x00001100  // Trigger Low Once
#define ADC_COMP_TRIG_LOW_HALWAYS \
                                0x00001200  // Trigger Low Always (Hysteresis)
#define ADC_COMP_TRIG_LOW_HONCE 0x00001300  // Trigger Low Once (Hysteresis)
#define ADC_COMP_TRIG_MID_ALWAYS \
                                0x00001400  // Trigger Mid Always
#define ADC_COMP_TRIG_MID_ONCE  0x00001500  // Trigger Mid Once
#define ADC_COMP_TRIG_HIGH_ALWAYS \
                                0x00001C00  // Trigger High Always
#define ADC_COMP_TRIG_HIGH_ONCE 0x00001D00  // Trigger High Once
#define ADC_COMP_TRIG_HIGH_HALWAYS \
                                0x00001E00  // Trigger High Always (Hysteresis)
#define ADC_COMP_TRIG_HIGH_HONCE \
                                0x00001F00  // Trigger High Once (Hysteresis)

#define ADC_COMP_INT_NONE       0x00000000  // Interrupt Disabled
#define ADC_COMP_INT_LOW_ALWAYS \
                                0x00000010  // Interrupt Low Always
#define ADC_COMP_INT_LOW_ONCE   0x00000011  // Interrupt Low Once
#define ADC_COMP_INT_LOW_HALWAYS \
                                0x00000012  // Interrupt Low Always
                                            // (Hysteresis)
#define ADC_COMP_INT_LOW_HONCE  0x00000013  // Interrupt Low Once (Hysteresis)
#define ADC_COMP_INT_MID_ALWAYS \
                                0x00000014  // Interrupt Mid Always
#define ADC_COMP_INT_MID_ONCE   0x00000015  // Interrupt Mid Once
#define ADC_COMP_INT_HIGH_ALWAYS \
                                0x0000001C  // Interrupt High Always
#define ADC_COMP_INT_HIGH_ONCE  0x0000001D  // Interrupt High Once
#define ADC_COMP_INT_HIGH_HALWAYS \
                                0x0000001E  // Interrupt High Always
                                            // (Hysteresis)
#define ADC_COMP_INT_HIGH_HONCE \
                                0x0000001F  // Interrupt High Once (Hysteresis)

//*****************************************************************************
//
// Values that can be used to modify the sequence number passed to
// ADCProcessorTrigger in order to get cross-module synchronous processor
// triggers.
//
//*****************************************************************************
#define ADC_TRIGGER_WAIT        0x08000000  // Wait for the synchronous trigger
#define ADC_TRIGGER_SIGNAL      0x80000000  // Signal the synchronous trigger

//*****************************************************************************
//
// Values that can be passed to ADCPhaseDelaySet as the ui32Phase parameter and
// returned from ADCPhaseDelayGet.
//
//*****************************************************************************
#define ADC_PHASE_0             0x00000000  // 0 degrees
#define ADC_PHASE_22_5          0x00000001  // 22.5 degrees
#define ADC_PHASE_45            0x00000002  // 45 degrees
#define ADC_PHASE_67_5          0x00000003  // 67.5 degrees
#define ADC_PHASE_90            0x00000004  // 90 degrees
#define ADC_PHASE_112_5         0x00000005  // 112.5 degrees
#define ADC_PHASE_135           0x00000006  // 135 degrees
#define ADC_PHASE_157_5         0x00000007  // 157.5 degrees
#define ADC_PHASE_180           0x00000008  // 180 degrees
#define ADC_PHASE_202_5         0x00000009  // 202.5 degrees
#define ADC_PHASE_225           0x0000000A  // 225 degrees
#define ADC_PHASE_247_5         0x0000000B  // 247.5 degrees
#define ADC_PHASE_270           0x0000000C  // 270 degrees
#define ADC_PHASE_292_5         0x0000000D  // 292.5 degrees
#define ADC_PHASE_315           0x0000000E  // 315 degrees
#define ADC_PHASE_337_5         0x0000000F  // 337.5 degrees

//*****************************************************************************
//
// Values that can be passed to ADCReferenceSet as the ui32Ref parameter.
//
//*****************************************************************************
#define ADC_REF_INT             0x00000000  // Internal reference
#define ADC_REF_EXT_3V          0x00000001  // External 3V reference
#define ADC_REF_EXT_1V          0x00000003  // External 1V reference

//*****************************************************************************
//
// Values that can be passed to ADCIntDisableEx(), ADCIntEnableEx(),
// ADCIntClearEx() and ADCIntStatusEx().
//
//*****************************************************************************
#define ADC_INT_SS0             0x00000001
#define ADC_INT_SS1             0x00000002
#define ADC_INT_SS2             0x00000004
#define ADC_INT_SS3             0x00000008
#define ADC_INT_DMA_SS0         0x00000100
#define ADC_INT_DMA_SS1         0x00000200
#define ADC_INT_DMA_SS2         0x00000400
#define ADC_INT_DMA_SS3         0x00000800
#define ADC_INT_DCON_SS0        0x00010000
#define ADC_INT_DCON_SS1        0x00020000
#define ADC_INT_DCON_SS2        0x00040000
#define ADC_INT_DCON_SS3        0x00080000


//*****************************************************************************
//
// The following are defines for the ADC register offsets.
//
//*****************************************************************************
#define ADC_O_ACTSS             0x00000000  // ADC Active Sample Sequencer
#define ADC_O_RIS               0x00000004  // ADC Raw Interrupt Status
#define ADC_O_IM                0x00000008  // ADC Interrupt Mask
#define ADC_O_ISC               0x0000000C  // ADC Interrupt Status and Clear
#define ADC_O_OSTAT             0x00000010  // ADC Overflow Status
#define ADC_O_EMUX              0x00000014  // ADC Event Multiplexer Select
#define ADC_O_USTAT             0x00000018  // ADC Underflow Status
#define ADC_O_TSSEL             0x0000001C  // ADC Trigger Source Select
#define ADC_O_SSPRI             0x00000020  // ADC Sample Sequencer Priority
#define ADC_O_SPC               0x00000024  // ADC Sample Phase Control
#define ADC_O_PSSI              0x00000028  // ADC Processor Sample Sequence
                                            // Initiate
#define ADC_O_SAC               0x00000030  // ADC Sample Averaging Control
#define ADC_O_DCISC             0x00000034  // ADC Digital Comparator Interrupt
                                            // Status and Clear
#define ADC_O_CTL               0x00000038  // ADC Control
#define ADC_O_SSMUX0            0x00000040  // ADC Sample Sequence Input
                                            // Multiplexer Select 0
#define ADC_O_SSCTL0            0x00000044  // ADC Sample Sequence Control 0
#define ADC_O_SSFIFO0           0x00000048  // ADC Sample Sequence Result FIFO
                                            // 0
#define ADC_O_SSFSTAT0          0x0000004C  // ADC Sample Sequence FIFO 0
                                            // Status
#define ADC_O_SSOP0             0x00000050  // ADC Sample Sequence 0 Operation
#define ADC_O_SSDC0             0x00000054  // ADC Sample Sequence 0 Digital
                                            // Comparator Select
#define ADC_O_SSEMUX0           0x00000058  // ADC Sample Sequence Extended
                                            // Input Multiplexer Select 0
#define ADC_O_SSTSH0            0x0000005C  // ADC Sample Sequence 0 Sample and
                                            // Hold Time
#define ADC_O_SSMUX1            0x00000060  // ADC Sample Sequence Input
                                            // Multiplexer Select 1
#define ADC_O_SSCTL1            0x00000064  // ADC Sample Sequence Control 1
#define ADC_O_SSFIFO1           0x00000068  // ADC Sample Sequence Result FIFO
                                            // 1
#define ADC_O_SSFSTAT1          0x0000006C  // ADC Sample Sequence FIFO 1
                                            // Status
#define ADC_O_SSOP1             0x00000070  // ADC Sample Sequence 1 Operation
#define ADC_O_SSDC1             0x00000074  // ADC Sample Sequence 1 Digital
                                            // Comparator Select
#define ADC_O_SSEMUX1           0x00000078  // ADC Sample Sequence Extended
                                            // Input Multiplexer Select 1
#define ADC_O_SSTSH1            0x0000007C  // ADC Sample Sequence 1 Sample and
                                            // Hold Time
#define ADC_O_SSMUX2            0x00000080  // ADC Sample Sequence Input
                                            // Multiplexer Select 2
#define ADC_O_SSCTL2            0x00000084  // ADC Sample Sequence Control 2
#define ADC_O_SSFIFO2           0x00000088  // ADC Sample Sequence Result FIFO
                                            // 2
#define ADC_O_SSFSTAT2          0x0000008C  // ADC Sample Sequence FIFO 2
                                            // Status
#define ADC_O_SSOP2             0x00000090  // ADC Sample Sequence 2 Operation
#define ADC_O_SSDC2             0x00000094  // ADC Sample Sequence 2 Digital
                                            // Comparator Select
#define ADC_O_SSEMUX2           0x00000098  // ADC Sample Sequence Extended
                                            // Input Multiplexer Select 2
#define ADC_O_SSTSH2            0x0000009C  // ADC Sample Sequence 2 Sample and
                                            // Hold Time
#define ADC_O_SSMUX3            0x000000A0  // ADC Sample Sequence Input
                                            // Multiplexer Select 3
#define ADC_O_SSCTL3            0x000000A4  // ADC Sample Sequence Control 3
#define ADC_O_SSFIFO3           0x000000A8  // ADC Sample Sequence Result FIFO
                                            // 3
#define ADC_O_SSFSTAT3          0x000000AC  // ADC Sample Sequence FIFO 3
                                            // Status
#define ADC_O_SSOP3             0x000000B0  // ADC Sample Sequence 3 Operation
#define ADC_O_SSDC3             0x000000B4  // ADC Sample Sequence 3 Digital
                                            // Comparator Select
#define ADC_O_SSEMUX3           0x000000B8  // ADC Sample Sequence Extended
                                            // Input Multiplexer Select 3
#define ADC_O_SSTSH3            0x000000BC  // ADC Sample Sequence 3 Sample and
                                            // Hold Time
#define ADC_O_DCRIC             0x00000D00  // ADC Digital Comparator Reset
                                            // Initial Conditions
#define ADC_O_DCCTL0            0x00000E00  // ADC Digital Comparator Control 0
#define ADC_O_DCCTL1            0x00000E04  // ADC Digital Comparator Control 1
#define ADC_O_DCCTL2            0x00000E08  // ADC Digital Comparator Control 2
#define ADC_O_DCCTL3            0x00000E0C  // ADC Digital Comparator Control 3
#define ADC_O_DCCTL4            0x00000E10  // ADC Digital Comparator Control 4
#define ADC_O_DCCTL5            0x00000E14  // ADC Digital Comparator Control 5
#define ADC_O_DCCTL6            0x00000E18  // ADC Digital Comparator Control 6
#define ADC_O_DCCTL7            0x00000E1C  // ADC Digital Comparator Control 7
#define ADC_O_DCCMP0            0x00000E40  // ADC Digital Comparator Range 0
#define ADC_O_DCCMP1            0x00000E44  // ADC Digital Comparator Range 1
#define ADC_O_DCCMP2            0x00000E48  // ADC Digital Comparator Range 2
#define ADC_O_DCCMP3            0x00000E4C  // ADC Digital Comparator Range 3
#define ADC_O_DCCMP4            0x00000E50  // ADC Digital Comparator Range 4
#define ADC_O_DCCMP5            0x00000E54  // ADC Digital Comparator Range 5
#define ADC_O_DCCMP6            0x00000E58  // ADC Digital Comparator Range 6
#define ADC_O_DCCMP7            0x00000E5C  // ADC Digital Comparator Range 7
#define ADC_O_PP                0x00000FC0  // ADC Peripheral Properties
#define ADC_O_PC                0x00000FC4  // ADC Peripheral Configuration
#define ADC_O_CC                0x00000FC8  // ADC Clock Configuration

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_ACTSS register.
//
//*****************************************************************************
#define ADC_ACTSS_BUSY          0x00010000  // ADC Busy
#define ADC_ACTSS_ADEN3         0x00000800  // ADC SS3 DMA Enable
#define ADC_ACTSS_ADEN2         0x00000400  // ADC SS2 DMA Enable
#define ADC_ACTSS_ADEN1         0x00000200  // ADC SS1 DMA Enable
#define ADC_ACTSS_ADEN0         0x00000100  // ADC SS1 DMA Enable
#define ADC_ACTSS_ASEN3         0x00000008  // ADC SS3 Enable
#define ADC_ACTSS_ASEN2         0x00000004  // ADC SS2 Enable
#define ADC_ACTSS_ASEN1         0x00000002  // ADC SS1 Enable
#define ADC_ACTSS_ASEN0         0x00000001  // ADC SS0 Enable

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_RIS register.
//
//*****************************************************************************
#define ADC_RIS_INRDC           0x00010000  // Digital Comparator Raw Interrupt
                                            // Status
#define ADC_RIS_DMAINR3         0x00000800  // SS3 DMA Raw Interrupt Status
#define ADC_RIS_DMAINR2         0x00000400  // SS2 DMA Raw Interrupt Status
#define ADC_RIS_DMAINR1         0x00000200  // SS1 DMA Raw Interrupt Status
#define ADC_RIS_DMAINR0         0x00000100  // SS0 DMA Raw Interrupt Status
#define ADC_RIS_INR3            0x00000008  // SS3 Raw Interrupt Status
#define ADC_RIS_INR2            0x00000004  // SS2 Raw Interrupt Status
#define ADC_RIS_INR1            0x00000002  // SS1 Raw Interrupt Status
#define ADC_RIS_INR0            0x00000001  // SS0 Raw Interrupt Status

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_IM register.
//
//*****************************************************************************
#define ADC_IM_DCONSS3          0x00080000  // Digital Comparator Interrupt on
                                            // SS3
#define ADC_IM_DCONSS2          0x00040000  // Digital Comparator Interrupt on
                                            // SS2
#define ADC_IM_DCONSS1          0x00020000  // Digital Comparator Interrupt on
                                            // SS1
#define ADC_IM_DCONSS0          0x00010000  // Digital Comparator Interrupt on
                                            // SS0
#define ADC_IM_DMAMASK3         0x00000800  // SS3 DMA Interrupt Mask
#define ADC_IM_DMAMASK2         0x00000400  // SS2 DMA Interrupt Mask
#define ADC_IM_DMAMASK1         0x00000200  // SS1 DMA Interrupt Mask
#define ADC_IM_DMAMASK0         0x00000100  // SS0 DMA Interrupt Mask
#define ADC_IM_MASK3            0x00000008  // SS3 Interrupt Mask
#define ADC_IM_MASK2            0x00000004  // SS2 Interrupt Mask
#define ADC_IM_MASK1            0x00000002  // SS1 Interrupt Mask
#define ADC_IM_MASK0            0x00000001  // SS0 Interrupt Mask

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_ISC register.
//
//*****************************************************************************
#define ADC_ISC_DCINSS3         0x00080000  // Digital Comparator Interrupt
                                            // Status on SS3
#define ADC_ISC_DCINSS2         0x00040000  // Digital Comparator Interrupt
                                            // Status on SS2
#define ADC_ISC_DCINSS1         0x00020000  // Digital Comparator Interrupt
                                            // Status on SS1
#define ADC_ISC_DCINSS0         0x00010000  // Digital Comparator Interrupt
                                            // Status on SS0
#define ADC_ISC_DMAIN3          0x00000800  // SS3 DMA Interrupt Status and
                                            // Clear
#define ADC_ISC_DMAIN2          0x00000400  // SS2 DMA Interrupt Status and
                                            // Clear
#define ADC_ISC_DMAIN1          0x00000200  // SS1 DMA Interrupt Status and
                                            // Clear
#define ADC_ISC_DMAIN0          0x00000100  // SS0 DMA Interrupt Status and
                                            // Clear
#define ADC_ISC_IN3             0x00000008  // SS3 Interrupt Status and Clear
#define ADC_ISC_IN2             0x00000004  // SS2 Interrupt Status and Clear
#define ADC_ISC_IN1             0x00000002  // SS1 Interrupt Status and Clear
#define ADC_ISC_IN0             0x00000001  // SS0 Interrupt Status and Clear

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_OSTAT register.
//
//*****************************************************************************
#define ADC_OSTAT_OV3           0x00000008  // SS3 FIFO Overflow
#define ADC_OSTAT_OV2           0x00000004  // SS2 FIFO Overflow
#define ADC_OSTAT_OV1           0x00000002  // SS1 FIFO Overflow
#define ADC_OSTAT_OV0           0x00000001  // SS0 FIFO Overflow

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_EMUX register.
//
//*****************************************************************************
#define ADC_EMUX_EM3_M          0x0000F000  // SS3 Trigger Select
#define ADC_EMUX_EM3_PROCESSOR  0x00000000  // Processor (default)
#define ADC_EMUX_EM3_COMP0      0x00001000  // Analog Comparator 0
#define ADC_EMUX_EM3_COMP1      0x00002000  // Analog Comparator 1
#define ADC_EMUX_EM3_COMP2      0x00003000  // Analog Comparator 2
#define ADC_EMUX_EM3_EXTERNAL   0x00004000  // External (GPIO PB4)
#define ADC_EMUX_EM3_TIMER      0x00005000  // Timer
#define ADC_EMUX_EM3_PWM0       0x00006000  // PWM0
#define ADC_EMUX_EM3_PWM1       0x00007000  // PWM1
#define ADC_EMUX_EM3_PWM2       0x00008000  // PWM2
#define ADC_EMUX_EM3_PWM3       0x00009000  // PWM3
#define ADC_EMUX_EM3_NEVER      0x0000E000  // Never Trigger
#define ADC_EMUX_EM3_ALWAYS     0x0000F000  // Always (continuously sample)
#define ADC_EMUX_EM2_M          0x00000F00  // SS2 Trigger Select
#define ADC_EMUX_EM2_PROCESSOR  0x00000000  // Processor (default)
#define ADC_EMUX_EM2_COMP0      0x00000100  // Analog Comparator 0
#define ADC_EMUX_EM2_COMP1      0x00000200  // Analog Comparator 1
#define ADC_EMUX_EM2_COMP2      0x00000300  // Analog Comparator 2
#define ADC_EMUX_EM2_EXTERNAL   0x00000400  // External (GPIO PB4)
#define ADC_EMUX_EM2_TIMER      0x00000500  // Timer
#define ADC_EMUX_EM2_PWM0       0x00000600  // PWM0
#define ADC_EMUX_EM2_PWM1       0x00000700  // PWM1
#define ADC_EMUX_EM2_PWM2       0x00000800  // PWM2
#define ADC_EMUX_EM2_PWM3       0x00000900  // PWM3
#define ADC_EMUX_EM2_NEVER      0x00000E00  // Never Trigger
#define ADC_EMUX_EM2_ALWAYS     0x00000F00  // Always (continuously sample)
#define ADC_EMUX_EM1_M          0x000000F0  // SS1 Trigger Select
#define ADC_EMUX_EM1_PROCESSOR  0x00000000  // Processor (default)
#define ADC_EMUX_EM1_COMP0      0x00000010  // Analog Comparator 0
#define ADC_EMUX_EM1_COMP1      0x00000020  // Analog Comparator 1
#define ADC_EMUX_EM1_COMP2      0x00000030  // Analog Comparator 2
#define ADC_EMUX_EM1_EXTERNAL   0x00000040  // External (GPIO PB4)
#define ADC_EMUX_EM1_TIMER      0x00000050  // Timer
#define ADC_EMUX_EM1_PWM0       0x00000060  // PWM0
#define ADC_EMUX_EM1_PWM1       0x00000070  // PWM1
#define ADC_EMUX_EM1_PWM2       0x00000080  // PWM2
#define ADC_EMUX_EM1_PWM3       0x00000090  // PWM3
#define ADC_EMUX_EM1_NEVER      0x000000E0  // Never Trigger
#define ADC_EMUX_EM1_ALWAYS     0x000000F0  // Always (continuously sample)
#define ADC_EMUX_EM0_M          0x0000000F  // SS0 Trigger Select
#define ADC_EMUX_EM0_PROCESSOR  0x00000000  // Processor (default)
#define ADC_EMUX_EM0_COMP0      0x00000001  // Analog Comparator 0
#define ADC_EMUX_EM0_COMP1      0x00000002  // Analog Comparator 1
#define ADC_EMUX_EM0_COMP2      0x00000003  // Analog Comparator 2
#define ADC_EMUX_EM0_EXTERNAL   0x00000004  // External (GPIO PB4)
#define ADC_EMUX_EM0_TIMER      0x00000005  // Timer
#define ADC_EMUX_EM0_PWM0       0x00000006  // PWM0
#define ADC_EMUX_EM0_PWM1       0x00000007  // PWM1
#define ADC_EMUX_EM0_PWM2       0x00000008  // PWM2
#define ADC_EMUX_EM0_PWM3       0x00000009  // PWM3
#define ADC_EMUX_EM0_NEVER      0x0000000E  // Never Trigger
#define ADC_EMUX_EM0_ALWAYS     0x0000000F  // Always (continuously sample)

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_USTAT register.
//
//*****************************************************************************
#define ADC_USTAT_UV3           0x00000008  // SS3 FIFO Underflow
#define ADC_USTAT_UV2           0x00000004  // SS2 FIFO Underflow
#define ADC_USTAT_UV1           0x00000002  // SS1 FIFO Underflow
#define ADC_USTAT_UV0           0x00000001  // SS0 FIFO Underflow

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_TSSEL register.
//
//*****************************************************************************
#define ADC_TSSEL_PS3_M         0x30000000  // PWM Unit Select
#define ADC_TSSEL_PS3_0         0x00000000  // PWM Unit 0
#define ADC_TSSEL_PS3_1         0x10000000  // PWM Unit 1
#define ADC_TSSEL_PS2_M         0x00300000  // PWM Unit Select
#define ADC_TSSEL_PS2_0         0x00000000  // PWM Unit 0
#define ADC_TSSEL_PS2_1         0x00100000  // PWM Unit 1
#define ADC_TSSEL_PS1_M         0x00003000  // PWM Unit Select
#define ADC_TSSEL_PS1_0         0x00000000  // PWM Unit 0
#define ADC_TSSEL_PS1_1         0x00001000  // PWM Unit 1
#define ADC_TSSEL_PS0_M         0x00000030  // PWM Unit Select
#define ADC_TSSEL_PS0_0         0x00000000  // PWM Unit 0
#define ADC_TSSEL_PS0_1         0x00000010  // PWM Unit 1

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSPRI register.
//
//*****************************************************************************
#define ADC_SSPRI_SS3_M         0x00003000  // SS3 Priority
#define ADC_SSPRI_SS2_M         0x00000300  // SS2 Priority
#define ADC_SSPRI_SS1_M         0x00000030  // SS1 Priority
#define ADC_SSPRI_SS0_M         0x00000003  // SS0 Priority

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SPC register.
//
//*****************************************************************************
#define ADC_SPC_PHASE_M         0x0000000F  // Phase Difference
#define ADC_SPC_PHASE_0         0x00000000  // ADC sample lags by 0.0
#define ADC_SPC_PHASE_22_5      0x00000001  // ADC sample lags by 22.5
#define ADC_SPC_PHASE_45        0x00000002  // ADC sample lags by 45.0
#define ADC_SPC_PHASE_67_5      0x00000003  // ADC sample lags by 67.5
#define ADC_SPC_PHASE_90        0x00000004  // ADC sample lags by 90.0
#define ADC_SPC_PHASE_112_5     0x00000005  // ADC sample lags by 112.5
#define ADC_SPC_PHASE_135       0x00000006  // ADC sample lags by 135.0
#define ADC_SPC_PHASE_157_5     0x00000007  // ADC sample lags by 157.5
#define ADC_SPC_PHASE_180       0x00000008  // ADC sample lags by 180.0
#define ADC_SPC_PHASE_202_5     0x00000009  // ADC sample lags by 202.5
#define ADC_SPC_PHASE_225       0x0000000A  // ADC sample lags by 225.0
#define ADC_SPC_PHASE_247_5     0x0000000B  // ADC sample lags by 247.5
#define ADC_SPC_PHASE_270       0x0000000C  // ADC sample lags by 270.0
#define ADC_SPC_PHASE_292_5     0x0000000D  // ADC sample lags by 292.5
#define ADC_SPC_PHASE_315       0x0000000E  // ADC sample lags by 315.0
#define ADC_SPC_PHASE_337_5     0x0000000F  // ADC sample lags by 337.5

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_PSSI register.
//
//*****************************************************************************
#define ADC_PSSI_GSYNC          0x80000000  // Global Synchronize
#define ADC_PSSI_SYNCWAIT       0x08000000  // Synchronize Wait
#define ADC_PSSI_SS3            0x00000008  // SS3 Initiate
#define ADC_PSSI_SS2            0x00000004  // SS2 Initiate
#define ADC_PSSI_SS1            0x00000002  // SS1 Initiate
#define ADC_PSSI_SS0            0x00000001  // SS0 Initiate

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SAC register.
//
//*****************************************************************************
#define ADC_SAC_AVG_M           0x00000007  // Hardware Averaging Control
#define ADC_SAC_AVG_OFF         0x00000000  // No hardware oversampling
#define ADC_SAC_AVG_2X          0x00000001  // 2x hardware oversampling
#define ADC_SAC_AVG_4X          0x00000002  // 4x hardware oversampling
#define ADC_SAC_AVG_8X          0x00000003  // 8x hardware oversampling
#define ADC_SAC_AVG_16X         0x00000004  // 16x hardware oversampling
#define ADC_SAC_AVG_32X         0x00000005  // 32x hardware oversampling
#define ADC_SAC_AVG_64X         0x00000006  // 64x hardware oversampling

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCISC register.
//
//*****************************************************************************
#define ADC_DCISC_DCINT7        0x00000080  // Digital Comparator 7 Interrupt
                                            // Status and Clear
#define ADC_DCISC_DCINT6        0x00000040  // Digital Comparator 6 Interrupt
                                            // Status and Clear
#define ADC_DCISC_DCINT5        0x00000020  // Digital Comparator 5 Interrupt
                                            // Status and Clear
#define ADC_DCISC_DCINT4        0x00000010  // Digital Comparator 4 Interrupt
                                            // Status and Clear
#define ADC_DCISC_DCINT3        0x00000008  // Digital Comparator 3 Interrupt
                                            // Status and Clear
#define ADC_DCISC_DCINT2        0x00000004  // Digital Comparator 2 Interrupt
                                            // Status and Clear
#define ADC_DCISC_DCINT1        0x00000002  // Digital Comparator 1 Interrupt
                                            // Status and Clear
#define ADC_DCISC_DCINT0        0x00000001  // Digital Comparator 0 Interrupt
                                            // Status and Clear

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_CTL register.
//
//*****************************************************************************
#define ADC_CTL_DITHER          0x00000040  // Dither Mode Enable
#define ADC_CTL_VREF_M          0x00000003  // Voltage Reference Select
#define ADC_CTL_VREF_INTERNAL   0x00000000  // The internal reference as the
                                            // voltage reference
#define ADC_CTL_VREF_EXT_3V     0x00000001  // A 3.0 V external VREFA input is
                                            // the voltage reference. The ADC
                                            // conversion range is 0.0 V to the
                                            // external reference value

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSMUX0 register.
//
//*****************************************************************************
#define ADC_SSMUX0_MUX7_M       0xF0000000  // 8th Sample Input Select
#define ADC_SSMUX0_MUX6_M       0x0F000000  // 7th Sample Input Select
#define ADC_SSMUX0_MUX5_M       0x00F00000  // 6th Sample Input Select
#define ADC_SSMUX0_MUX4_M       0x000F0000  // 5th Sample Input Select
#define ADC_SSMUX0_MUX3_M       0x0000F000  // 4th Sample Input Select
#define ADC_SSMUX0_MUX2_M       0x00000F00  // 3rd Sample Input Select
#define ADC_SSMUX0_MUX1_M       0x000000F0  // 2nd Sample Input Select
#define ADC_SSMUX0_MUX0_M       0x0000000F  // 1st Sample Input Select
#define ADC_SSMUX0_MUX7_S       28
#define ADC_SSMUX0_MUX6_S       24
#define ADC_SSMUX0_MUX5_S       20
#define ADC_SSMUX0_MUX4_S       16
#define ADC_SSMUX0_MUX3_S       12
#define ADC_SSMUX0_MUX2_S       8
#define ADC_SSMUX0_MUX1_S       4
#define ADC_SSMUX0_MUX0_S       0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSCTL0 register.
//
//*****************************************************************************
#define ADC_SSCTL0_TS7          0x80000000  // 8th Sample Temp Sensor Select
#define ADC_SSCTL0_IE7          0x40000000  // 8th Sample Interrupt Enable
#define ADC_SSCTL0_END7         0x20000000  // 8th Sample is End of Sequence
#define ADC_SSCTL0_D7           0x10000000  // 8th Sample Diff Input Select
#define ADC_SSCTL0_TS6          0x08000000  // 7th Sample Temp Sensor Select
#define ADC_SSCTL0_IE6          0x04000000  // 7th Sample Interrupt Enable
#define ADC_SSCTL0_END6         0x02000000  // 7th Sample is End of Sequence
#define ADC_SSCTL0_D6           0x01000000  // 7th Sample Diff Input Select
#define ADC_SSCTL0_TS5          0x00800000  // 6th Sample Temp Sensor Select
#define ADC_SSCTL0_IE5          0x00400000  // 6th Sample Interrupt Enable
#define ADC_SSCTL0_END5         0x00200000  // 6th Sample is End of Sequence
#define ADC_SSCTL0_D5           0x00100000  // 6th Sample Diff Input Select
#define ADC_SSCTL0_TS4          0x00080000  // 5th Sample Temp Sensor Select
#define ADC_SSCTL0_IE4          0x00040000  // 5th Sample Interrupt Enable
#define ADC_SSCTL0_END4         0x00020000  // 5th Sample is End of Sequence
#define ADC_SSCTL0_D4           0x00010000  // 5th Sample Diff Input Select
#define ADC_SSCTL0_TS3          0x00008000  // 4th Sample Temp Sensor Select
#define ADC_SSCTL0_IE3          0x00004000  // 4th Sample Interrupt Enable
#define ADC_SSCTL0_END3         0x00002000  // 4th Sample is End of Sequence
#define ADC_SSCTL0_D3           0x00001000  // 4th Sample Diff Input Select
#define ADC_SSCTL0_TS2          0x00000800  // 3rd Sample Temp Sensor Select
#define ADC_SSCTL0_IE2          0x00000400  // 3rd Sample Interrupt Enable
#define ADC_SSCTL0_END2         0x00000200  // 3rd Sample is End of Sequence
#define ADC_SSCTL0_D2           0x00000100  // 3rd Sample Diff Input Select
#define ADC_SSCTL0_TS1          0x00000080  // 2nd Sample Temp Sensor Select
#define ADC_SSCTL0_IE1          0x00000040  // 2nd Sample Interrupt Enable
#define ADC_SSCTL0_END1         0x00000020  // 2nd Sample is End of Sequence
#define ADC_SSCTL0_D1           0x00000010  // 2nd Sample Diff Input Select
#define ADC_SSCTL0_TS0          0x00000008  // 1st Sample Temp Sensor Select
#define ADC_SSCTL0_IE0          0x00000004  // 1st Sample Interrupt Enable
#define ADC_SSCTL0_END0         0x00000002  // 1st Sample is End of Sequence
#define ADC_SSCTL0_D0           0x00000001  // 1st Sample Diff Input Select

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSFIFO0 register.
//
//*****************************************************************************
#define ADC_SSFIFO0_DATA_M      0x00000FFF  // Conversion Result Data
#define ADC_SSFIFO0_DATA_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSFSTAT0 register.
//
//*****************************************************************************
#define ADC_SSFSTAT0_FULL       0x00001000  // FIFO Full
#define ADC_SSFSTAT0_EMPTY      0x00000100  // FIFO Empty
#define ADC_SSFSTAT0_HPTR_M     0x000000F0  // FIFO Head Pointer
#define ADC_SSFSTAT0_TPTR_M     0x0000000F  // FIFO Tail Pointer
#define ADC_SSFSTAT0_HPTR_S     4
#define ADC_SSFSTAT0_TPTR_S     0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSOP0 register.
//
//*****************************************************************************
#define ADC_SSOP0_S7DCOP        0x10000000  // Sample 7 Digital Comparator
                                            // Operation
#define ADC_SSOP0_S6DCOP        0x01000000  // Sample 6 Digital Comparator
                                            // Operation
#define ADC_SSOP0_S5DCOP        0x00100000  // Sample 5 Digital Comparator
                                            // Operation
#define ADC_SSOP0_S4DCOP        0x00010000  // Sample 4 Digital Comparator
                                            // Operation
#define ADC_SSOP0_S3DCOP        0x00001000  // Sample 3 Digital Comparator
                                            // Operation
#define ADC_SSOP0_S2DCOP        0x00000100  // Sample 2 Digital Comparator
                                            // Operation
#define ADC_SSOP0_S1DCOP        0x00000010  // Sample 1 Digital Comparator
                                            // Operation
#define ADC_SSOP0_S0DCOP        0x00000001  // Sample 0 Digital Comparator
                                            // Operation

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSDC0 register.
//
//*****************************************************************************
#define ADC_SSDC0_S7DCSEL_M     0xF0000000  // Sample 7 Digital Comparator
                                            // Select
#define ADC_SSDC0_S6DCSEL_M     0x0F000000  // Sample 6 Digital Comparator
                                            // Select
#define ADC_SSDC0_S5DCSEL_M     0x00F00000  // Sample 5 Digital Comparator
                                            // Select
#define ADC_SSDC0_S4DCSEL_M     0x000F0000  // Sample 4 Digital Comparator
                                            // Select
#define ADC_SSDC0_S3DCSEL_M     0x0000F000  // Sample 3 Digital Comparator
                                            // Select
#define ADC_SSDC0_S2DCSEL_M     0x00000F00  // Sample 2 Digital Comparator
                                            // Select
#define ADC_SSDC0_S1DCSEL_M     0x000000F0  // Sample 1 Digital Comparator
                                            // Select
#define ADC_SSDC0_S0DCSEL_M     0x0000000F  // Sample 0 Digital Comparator
                                            // Select
#define ADC_SSDC0_S6DCSEL_S     24
#define ADC_SSDC0_S5DCSEL_S     20
#define ADC_SSDC0_S4DCSEL_S     16
#define ADC_SSDC0_S3DCSEL_S     12
#define ADC_SSDC0_S2DCSEL_S     8
#define ADC_SSDC0_S1DCSEL_S     4
#define ADC_SSDC0_S0DCSEL_S     0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSEMUX0 register.
//
//*****************************************************************************
#define ADC_SSEMUX0_EMUX7       0x10000000  // 8th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX0_EMUX6       0x01000000  // 7th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX0_EMUX5       0x00100000  // 6th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX0_EMUX4       0x00010000  // 5th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX0_EMUX3       0x00001000  // 4th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX0_EMUX2       0x00000100  // 3rd Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX0_EMUX1       0x00000010  // 2th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX0_EMUX0       0x00000001  // 1st Sample Input Select (Upper
                                            // Bit)

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSTSH0 register.
//
//*****************************************************************************
#define ADC_SSTSH0_TSH7_M       0xF0000000  // 8th Sample and Hold Period
                                            // Select
#define ADC_SSTSH0_TSH6_M       0x0F000000  // 7th Sample and Hold Period
                                            // Select
#define ADC_SSTSH0_TSH5_M       0x00F00000  // 6th Sample and Hold Period
                                            // Select
#define ADC_SSTSH0_TSH4_M       0x000F0000  // 5th Sample and Hold Period
                                            // Select
#define ADC_SSTSH0_TSH3_M       0x0000F000  // 4th Sample and Hold Period
                                            // Select
#define ADC_SSTSH0_TSH2_M       0x00000F00  // 3rd Sample and Hold Period
                                            // Select
#define ADC_SSTSH0_TSH1_M       0x000000F0  // 2nd Sample and Hold Period
                                            // Select
#define ADC_SSTSH0_TSH0_M       0x0000000F  // 1st Sample and Hold Period
                                            // Select
#define ADC_SSTSH0_TSH7_S       28
#define ADC_SSTSH0_TSH6_S       24
#define ADC_SSTSH0_TSH5_S       20
#define ADC_SSTSH0_TSH4_S       16
#define ADC_SSTSH0_TSH3_S       12
#define ADC_SSTSH0_TSH2_S       8
#define ADC_SSTSH0_TSH1_S       4
#define ADC_SSTSH0_TSH0_S       0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSMUX1 register.
//
//*****************************************************************************
#define ADC_SSMUX1_MUX3_M       0x0000F000  // 4th Sample Input Select
#define ADC_SSMUX1_MUX2_M       0x00000F00  // 3rd Sample Input Select
#define ADC_SSMUX1_MUX1_M       0x000000F0  // 2nd Sample Input Select
#define ADC_SSMUX1_MUX0_M       0x0000000F  // 1st Sample Input Select
#define ADC_SSMUX1_MUX3_S       12
#define ADC_SSMUX1_MUX2_S       8
#define ADC_SSMUX1_MUX1_S       4
#define ADC_SSMUX1_MUX0_S       0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSCTL1 register.
//
//*****************************************************************************
#define ADC_SSCTL1_TS3          0x00008000  // 4th Sample Temp Sensor Select
#define ADC_SSCTL1_IE3          0x00004000  // 4th Sample Interrupt Enable
#define ADC_SSCTL1_END3         0x00002000  // 4th Sample is End of Sequence
#define ADC_SSCTL1_D3           0x00001000  // 4th Sample Diff Input Select
#define ADC_SSCTL1_TS2          0x00000800  // 3rd Sample Temp Sensor Select
#define ADC_SSCTL1_IE2          0x00000400  // 3rd Sample Interrupt Enable
#define ADC_SSCTL1_END2         0x00000200  // 3rd Sample is End of Sequence
#define ADC_SSCTL1_D2           0x00000100  // 3rd Sample Diff Input Select
#define ADC_SSCTL1_TS1          0x00000080  // 2nd Sample Temp Sensor Select
#define ADC_SSCTL1_IE1          0x00000040  // 2nd Sample Interrupt Enable
#define ADC_SSCTL1_END1         0x00000020  // 2nd Sample is End of Sequence
#define ADC_SSCTL1_D1           0x00000010  // 2nd Sample Diff Input Select
#define ADC_SSCTL1_TS0          0x00000008  // 1st Sample Temp Sensor Select
#define ADC_SSCTL1_IE0          0x00000004  // 1st Sample Interrupt Enable
#define ADC_SSCTL1_END0         0x00000002  // 1st Sample is End of Sequence
#define ADC_SSCTL1_D0           0x00000001  // 1st Sample Diff Input Select

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSFIFO1 register.
//
//*****************************************************************************
#define ADC_SSFIFO1_DATA_M      0x00000FFF  // Conversion Result Data
#define ADC_SSFIFO1_DATA_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSFSTAT1 register.
//
//*****************************************************************************
#define ADC_SSFSTAT1_FULL       0x00001000  // FIFO Full
#define ADC_SSFSTAT1_EMPTY      0x00000100  // FIFO Empty
#define ADC_SSFSTAT1_HPTR_M     0x000000F0  // FIFO Head Pointer
#define ADC_SSFSTAT1_TPTR_M     0x0000000F  // FIFO Tail Pointer
#define ADC_SSFSTAT1_HPTR_S     4
#define ADC_SSFSTAT1_TPTR_S     0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSOP1 register.
//
//*****************************************************************************
#define ADC_SSOP1_S3DCOP        0x00001000  // Sample 3 Digital Comparator
                                            // Operation
#define ADC_SSOP1_S2DCOP        0x00000100  // Sample 2 Digital Comparator
                                            // Operation
#define ADC_SSOP1_S1DCOP        0x00000010  // Sample 1 Digital Comparator
                                            // Operation
#define ADC_SSOP1_S0DCOP        0x00000001  // Sample 0 Digital Comparator
                                            // Operation

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSDC1 register.
//
//*****************************************************************************
#define ADC_SSDC1_S3DCSEL_M     0x0000F000  // Sample 3 Digital Comparator
                                            // Select
#define ADC_SSDC1_S2DCSEL_M     0x00000F00  // Sample 2 Digital Comparator
                                            // Select
#define ADC_SSDC1_S1DCSEL_M     0x000000F0  // Sample 1 Digital Comparator
                                            // Select
#define ADC_SSDC1_S0DCSEL_M     0x0000000F  // Sample 0 Digital Comparator
                                            // Select
#define ADC_SSDC1_S2DCSEL_S     8
#define ADC_SSDC1_S1DCSEL_S     4
#define ADC_SSDC1_S0DCSEL_S     0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSEMUX1 register.
//
//*****************************************************************************
#define ADC_SSEMUX1_EMUX3       0x00001000  // 4th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX1_EMUX2       0x00000100  // 3rd Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX1_EMUX1       0x00000010  // 2th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX1_EMUX0       0x00000001  // 1st Sample Input Select (Upper
                                            // Bit)

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSTSH1 register.
//
//*****************************************************************************
#define ADC_SSTSH1_TSH3_M       0x0000F000  // 4th Sample and Hold Period
                                            // Select
#define ADC_SSTSH1_TSH2_M       0x00000F00  // 3rd Sample and Hold Period
                                            // Select
#define ADC_SSTSH1_TSH1_M       0x000000F0  // 2nd Sample and Hold Period
                                            // Select
#define ADC_SSTSH1_TSH0_M       0x0000000F  // 1st Sample and Hold Period
                                            // Select
#define ADC_SSTSH1_TSH3_S       12
#define ADC_SSTSH1_TSH2_S       8
#define ADC_SSTSH1_TSH1_S       4
#define ADC_SSTSH1_TSH0_S       0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSMUX2 register.
//
//*****************************************************************************
#define ADC_SSMUX2_MUX3_M       0x0000F000  // 4th Sample Input Select
#define ADC_SSMUX2_MUX2_M       0x00000F00  // 3rd Sample Input Select
#define ADC_SSMUX2_MUX1_M       0x000000F0  // 2nd Sample Input Select
#define ADC_SSMUX2_MUX0_M       0x0000000F  // 1st Sample Input Select
#define ADC_SSMUX2_MUX3_S       12
#define ADC_SSMUX2_MUX2_S       8
#define ADC_SSMUX2_MUX1_S       4
#define ADC_SSMUX2_MUX0_S       0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSCTL2 register.
//
//*****************************************************************************
#define ADC_SSCTL2_TS3          0x00008000  // 4th Sample Temp Sensor Select
#define ADC_SSCTL2_IE3          0x00004000  // 4th Sample Interrupt Enable
#define ADC_SSCTL2_END3         0x00002000  // 4th Sample is End of Sequence
#define ADC_SSCTL2_D3           0x00001000  // 4th Sample Diff Input Select
#define ADC_SSCTL2_TS2          0x00000800  // 3rd Sample Temp Sensor Select
#define ADC_SSCTL2_IE2          0x00000400  // 3rd Sample Interrupt Enable
#define ADC_SSCTL2_END2         0x00000200  // 3rd Sample is End of Sequence
#define ADC_SSCTL2_D2           0x00000100  // 3rd Sample Diff Input Select
#define ADC_SSCTL2_TS1          0x00000080  // 2nd Sample Temp Sensor Select
#define ADC_SSCTL2_IE1          0x00000040  // 2nd Sample Interrupt Enable
#define ADC_SSCTL2_END1         0x00000020  // 2nd Sample is End of Sequence
#define ADC_SSCTL2_D1           0x00000010  // 2nd Sample Diff Input Select
#define ADC_SSCTL2_TS0          0x00000008  // 1st Sample Temp Sensor Select
#define ADC_SSCTL2_IE0          0x00000004  // 1st Sample Interrupt Enable
#define ADC_SSCTL2_END0         0x00000002  // 1st Sample is End of Sequence
#define ADC_SSCTL2_D0           0x00000001  // 1st Sample Diff Input Select

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSFIFO2 register.
//
//*****************************************************************************
#define ADC_SSFIFO2_DATA_M      0x00000FFF  // Conversion Result Data
#define ADC_SSFIFO2_DATA_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSFSTAT2 register.
//
//*****************************************************************************
#define ADC_SSFSTAT2_FULL       0x00001000  // FIFO Full
#define ADC_SSFSTAT2_EMPTY      0x00000100  // FIFO Empty
#define ADC_SSFSTAT2_HPTR_M     0x000000F0  // FIFO Head Pointer
#define ADC_SSFSTAT2_TPTR_M     0x0000000F  // FIFO Tail Pointer
#define ADC_SSFSTAT2_HPTR_S     4
#define ADC_SSFSTAT2_TPTR_S     0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSOP2 register.
//
//*****************************************************************************
#define ADC_SSOP2_S3DCOP        0x00001000  // Sample 3 Digital Comparator
                                            // Operation
#define ADC_SSOP2_S2DCOP        0x00000100  // Sample 2 Digital Comparator
                                            // Operation
#define ADC_SSOP2_S1DCOP        0x00000010  // Sample 1 Digital Comparator
                                            // Operation
#define ADC_SSOP2_S0DCOP        0x00000001  // Sample 0 Digital Comparator
                                            // Operation

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSDC2 register.
//
//*****************************************************************************
#define ADC_SSDC2_S3DCSEL_M     0x0000F000  // Sample 3 Digital Comparator
                                            // Select
#define ADC_SSDC2_S2DCSEL_M     0x00000F00  // Sample 2 Digital Comparator
                                            // Select
#define ADC_SSDC2_S1DCSEL_M     0x000000F0  // Sample 1 Digital Comparator
                                            // Select
#define ADC_SSDC2_S0DCSEL_M     0x0000000F  // Sample 0 Digital Comparator
                                            // Select
#define ADC_SSDC2_S2DCSEL_S     8
#define ADC_SSDC2_S1DCSEL_S     4
#define ADC_SSDC2_S0DCSEL_S     0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSEMUX2 register.
//
//*****************************************************************************
#define ADC_SSEMUX2_EMUX3       0x00001000  // 4th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX2_EMUX2       0x00000100  // 3rd Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX2_EMUX1       0x00000010  // 2th Sample Input Select (Upper
                                            // Bit)
#define ADC_SSEMUX2_EMUX0       0x00000001  // 1st Sample Input Select (Upper
                                            // Bit)

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSTSH2 register.
//
//*****************************************************************************
#define ADC_SSTSH2_TSH3_M       0x0000F000  // 4th Sample and Hold Period
                                            // Select
#define ADC_SSTSH2_TSH2_M       0x00000F00  // 3rd Sample and Hold Period
                                            // Select
#define ADC_SSTSH2_TSH1_M       0x000000F0  // 2nd Sample and Hold Period
                                            // Select
#define ADC_SSTSH2_TSH0_M       0x0000000F  // 1st Sample and Hold Period
                                            // Select
#define ADC_SSTSH2_TSH3_S       12
#define ADC_SSTSH2_TSH2_S       8
#define ADC_SSTSH2_TSH1_S       4
#define ADC_SSTSH2_TSH0_S       0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSMUX3 register.
//
//*****************************************************************************
#define ADC_SSMUX3_MUX0_M       0x0000000F  // 1st Sample Input Select
#define ADC_SSMUX3_MUX0_S       0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSCTL3 register.
//
//*****************************************************************************
#define ADC_SSCTL3_TS0          0x00000008  // 1st Sample Temp Sensor Select
#define ADC_SSCTL3_IE0          0x00000004  // 1st Sample Interrupt Enable
#define ADC_SSCTL3_END0         0x00000002  // 1st Sample is End of Sequence
#define ADC_SSCTL3_D0           0x00000001  // 1st Sample Diff Input Select

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSFIFO3 register.
//
//*****************************************************************************
#define ADC_SSFIFO3_DATA_M      0x00000FFF  // Conversion Result Data
#define ADC_SSFIFO3_DATA_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSFSTAT3 register.
//
//*****************************************************************************
#define ADC_SSFSTAT3_FULL       0x00001000  // FIFO Full
#define ADC_SSFSTAT3_EMPTY      0x00000100  // FIFO Empty
#define ADC_SSFSTAT3_HPTR_M     0x000000F0  // FIFO Head Pointer
#define ADC_SSFSTAT3_TPTR_M     0x0000000F  // FIFO Tail Pointer
#define ADC_SSFSTAT3_HPTR_S     4
#define ADC_SSFSTAT3_TPTR_S     0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSOP3 register.
//
//*****************************************************************************
#define ADC_SSOP3_S0DCOP        0x00000001  // Sample 0 Digital Comparator
                                            // Operation

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSDC3 register.
//
//*****************************************************************************
#define ADC_SSDC3_S0DCSEL_M     0x0000000F  // Sample 0 Digital Comparator
                                            // Select

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSEMUX3 register.
//
//*****************************************************************************
#define ADC_SSEMUX3_EMUX0       0x00000001  // 1st Sample Input Select (Upper
                                            // Bit)

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_SSTSH3 register.
//
//*****************************************************************************
#define ADC_SSTSH3_TSH0_M       0x0000000F  // 1st Sample and Hold Period
                                            // Select
#define ADC_SSTSH3_TSH0_S       0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCRIC register.
//
//*****************************************************************************
#define ADC_DCRIC_DCTRIG7       0x00800000  // Digital Comparator Trigger 7
#define ADC_DCRIC_DCTRIG6       0x00400000  // Digital Comparator Trigger 6
#define ADC_DCRIC_DCTRIG5       0x00200000  // Digital Comparator Trigger 5
#define ADC_DCRIC_DCTRIG4       0x00100000  // Digital Comparator Trigger 4
#define ADC_DCRIC_DCTRIG3       0x00080000  // Digital Comparator Trigger 3
#define ADC_DCRIC_DCTRIG2       0x00040000  // Digital Comparator Trigger 2
#define ADC_DCRIC_DCTRIG1       0x00020000  // Digital Comparator Trigger 1
#define ADC_DCRIC_DCTRIG0       0x00010000  // Digital Comparator Trigger 0
#define ADC_DCRIC_DCINT7        0x00000080  // Digital Comparator Interrupt 7
#define ADC_DCRIC_DCINT6        0x00000040  // Digital Comparator Interrupt 6
#define ADC_DCRIC_DCINT5        0x00000020  // Digital Comparator Interrupt 5
#define ADC_DCRIC_DCINT4        0x00000010  // Digital Comparator Interrupt 4
#define ADC_DCRIC_DCINT3        0x00000008  // Digital Comparator Interrupt 3
#define ADC_DCRIC_DCINT2        0x00000004  // Digital Comparator Interrupt 2
#define ADC_DCRIC_DCINT1        0x00000002  // Digital Comparator Interrupt 1
#define ADC_DCRIC_DCINT0        0x00000001  // Digital Comparator Interrupt 0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCTL0 register.
//
//*****************************************************************************
#define ADC_DCCTL0_CTE          0x00001000  // Comparison Trigger Enable
#define ADC_DCCTL0_CTC_M        0x00000C00  // Comparison Trigger Condition
#define ADC_DCCTL0_CTC_LOW      0x00000000  // Low Band
#define ADC_DCCTL0_CTC_MID      0x00000400  // Mid Band
#define ADC_DCCTL0_CTC_HIGH     0x00000C00  // High Band
#define ADC_DCCTL0_CTM_M        0x00000300  // Comparison Trigger Mode
#define ADC_DCCTL0_CTM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL0_CTM_ONCE     0x00000100  // Once
#define ADC_DCCTL0_CTM_HALWAYS  0x00000200  // Hysteresis Always
#define ADC_DCCTL0_CTM_HONCE    0x00000300  // Hysteresis Once
#define ADC_DCCTL0_CIE          0x00000010  // Comparison Interrupt Enable
#define ADC_DCCTL0_CIC_M        0x0000000C  // Comparison Interrupt Condition
#define ADC_DCCTL0_CIC_LOW      0x00000000  // Low Band
#define ADC_DCCTL0_CIC_MID      0x00000004  // Mid Band
#define ADC_DCCTL0_CIC_HIGH     0x0000000C  // High Band
#define ADC_DCCTL0_CIM_M        0x00000003  // Comparison Interrupt Mode
#define ADC_DCCTL0_CIM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL0_CIM_ONCE     0x00000001  // Once
#define ADC_DCCTL0_CIM_HALWAYS  0x00000002  // Hysteresis Always
#define ADC_DCCTL0_CIM_HONCE    0x00000003  // Hysteresis Once

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCTL1 register.
//
//*****************************************************************************
#define ADC_DCCTL1_CTE          0x00001000  // Comparison Trigger Enable
#define ADC_DCCTL1_CTC_M        0x00000C00  // Comparison Trigger Condition
#define ADC_DCCTL1_CTC_LOW      0x00000000  // Low Band
#define ADC_DCCTL1_CTC_MID      0x00000400  // Mid Band
#define ADC_DCCTL1_CTC_HIGH     0x00000C00  // High Band
#define ADC_DCCTL1_CTM_M        0x00000300  // Comparison Trigger Mode
#define ADC_DCCTL1_CTM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL1_CTM_ONCE     0x00000100  // Once
#define ADC_DCCTL1_CTM_HALWAYS  0x00000200  // Hysteresis Always
#define ADC_DCCTL1_CTM_HONCE    0x00000300  // Hysteresis Once
#define ADC_DCCTL1_CIE          0x00000010  // Comparison Interrupt Enable
#define ADC_DCCTL1_CIC_M        0x0000000C  // Comparison Interrupt Condition
#define ADC_DCCTL1_CIC_LOW      0x00000000  // Low Band
#define ADC_DCCTL1_CIC_MID      0x00000004  // Mid Band
#define ADC_DCCTL1_CIC_HIGH     0x0000000C  // High Band
#define ADC_DCCTL1_CIM_M        0x00000003  // Comparison Interrupt Mode
#define ADC_DCCTL1_CIM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL1_CIM_ONCE     0x00000001  // Once
#define ADC_DCCTL1_CIM_HALWAYS  0x00000002  // Hysteresis Always
#define ADC_DCCTL1_CIM_HONCE    0x00000003  // Hysteresis Once

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCTL2 register.
//
//*****************************************************************************
#define ADC_DCCTL2_CTE          0x00001000  // Comparison Trigger Enable
#define ADC_DCCTL2_CTC_M        0x00000C00  // Comparison Trigger Condition
#define ADC_DCCTL2_CTC_LOW      0x00000000  // Low Band
#define ADC_DCCTL2_CTC_MID      0x00000400  // Mid Band
#define ADC_DCCTL2_CTC_HIGH     0x00000C00  // High Band
#define ADC_DCCTL2_CTM_M        0x00000300  // Comparison Trigger Mode
#define ADC_DCCTL2_CTM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL2_CTM_ONCE     0x00000100  // Once
#define ADC_DCCTL2_CTM_HALWAYS  0x00000200  // Hysteresis Always
#define ADC_DCCTL2_CTM_HONCE    0x00000300  // Hysteresis Once
#define ADC_DCCTL2_CIE          0x00000010  // Comparison Interrupt Enable
#define ADC_DCCTL2_CIC_M        0x0000000C  // Comparison Interrupt Condition
#define ADC_DCCTL2_CIC_LOW      0x00000000  // Low Band
#define ADC_DCCTL2_CIC_MID      0x00000004  // Mid Band
#define ADC_DCCTL2_CIC_HIGH     0x0000000C  // High Band
#define ADC_DCCTL2_CIM_M        0x00000003  // Comparison Interrupt Mode
#define ADC_DCCTL2_CIM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL2_CIM_ONCE     0x00000001  // Once
#define ADC_DCCTL2_CIM_HALWAYS  0x00000002  // Hysteresis Always
#define ADC_DCCTL2_CIM_HONCE    0x00000003  // Hysteresis Once

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCTL3 register.
//
//*****************************************************************************
#define ADC_DCCTL3_CTE          0x00001000  // Comparison Trigger Enable
#define ADC_DCCTL3_CTC_M        0x00000C00  // Comparison Trigger Condition
#define ADC_DCCTL3_CTC_LOW      0x00000000  // Low Band
#define ADC_DCCTL3_CTC_MID      0x00000400  // Mid Band
#define ADC_DCCTL3_CTC_HIGH     0x00000C00  // High Band
#define ADC_DCCTL3_CTM_M        0x00000300  // Comparison Trigger Mode
#define ADC_DCCTL3_CTM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL3_CTM_ONCE     0x00000100  // Once
#define ADC_DCCTL3_CTM_HALWAYS  0x00000200  // Hysteresis Always
#define ADC_DCCTL3_CTM_HONCE    0x00000300  // Hysteresis Once
#define ADC_DCCTL3_CIE          0x00000010  // Comparison Interrupt Enable
#define ADC_DCCTL3_CIC_M        0x0000000C  // Comparison Interrupt Condition
#define ADC_DCCTL3_CIC_LOW      0x00000000  // Low Band
#define ADC_DCCTL3_CIC_MID      0x00000004  // Mid Band
#define ADC_DCCTL3_CIC_HIGH     0x0000000C  // High Band
#define ADC_DCCTL3_CIM_M        0x00000003  // Comparison Interrupt Mode
#define ADC_DCCTL3_CIM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL3_CIM_ONCE     0x00000001  // Once
#define ADC_DCCTL3_CIM_HALWAYS  0x00000002  // Hysteresis Always
#define ADC_DCCTL3_CIM_HONCE    0x00000003  // Hysteresis Once

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCTL4 register.
//
//*****************************************************************************
#define ADC_DCCTL4_CTE          0x00001000  // Comparison Trigger Enable
#define ADC_DCCTL4_CTC_M        0x00000C00  // Comparison Trigger Condition
#define ADC_DCCTL4_CTC_LOW      0x00000000  // Low Band
#define ADC_DCCTL4_CTC_MID      0x00000400  // Mid Band
#define ADC_DCCTL4_CTC_HIGH     0x00000C00  // High Band
#define ADC_DCCTL4_CTM_M        0x00000300  // Comparison Trigger Mode
#define ADC_DCCTL4_CTM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL4_CTM_ONCE     0x00000100  // Once
#define ADC_DCCTL4_CTM_HALWAYS  0x00000200  // Hysteresis Always
#define ADC_DCCTL4_CTM_HONCE    0x00000300  // Hysteresis Once
#define ADC_DCCTL4_CIE          0x00000010  // Comparison Interrupt Enable
#define ADC_DCCTL4_CIC_M        0x0000000C  // Comparison Interrupt Condition
#define ADC_DCCTL4_CIC_LOW      0x00000000  // Low Band
#define ADC_DCCTL4_CIC_MID      0x00000004  // Mid Band
#define ADC_DCCTL4_CIC_HIGH     0x0000000C  // High Band
#define ADC_DCCTL4_CIM_M        0x00000003  // Comparison Interrupt Mode
#define ADC_DCCTL4_CIM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL4_CIM_ONCE     0x00000001  // Once
#define ADC_DCCTL4_CIM_HALWAYS  0x00000002  // Hysteresis Always
#define ADC_DCCTL4_CIM_HONCE    0x00000003  // Hysteresis Once

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCTL5 register.
//
//*****************************************************************************
#define ADC_DCCTL5_CTE          0x00001000  // Comparison Trigger Enable
#define ADC_DCCTL5_CTC_M        0x00000C00  // Comparison Trigger Condition
#define ADC_DCCTL5_CTC_LOW      0x00000000  // Low Band
#define ADC_DCCTL5_CTC_MID      0x00000400  // Mid Band
#define ADC_DCCTL5_CTC_HIGH     0x00000C00  // High Band
#define ADC_DCCTL5_CTM_M        0x00000300  // Comparison Trigger Mode
#define ADC_DCCTL5_CTM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL5_CTM_ONCE     0x00000100  // Once
#define ADC_DCCTL5_CTM_HALWAYS  0x00000200  // Hysteresis Always
#define ADC_DCCTL5_CTM_HONCE    0x00000300  // Hysteresis Once
#define ADC_DCCTL5_CIE          0x00000010  // Comparison Interrupt Enable
#define ADC_DCCTL5_CIC_M        0x0000000C  // Comparison Interrupt Condition
#define ADC_DCCTL5_CIC_LOW      0x00000000  // Low Band
#define ADC_DCCTL5_CIC_MID      0x00000004  // Mid Band
#define ADC_DCCTL5_CIC_HIGH     0x0000000C  // High Band
#define ADC_DCCTL5_CIM_M        0x00000003  // Comparison Interrupt Mode
#define ADC_DCCTL5_CIM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL5_CIM_ONCE     0x00000001  // Once
#define ADC_DCCTL5_CIM_HALWAYS  0x00000002  // Hysteresis Always
#define ADC_DCCTL5_CIM_HONCE    0x00000003  // Hysteresis Once

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCTL6 register.
//
//*****************************************************************************
#define ADC_DCCTL6_CTE          0x00001000  // Comparison Trigger Enable
#define ADC_DCCTL6_CTC_M        0x00000C00  // Comparison Trigger Condition
#define ADC_DCCTL6_CTC_LOW      0x00000000  // Low Band
#define ADC_DCCTL6_CTC_MID      0x00000400  // Mid Band
#define ADC_DCCTL6_CTC_HIGH     0x00000C00  // High Band
#define ADC_DCCTL6_CTM_M        0x00000300  // Comparison Trigger Mode
#define ADC_DCCTL6_CTM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL6_CTM_ONCE     0x00000100  // Once
#define ADC_DCCTL6_CTM_HALWAYS  0x00000200  // Hysteresis Always
#define ADC_DCCTL6_CTM_HONCE    0x00000300  // Hysteresis Once
#define ADC_DCCTL6_CIE          0x00000010  // Comparison Interrupt Enable
#define ADC_DCCTL6_CIC_M        0x0000000C  // Comparison Interrupt Condition
#define ADC_DCCTL6_CIC_LOW      0x00000000  // Low Band
#define ADC_DCCTL6_CIC_MID      0x00000004  // Mid Band
#define ADC_DCCTL6_CIC_HIGH     0x0000000C  // High Band
#define ADC_DCCTL6_CIM_M        0x00000003  // Comparison Interrupt Mode
#define ADC_DCCTL6_CIM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL6_CIM_ONCE     0x00000001  // Once
#define ADC_DCCTL6_CIM_HALWAYS  0x00000002  // Hysteresis Always
#define ADC_DCCTL6_CIM_HONCE    0x00000003  // Hysteresis Once

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCTL7 register.
//
//*****************************************************************************
#define ADC_DCCTL7_CTE          0x00001000  // Comparison Trigger Enable
#define ADC_DCCTL7_CTC_M        0x00000C00  // Comparison Trigger Condition
#define ADC_DCCTL7_CTC_LOW      0x00000000  // Low Band
#define ADC_DCCTL7_CTC_MID      0x00000400  // Mid Band
#define ADC_DCCTL7_CTC_HIGH     0x00000C00  // High Band
#define ADC_DCCTL7_CTM_M        0x00000300  // Comparison Trigger Mode
#define ADC_DCCTL7_CTM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL7_CTM_ONCE     0x00000100  // Once
#define ADC_DCCTL7_CTM_HALWAYS  0x00000200  // Hysteresis Always
#define ADC_DCCTL7_CTM_HONCE    0x00000300  // Hysteresis Once
#define ADC_DCCTL7_CIE          0x00000010  // Comparison Interrupt Enable
#define ADC_DCCTL7_CIC_M        0x0000000C  // Comparison Interrupt Condition
#define ADC_DCCTL7_CIC_LOW      0x00000000  // Low Band
#define ADC_DCCTL7_CIC_MID      0x00000004  // Mid Band
#define ADC_DCCTL7_CIC_HIGH     0x0000000C  // High Band
#define ADC_DCCTL7_CIM_M        0x00000003  // Comparison Interrupt Mode
#define ADC_DCCTL7_CIM_ALWAYS   0x00000000  // Always
#define ADC_DCCTL7_CIM_ONCE     0x00000001  // Once
#define ADC_DCCTL7_CIM_HALWAYS  0x00000002  // Hysteresis Always
#define ADC_DCCTL7_CIM_HONCE    0x00000003  // Hysteresis Once

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCMP0 register.
//
//*****************************************************************************
#define ADC_DCCMP0_COMP1_M      0x0FFF0000  // Compare 1
#define ADC_DCCMP0_COMP0_M      0x00000FFF  // Compare 0
#define ADC_DCCMP0_COMP1_S      16
#define ADC_DCCMP0_COMP0_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCMP1 register.
//
//*****************************************************************************
#define ADC_DCCMP1_COMP1_M      0x0FFF0000  // Compare 1
#define ADC_DCCMP1_COMP0_M      0x00000FFF  // Compare 0
#define ADC_DCCMP1_COMP1_S      16
#define ADC_DCCMP1_COMP0_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCMP2 register.
//
//*****************************************************************************
#define ADC_DCCMP2_COMP1_M      0x0FFF0000  // Compare 1
#define ADC_DCCMP2_COMP0_M      0x00000FFF  // Compare 0
#define ADC_DCCMP2_COMP1_S      16
#define ADC_DCCMP2_COMP0_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCMP3 register.
//
//*****************************************************************************
#define ADC_DCCMP3_COMP1_M      0x0FFF0000  // Compare 1
#define ADC_DCCMP3_COMP0_M      0x00000FFF  // Compare 0
#define ADC_DCCMP3_COMP1_S      16
#define ADC_DCCMP3_COMP0_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCMP4 register.
//
//*****************************************************************************
#define ADC_DCCMP4_COMP1_M      0x0FFF0000  // Compare 1
#define ADC_DCCMP4_COMP0_M      0x00000FFF  // Compare 0
#define ADC_DCCMP4_COMP1_S      16
#define ADC_DCCMP4_COMP0_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCMP5 register.
//
//*****************************************************************************
#define ADC_DCCMP5_COMP1_M      0x0FFF0000  // Compare 1
#define ADC_DCCMP5_COMP0_M      0x00000FFF  // Compare 0
#define ADC_DCCMP5_COMP1_S      16
#define ADC_DCCMP5_COMP0_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCMP6 register.
//
//*****************************************************************************
#define ADC_DCCMP6_COMP1_M      0x0FFF0000  // Compare 1
#define ADC_DCCMP6_COMP0_M      0x00000FFF  // Compare 0
#define ADC_DCCMP6_COMP1_S      16
#define ADC_DCCMP6_COMP0_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_DCCMP7 register.
//
//*****************************************************************************
#define ADC_DCCMP7_COMP1_M      0x0FFF0000  // Compare 1
#define ADC_DCCMP7_COMP0_M      0x00000FFF  // Compare 0
#define ADC_DCCMP7_COMP1_S      16
#define ADC_DCCMP7_COMP0_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_PP register.
//
//*****************************************************************************
#define ADC_PP_APSHT            0x01000000  // Application-Programmable
                                            // Sample-and-Hold Time
#define ADC_PP_TS               0x00800000  // Temperature Sensor
#define ADC_PP_RSL_M            0x007C0000  // Resolution
#define ADC_PP_TYPE_M           0x00030000  // ADC Architecture
#define ADC_PP_TYPE_SAR         0x00000000  // SAR
#define ADC_PP_DC_M             0x0000FC00  // Digital Comparator Count
#define ADC_PP_CH_M             0x000003F0  // ADC Channel Count
#define ADC_PP_MCR_M            0x0000000F  // Maximum Conversion Rate
#define ADC_PP_MCR_FULL         0x00000007  // Full conversion rate (FCONV) as
                                            // defined by TADC and NSH
#define ADC_PP_MSR_M            0x0000000F  // Maximum ADC Sample Rate
#define ADC_PP_MSR_125K         0x00000001  // 125 ksps
#define ADC_PP_MSR_250K         0x00000003  // 250 ksps
#define ADC_PP_MSR_500K         0x00000005  // 500 ksps
#define ADC_PP_MSR_1M           0x00000007  // 1 Msps
#define ADC_PP_RSL_S            18
#define ADC_PP_DC_S             10
#define ADC_PP_CH_S             4

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_PC register.
//
//*****************************************************************************
#define ADC_PC_SR_M             0x0000000F  // ADC Sample Rate
#define ADC_PC_SR_125K          0x00000001  // 125 ksps
#define ADC_PC_SR_250K          0x00000003  // 250 ksps
#define ADC_PC_SR_500K          0x00000005  // 500 ksps
#define ADC_PC_SR_1M            0x00000007  // 1 Msps
#define ADC_PC_MCR_M            0x0000000F  // Conversion Rate
#define ADC_PC_MCR_1_8          0x00000001  // Eighth conversion rate. After a
                                            // conversion completes, the logic
                                            // pauses for 112 TADC periods
                                            // before starting the next
                                            // conversion
#define ADC_PC_MCR_1_4          0x00000003  // Quarter conversion rate. After a
                                            // conversion completes, the logic
                                            // pauses for 48 TADC periods
                                            // before starting the next
                                            // conversion
#define ADC_PC_MCR_1_2          0x00000005  // Half conversion rate. After a
                                            // conversion completes, the logic
                                            // pauses for 16 TADC periods
                                            // before starting the next
                                            // conversion
#define ADC_PC_MCR_FULL         0x00000007  // Full conversion rate (FCONV) as
                                            // defined by TADC and NSH

//*****************************************************************************
//
// The following are defines for the bit fields in the ADC_O_CC register.
//
//*****************************************************************************
#define ADC_CC_CLKDIV_M         0x000003F0  // PLL VCO Clock Divisor
#define ADC_CC_CS_M             0x0000000F  // ADC Clock Source
#define ADC_CC_CS_SYSPLL        0x00000000  // Either the system clock (if the
                                            // PLL bypass is in effect) or the
                                            // 16 MHz clock derived from PLL /
                                            // 25 (default)
#define ADC_CC_CS_PIOSC         0x00000001  // PIOSC
#define ADC_CC_CS_MOSC          0x00000002  // MOSC
#define ADC_CC_CLKDIV_S         4

//*****************************************************************************
//
// Snowflake Interrupt Class Definition
//
//*****************************************************************************
#define INT_RESOLVE(intname, class) intname##SNOWFLAKE

//*****************************************************************************
//
// Macros to resolve the INT_PERIPH_CLASS name to a common INT_PERIPH name.
//
//*****************************************************************************
#define INT_CONCAT(intname, class)  INT_RESOLVE(intname, class)

//*****************************************************************************
//
// The following are defines for the interrupt assignments.
//
//*****************************************************************************
#define INT_ADC0SS3             INT_CONCAT(INT_ADC0SS3_, INT_DEVICE_CLASS)

//*****************************************************************************
//
// Snowflake Class Interrupts
//
//*****************************************************************************
#define INT_GPIOA_SNOWFLAKE     16          // GPIO Port A
#define INT_GPIOB_SNOWFLAKE     17          // GPIO Port B
#define INT_GPIOC_SNOWFLAKE     18          // GPIO Port C
#define INT_GPIOD_SNOWFLAKE     19          // GPIO Port D
#define INT_GPIOE_SNOWFLAKE     20          // GPIO Port E
#define INT_UART0_SNOWFLAKE     21          // UART0
#define INT_UART1_SNOWFLAKE     22          // UART1
#define INT_SSI0_SNOWFLAKE      23          // SSI0
#define INT_I2C0_SNOWFLAKE      24          // I2C0
#define INT_PWM0_FAULT_SNOWFLAKE                                              \
                                25          // PWM Fault
#define INT_PWM0_0_SNOWFLAKE    26          // PWM Generator 0
#define INT_PWM0_1_SNOWFLAKE    27          // PWM Generator 1
#define INT_PWM0_2_SNOWFLAKE    28          // PWM Generator 2
#define INT_QEI0_SNOWFLAKE      29          // QEI0
#define INT_ADC0SS0_SNOWFLAKE   30          // ADC0 Sequence 0
#define INT_ADC0SS1_SNOWFLAKE   31          // ADC0 Sequence 1
#define INT_ADC0SS2_SNOWFLAKE   32          // ADC0 Sequence 2
#define INT_ADC0SS3_SNOWFLAKE   33          // ADC0 Sequence 3
#define INT_WATCHDOG_SNOWFLAKE  34          // Watchdog Timers 0 and 1
#define INT_TIMER0A_SNOWFLAKE   35          // 16/32-Bit Timer 0A
#define INT_TIMER0B_SNOWFLAKE   36          // 16/32-Bit Timer 0B
#define INT_TIMER1A_SNOWFLAKE   37          // 16/32-Bit Timer 1A
#define INT_TIMER1B_SNOWFLAKE   38          // 16/32-Bit Timer 1B
#define INT_TIMER2A_SNOWFLAKE   39          // 16/32-Bit Timer 2A
#define INT_TIMER2B_SNOWFLAKE   40          // 16/32-Bit Timer 2B
#define INT_COMP0_SNOWFLAKE     41          // Analog Comparator 0
#define INT_COMP1_SNOWFLAKE     42          // Analog Comparator 1
#define INT_COMP2_SNOWFLAKE     43          // Analog Comparator 2
#define INT_SYSCTL_SNOWFLAKE    44          // System Control
#define INT_FLASH_SNOWFLAKE     45          // Flash Memory Control
#define INT_GPIOF_SNOWFLAKE     46          // GPIO Port F
#define INT_GPIOG_SNOWFLAKE     47          // GPIO Port G
#define INT_GPIOH_SNOWFLAKE     48          // GPIO Port H
#define INT_UART2_SNOWFLAKE     49          // UART2
#define INT_SSI1_SNOWFLAKE      50          // SSI1
#define INT_TIMER3A_SNOWFLAKE   51          // 16/32-Bit Timer 3A
#define INT_TIMER3B_SNOWFLAKE   52          // 16/32-Bit Timer 3B
#define INT_I2C1_SNOWFLAKE      53          // I2C1
#define INT_CAN0_SNOWFLAKE      54          // CAN 0
#define INT_CAN1_SNOWFLAKE      55          // CAN1
#define INT_EMAC0_SNOWFLAKE     56          // Ethernet MAC
#define INT_HIBERNATE_SNOWFLAKE 57          // HIB (Power Island)
#define INT_USB0_SNOWFLAKE      58          // USB MAC
#define INT_PWM0_3_SNOWFLAKE    59          // PWM Generator 3
#define INT_UDMA_SNOWFLAKE      60          // uDMA 0 Software
#define INT_UDMAERR_SNOWFLAKE   61          // uDMA 0 Error
#define INT_ADC1SS0_SNOWFLAKE   62          // ADC1 Sequence 0
#define INT_ADC1SS1_SNOWFLAKE   63          // ADC1 Sequence 1
#define INT_ADC1SS2_SNOWFLAKE   64          // ADC1 Sequence 2
#define INT_ADC1SS3_SNOWFLAKE   65          // ADC1 Sequence 3
#define INT_EPI0_SNOWFLAKE      66          // EPI 0
#define INT_GPIOJ_SNOWFLAKE     67          // GPIO Port J
#define INT_GPIOK_SNOWFLAKE     68          // GPIO Port K
#define INT_GPIOL_SNOWFLAKE     69          // GPIO Port L
#define INT_SSI2_SNOWFLAKE      70          // SSI 2
#define INT_SSI3_SNOWFLAKE      71          // SSI 3
#define INT_UART3_SNOWFLAKE     72          // UART 3
#define INT_UART4_SNOWFLAKE     73          // UART 4
#define INT_UART5_SNOWFLAKE     74          // UART 5
#define INT_UART6_SNOWFLAKE     75          // UART 6
#define INT_UART7_SNOWFLAKE     76          // UART 7
#define INT_I2C2_SNOWFLAKE      77          // I2C 2
#define INT_I2C3_SNOWFLAKE      78          // I2C 3
#define INT_TIMER4A_SNOWFLAKE   79          // Timer 4A
#define INT_TIMER4B_SNOWFLAKE   80          // Timer 4B
#define INT_TIMER5A_SNOWFLAKE   81          // Timer 5A
#define INT_TIMER5B_SNOWFLAKE   82          // Timer 5B
#define INT_SYSEXC_SNOWFLAKE    83          // Floating-Point Exception
                                            // (imprecise)
#define INT_PECI0_SNOWFLAKE     84          // PECI
#define INT_LPC0_SNOWFLAKE      85          // LPC
#define INT_I2C4_SNOWFLAKE      86          // I2C 4
#define INT_I2C5_SNOWFLAKE      87          // I2C 5
#define INT_GPIOM_SNOWFLAKE     88          // GPIO Port M
#define INT_GPION_SNOWFLAKE     89          // GPIO Port N
#define INT_FAN0_SNOWFLAKE      90          // FAN 0
#define INT_TAMPER0_SNOWFLAKE   91          // Tamper
#define INT_GPIOP0_SNOWFLAKE    92          // GPIO Port P (Summary or P0)
#define INT_GPIOP1_SNOWFLAKE    93          // GPIO Port P1
#define INT_GPIOP2_SNOWFLAKE    94          // GPIO Port P2
#define INT_GPIOP3_SNOWFLAKE    95          // GPIO Port P3
#define INT_GPIOP4_SNOWFLAKE    96          // GPIO Port P4
#define INT_GPIOP5_SNOWFLAKE    97          // GPIO Port P5
#define INT_GPIOP6_SNOWFLAKE    98          // GPIO Port P6
#define INT_GPIOP7_SNOWFLAKE    99          // GPIO Port P7
#define INT_GPIOQ0_SNOWFLAKE    100         // GPIO Port Q (Summary or Q0)
#define INT_GPIOQ1_SNOWFLAKE    101         // GPIO Port Q1
#define INT_GPIOQ2_SNOWFLAKE    102         // GPIO Port Q2
#define INT_GPIOQ3_SNOWFLAKE    103         // GPIO Port Q3
#define INT_GPIOQ4_SNOWFLAKE    104         // GPIO Port Q4
#define INT_GPIOQ5_SNOWFLAKE    105         // GPIO Port Q5
#define INT_GPIOQ6_SNOWFLAKE    106         // GPIO Port Q6
#define INT_GPIOQ7_SNOWFLAKE    107         // GPIO Port Q7
#define INT_GPIOR_SNOWFLAKE     108         // GPIO Port R
#define INT_GPIOS_SNOWFLAKE     109         // GPIO Port S
#define INT_SHA0_SNOWFLAKE      110         // SHA/MD5
#define INT_AES0_SNOWFLAKE      111         // AES
#define INT_DES0_SNOWFLAKE      112         // DES
#define INT_LCD0_SNOWFLAKE      113         // LCD
#define INT_TIMER6A_SNOWFLAKE   114         // 16/32-Bit Timer 6A
#define INT_TIMER6B_SNOWFLAKE   115         // 16/32-Bit Timer 6B
#define INT_TIMER7A_SNOWFLAKE   116         // 16/32-Bit Timer 7A
#define INT_TIMER7B_SNOWFLAKE   117         // 16/32-Bit Timer 7B
#define INT_I2C6_SNOWFLAKE      118         // I2C 6
#define INT_I2C7_SNOWFLAKE      119         // I2C 7
#define INT_KBSCAN0_SNOWFLAKE   120         // Keyboard Scan - Human Interface
                                            // Module (HIM)
#define INT_ONEWIRE0_SNOWFLAKE  121         // 1-Wire
#define INT_PS20_SNOWFLAKE      122         // PS/2 - Human Interface Module
                                            // (HIM)
#define INT_LED0_SNOWFLAKE      123         // LED Sequencer - Human Interface
                                            // Module (HIM)
#define INT_CIR0_SNOWFLAKE      124         // Consumer IR - Human Interface
                                            // Module (HIM)
#define INT_I2C8_SNOWFLAKE      125         // I2C 8
#define INT_I2C9_SNOWFLAKE      126         // I2C 9
#define INT_GPIOT_SNOWFLAKE     127         // GPIO T
#define INT_FAN1_SNOWFLAKE      128         // FAN 1
#define NUM_INTERRUPTS_SNOWFLAKE                                              \
                                129
//*****************************************************************************
//
// Values that can be passed to TimerConfigure as the ui32Config parameter.
//
//*****************************************************************************
#define TIMER_CFG_ONE_SHOT       0x00000021  // Full-width one-shot timer
#define TIMER_CFG_ONE_SHOT_UP    0x00000031  // Full-width one-shot up-count
                                            // timer
#define TIMER_CFG_PERIODIC       0x00000022  // Full-width periodic timer
#define TIMER_CFG_PERIODIC_UP    0x00000032  // Full-width periodic up-count
                                            // timer
#define TIMER_CFG_RTC            0x01000000  // Full-width RTC timer
#define TIMER_CFG_SPLIT_PAIR     0x04000000  // Two half-width timers
#define TIMER_CFG_A_ONE_SHOT     0x00000021  // Timer A one-shot timer
#define TIMER_CFG_A_ONE_SHOT_UP  0x00000031  // Timer A one-shot up-count timer
#define TIMER_CFG_A_PERIODIC     0x00000022  // Timer A periodic timer
#define TIMER_CFG_A_PERIODIC_UP  0x00000032  // Timer A periodic up-count timer
#define TIMER_CFG_A_CAP_COUNT    0x00000003  // Timer A event counter
#define TIMER_CFG_A_CAP_COUNT_UP 0x00000013  // Timer A event up-counter
#define TIMER_CFG_A_CAP_TIME     0x00000007  // Timer A event timer
#define TIMER_CFG_A_CAP_TIME_UP  0x00000017  // Timer A event up-count timer
#define TIMER_CFG_A_PWM          0x0000000A  // Timer A PWM output
#define TIMER_CFG_B_ONE_SHOT     0x00002100  // Timer B one-shot timer
#define TIMER_CFG_B_ONE_SHOT_UP  0x00003100  // Timer B one-shot up-count timer
#define TIMER_CFG_B_PERIODIC     0x00002200  // Timer B periodic timer
#define TIMER_CFG_B_PERIODIC_UP  0x00003200  // Timer B periodic up-count timer
#define TIMER_CFG_B_CAP_COUNT    0x00000300  // Timer B event counter
#define TIMER_CFG_B_CAP_COUNT_UP 0x00001300  // Timer B event up-counter
#define TIMER_CFG_B_CAP_TIME     0x00000700  // Timer B event timer
#define TIMER_CFG_B_CAP_TIME_UP  0x00001700  // Timer B event up-count timer
#define TIMER_CFG_B_PWM          0x00000A00  // Timer B PWM output
#define TIMER_CFG_A_ACT_TOINTD   0x00010000  // Timer A compare action disable
                                             // time-out interrupt.
#define TIMER_CFG_A_ACT_NONE     0x00000000  // Timer A compare action none.
#define TIMER_CFG_A_ACT_TOGGLE   0x00020000  // Timer A compare action toggle.
#define TIMER_CFG_A_ACT_CLRTO    0x00040000  // Timer A compare action CCP
                                             // clear on time-out.
#define TIMER_CFG_A_ACT_SETTO    0x00060000  // Timer A compare action CCP set
                                             // on time-out.
#define TIMER_CFG_A_ACT_SETTOGTO 0x00080000  // Timer A compare action set CCP
                                             // toggle on time-out.
#define TIMER_CFG_A_ACT_CLRTOGTO 0x000A0000  // Timer A compare action clear
                                             // CCP toggle on time-out.
#define TIMER_CFG_A_ACT_SETCLRTO 0x000C0000  // Timer A compare action set CCP
                                             // clear on time-out.
#define TIMER_CFG_A_ACT_CLRSETTO 0x000E0000  // Timer A compare action clear
                                             // CCP set on time-out.
#define TIMER_CFG_B_ACT_TOINTD   0x00100000  // Timer B compare action disable
                                             // time-out interrupt.
#define TIMER_CFG_B_ACT_NONE     0x00000000  // Timer A compare action none.
#define TIMER_CFG_B_ACT_TOGGLE   0x00200000  // Timer A compare action toggle.
#define TIMER_CFG_B_ACT_CLRTO    0x00400000  // Timer A compare action CCP
                                             // clear on time-out.
#define TIMER_CFG_B_ACT_SETTO    0x00600000  // Timer A compare action CCP set
                                             // on time-out.
#define TIMER_CFG_B_ACT_SETTOGTO 0x00800000  // Timer A compare action set CCP
                                             // toggle on time-out.
#define TIMER_CFG_B_ACT_CLRTOGTO 0x00A00000  // Timer A compare action clear
                                             // CCP toggle on time-out.
#define TIMER_CFG_B_ACT_SETCLRTO 0x00C00000  // Timer A compare action set CCP
                                             // clear on time-out.
#define TIMER_CFG_B_ACT_CLRSETTO 0x0000E000  // Timer A compare action clear
                                             // CCP set on time-out.

//*****************************************************************************
//
// Values that can be passed to TimerIntEnable, TimerIntDisable, and
// TimerIntClear as the ui32IntFlags parameter, and returned from
// TimerIntStatus.
//
//*****************************************************************************
#define TIMER_TIMB_DMA          0x00002000 // TimerB DMA Complete Interrupt.
#define TIMER_TIMB_MATCH        0x00000800  // TimerB match interrupt
#define TIMER_CAPB_EVENT        0x00000400  // CaptureB event interrupt
#define TIMER_CAPB_MATCH        0x00000200  // CaptureB match interrupt
#define TIMER_TIMB_TIMEOUT      0x00000100  // TimerB time out interrupt
#define TIMER_TIMA_DMA          0x00000020 // TimerA DMA Complete Interrupt.
#define TIMER_TIMA_MATCH        0x00000010  // TimerA match interrupt
#define TIMER_RTC_MATCH         0x00000008  // RTC interrupt mask
#define TIMER_CAPA_EVENT        0x00000004  // CaptureA event interrupt
#define TIMER_CAPA_MATCH        0x00000002  // CaptureA match interrupt
#define TIMER_TIMA_TIMEOUT      0x00000001  // TimerA time out interrupt

//*****************************************************************************
//
// Values that can be passed to TimerControlEvent as the ui32Event parameter.
//
//*****************************************************************************
#define TIMER_EVENT_POS_EDGE    0x00000000  // Count positive edges
#define TIMER_EVENT_NEG_EDGE    0x00000404  // Count negative edges
#define TIMER_EVENT_BOTH_EDGES  0x00000C0C  // Count both edges

//*****************************************************************************
//
// Values that can be passed to most of the timer APIs as the ui32Timer
// parameter.
//
//*****************************************************************************
#define TIMER_A                 0x000000ff  // Timer A
#define TIMER_B                 0x0000ff00  // Timer B
#define TIMER_BOTH              0x0000ffff  // Timer Both

//*****************************************************************************
//
// Values that can be passed to TimerSynchronize as the ui32Timers parameter.
//
//*****************************************************************************
#define TIMER_0A_SYNC           0x00000001  // Synchronize Timer 0A
#define TIMER_0B_SYNC           0x00000002  // Synchronize Timer 0B
#define TIMER_1A_SYNC           0x00000004  // Synchronize Timer 1A
#define TIMER_1B_SYNC           0x00000008  // Synchronize Timer 1B
#define TIMER_2A_SYNC           0x00000010  // Synchronize Timer 2A
#define TIMER_2B_SYNC           0x00000020  // Synchronize Timer 2B
#define TIMER_3A_SYNC           0x00000040  // Synchronize Timer 3A
#define TIMER_3B_SYNC           0x00000080  // Synchronize Timer 3B
#define TIMER_4A_SYNC           0x00000100  // Synchronize Timer 4A
#define TIMER_4B_SYNC           0x00000200  // Synchronize Timer 4B
#define TIMER_5A_SYNC           0x00000400  // Synchronize Timer 5A
#define TIMER_5B_SYNC           0x00000800  // Synchronize Timer 5B
#define WTIMER_0A_SYNC          0x00001000  // Synchronize Wide Timer 0A
#define WTIMER_0B_SYNC          0x00002000  // Synchronize Wide Timer 0B
#define WTIMER_1A_SYNC          0x00004000  // Synchronize Wide Timer 1A
#define WTIMER_1B_SYNC          0x00008000  // Synchronize Wide Timer 1B
#define WTIMER_2A_SYNC          0x00010000  // Synchronize Wide Timer 2A
#define WTIMER_2B_SYNC          0x00020000  // Synchronize Wide Timer 2B
#define WTIMER_3A_SYNC          0x00040000  // Synchronize Wide Timer 3A
#define WTIMER_3B_SYNC          0x00080000  // Synchronize Wide Timer 3B
#define WTIMER_4A_SYNC          0x00100000  // Synchronize Wide Timer 4A
#define WTIMER_4B_SYNC          0x00200000  // Synchronize Wide Timer 4B
#define WTIMER_5A_SYNC          0x00400000  // Synchronize Wide Timer 5A
#define WTIMER_5B_SYNC          0x00800000  // Synchronize Wide Timer 5B

//*****************************************************************************
//
// Values that can be passed to TimerClockSourceSet() or returned from
// TimerClockSourceGet().
//
//*****************************************************************************
#define TIMER_CLOCK_SYSTEM      0x00000000
#define TIMER_CLOCK_PIOSC       0x00000001

//*****************************************************************************
//
// Values that can be passed to TimerDMAEventSet() or returned from
// TimerDMAEventGet().
//
//*****************************************************************************
#define TIMER_DMA_MODEMATCH_B   0x00000800
#define TIMER_DMA_CAPEVENT_B    0x00000400
#define TIMER_DMA_CAPMATCH_B    0x00000200
#define TIMER_DMA_TIMEOUT_B     0x00000100
#define TIMER_DMA_MODEMATCH_A   0x00000010
#define TIMER_DMA_RTC_A         0x00000008
#define TIMER_DMA_CAPEVENT_A    0x00000004
#define TIMER_DMA_CAPMATCH_A    0x00000002
#define TIMER_DMA_TIMEOUT_A     0x00000001

//*****************************************************************************
//
// Values that can be passed to TimerADCEventSet() or returned from
// TimerADCEventGet().
//
//*****************************************************************************
#define TIMER_ADC_MODEMATCH_B   0x00000800
#define TIMER_ADC_CAPEVENT_B    0x00000400
#define TIMER_ADC_CAPMATCH_B    0x00000200
#define TIMER_ADC_TIMEOUT_B     0x00000100
#define TIMER_ADC_MODEMATCH_A   0x00000010
#define TIMER_ADC_RTC_A         0x00000008
#define TIMER_ADC_CAPEVENT_A    0x00000004
#define TIMER_ADC_CAPMATCH_A    0x00000002
#define TIMER_ADC_TIMEOUT_A     0x00000001

//*****************************************************************************
//
// The following are defines for the Timer register offsets.
//
//*****************************************************************************
#define TIMER_O_CFG             0x00000000  // GPTM Configuration
#define TIMER_O_TAMR            0x00000004  // GPTM Timer A Mode
#define TIMER_O_TBMR            0x00000008  // GPTM Timer B Mode
#define TIMER_O_CTL             0x0000000C  // GPTM Control
#define TIMER_O_SYNC            0x00000010  // GPTM Synchronize
#define TIMER_O_IMR             0x00000018  // GPTM Interrupt Mask
#define TIMER_O_RIS             0x0000001C  // GPTM Raw Interrupt Status
#define TIMER_O_MIS             0x00000020  // GPTM Masked Interrupt Status
#define TIMER_O_ICR             0x00000024  // GPTM Interrupt Clear
#define TIMER_O_TAILR           0x00000028  // GPTM Timer A Interval Load
#define TIMER_O_TBILR           0x0000002C  // GPTM Timer B Interval Load
#define TIMER_O_TAMATCHR        0x00000030  // GPTM Timer A Match
#define TIMER_O_TBMATCHR        0x00000034  // GPTM Timer B Match
#define TIMER_O_TAPR            0x00000038  // GPTM Timer A Prescale
#define TIMER_O_TBPR            0x0000003C  // GPTM Timer B Prescale
#define TIMER_O_TAPMR           0x00000040  // GPTM TimerA Prescale Match
#define TIMER_O_TBPMR           0x00000044  // GPTM TimerB Prescale Match
#define TIMER_O_TAR             0x00000048  // GPTM Timer A
#define TIMER_O_TBR             0x0000004C  // GPTM Timer B
#define TIMER_O_TAV             0x00000050  // GPTM Timer A Value
#define TIMER_O_TBV             0x00000054  // GPTM Timer B Value
#define TIMER_O_RTCPD           0x00000058  // GPTM RTC Predivide
#define TIMER_O_TAPS            0x0000005C  // GPTM Timer A Prescale Snapshot
#define TIMER_O_TBPS            0x00000060  // GPTM Timer B Prescale Snapshot
#define TIMER_O_TAPV            0x00000064  // GPTM Timer A Prescale Value
#define TIMER_O_TBPV            0x00000068  // GPTM Timer B Prescale Value
#define TIMER_O_DMAEV           0x0000006C  // GPTM DMA Event
#define TIMER_O_ADCEV           0x00000070  // GPTM ADC Event
#define TIMER_O_PP              0x00000FC0  // GPTM Peripheral Properties
#define TIMER_O_CC              0x00000FC8  // GPTM Clock Configuration

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_CFG register.
//
//*****************************************************************************
#define TIMER_CFG_M             0x00000007  // GPTM Configuration
#define TIMER_CFG_32_BIT_TIMER  0x00000000  // 32-bit timer configuration
#define TIMER_CFG_32_BIT_RTC    0x00000001  // 32-bit real-time clock (RTC)
                                            // counter configuration
#define TIMER_CFG_16_BIT        0x00000004  // 16-bit timer configuration. The
                                            // function is controlled by bits
                                            // 1:0 of GPTMTAMR and GPTMTBMR

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TAMR register.
//
//*****************************************************************************
#define TIMER_TAMR_TCACT_M      0x0000E000  // Timer Compare Action Select
#define TIMER_TAMR_TCACT_NONE   0x00000000  // Disable compare operations
#define TIMER_TAMR_TCACT_TOGGLE 0x00002000  // Toggle State on Time-Out
#define TIMER_TAMR_TCACT_CLRTO  0x00004000  // Clear CCP on Time-Out
#define TIMER_TAMR_TCACT_SETTO  0x00006000  // Set CCP on Time-Out
#define TIMER_TAMR_TCACT_SETTOGTO                                             \
                                0x00008000  // Set CCP immediately and toggle
                                            // on Time-Out
#define TIMER_TAMR_TCACT_CLRTOGTO                                             \
                                0x0000A000  // Clear CCP immediately and toggle
                                            // on Time-Out
#define TIMER_TAMR_TCACT_SETCLRTO                                             \
                                0x0000C000  // Set CCP immediately and clear on
                                            // Time-Out
#define TIMER_TAMR_TCACT_CLRSETTO                                             \
                                0x0000E000  // Clear CCP immediately and set on
                                            // Time-Out
#define TIMER_TAMR_TACINTD      0x00001000  // One-shot/Periodic Interrupt Mode
#define TIMER_TAMR_TAPLO        0x00000800  // GPTM Timer A PWM Legacy
                                            // Operation
#define TIMER_TAMR_TAMRSU       0x00000400  // GPTM Timer A Match Register
                                            // Update
#define TIMER_TAMR_TAPWMIE      0x00000200  // GPTM Timer A PWM Interrupt
                                            // Enable
#define TIMER_TAMR_TAILD        0x00000100  // GPTM Timer A Interval Load Write
#define TIMER_TAMR_TASNAPS      0x00000080  // GPTM Timer A Snap-Shot Mode
#define TIMER_TAMR_TAWOT        0x00000040  // GPTM Timer A Wait-on-Trigger
#define TIMER_TAMR_TAMIE        0x00000020  // GPTM Timer A Match Interrupt
                                            // Enable
#define TIMER_TAMR_TACDIR       0x00000010  // GPTM Timer A Count Direction
#define TIMER_TAMR_TAAMS        0x00000008  // GPTM Timer A Alternate Mode
                                            // Select
#define TIMER_TAMR_TACMR        0x00000004  // GPTM Timer A Capture Mode
#define TIMER_TAMR_TAMR_M       0x00000003  // GPTM Timer A Mode
#define TIMER_TAMR_TAMR_1_SHOT  0x00000001  // One-Shot Timer mode
#define TIMER_TAMR_TAMR_PERIOD  0x00000002  // Periodic Timer mode
#define TIMER_TAMR_TAMR_CAP     0x00000003  // Capture mode

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TBMR register.
//
//*****************************************************************************
#define TIMER_TBMR_TCACT_M      0x0000E000  // Timer Compare Action Select
#define TIMER_TBMR_TCACT_NONE   0x00000000  // Disable compare operations
#define TIMER_TBMR_TCACT_TOGGLE 0x00002000  // Toggle State on Time-Out
#define TIMER_TBMR_TCACT_CLRTO  0x00004000  // Clear CCP on Time-Out
#define TIMER_TBMR_TCACT_SETTO  0x00006000  // Set CCP on Time-Out
#define TIMER_TBMR_TCACT_SETTOGTO                                             \
                                0x00008000  // Set CCP immediately and toggle
                                            // on Time-Out
#define TIMER_TBMR_TCACT_CLRTOGTO                                             \
                                0x0000A000  // Clear CCP immediately and toggle
                                            // on Time-Out
#define TIMER_TBMR_TCACT_SETCLRTO                                             \
                                0x0000C000  // Set CCP immediately and clear on
                                            // Time-Out
#define TIMER_TBMR_TCACT_CLRSETTO                                             \
                                0x0000E000  // Clear CCP immediately and set on
                                            // Time-Out
#define TIMER_TBMR_TBCINTD      0x00001000  // One-Shot/Periodic Interrupt Mode
#define TIMER_TBMR_TBPLO        0x00000800  // GPTM Timer B PWM Legacy
                                            // Operation
#define TIMER_TBMR_TBMRSU       0x00000400  // GPTM Timer B Match Register
                                            // Update
#define TIMER_TBMR_TBPWMIE      0x00000200  // GPTM Timer B PWM Interrupt
                                            // Enable
#define TIMER_TBMR_TBILD        0x00000100  // GPTM Timer B Interval Load Write
#define TIMER_TBMR_TBSNAPS      0x00000080  // GPTM Timer B Snap-Shot Mode
#define TIMER_TBMR_TBWOT        0x00000040  // GPTM Timer B Wait-on-Trigger
#define TIMER_TBMR_TBMIE        0x00000020  // GPTM Timer B Match Interrupt
                                            // Enable
#define TIMER_TBMR_TBCDIR       0x00000010  // GPTM Timer B Count Direction
#define TIMER_TBMR_TBAMS        0x00000008  // GPTM Timer B Alternate Mode
                                            // Select
#define TIMER_TBMR_TBCMR        0x00000004  // GPTM Timer B Capture Mode
#define TIMER_TBMR_TBMR_M       0x00000003  // GPTM Timer B Mode
#define TIMER_TBMR_TBMR_1_SHOT  0x00000001  // One-Shot Timer mode
#define TIMER_TBMR_TBMR_PERIOD  0x00000002  // Periodic Timer mode
#define TIMER_TBMR_TBMR_CAP     0x00000003  // Capture mode

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_CTL register.
//
//*****************************************************************************
#define TIMER_CTL_TBPWML        0x00004000  // GPTM Timer B PWM Output Level
#define TIMER_CTL_TBOTE         0x00002000  // GPTM Timer B Output Trigger
                                            // Enable
#define TIMER_CTL_TBEVENT_M     0x00000C00  // GPTM Timer B Event Mode
#define TIMER_CTL_TBEVENT_POS   0x00000000  // Positive edge
#define TIMER_CTL_TBEVENT_NEG   0x00000400  // Negative edge
#define TIMER_CTL_TBEVENT_BOTH  0x00000C00  // Both edges
#define TIMER_CTL_TBSTALL       0x00000200  // GPTM Timer B Stall Enable
#define TIMER_CTL_TBEN          0x00000100  // GPTM Timer B Enable
#define TIMER_CTL_TAPWML        0x00000040  // GPTM Timer A PWM Output Level
#define TIMER_CTL_TAOTE         0x00000020  // GPTM Timer A Output Trigger
                                            // Enable
#define TIMER_CTL_RTCEN         0x00000010  // GPTM RTC Stall Enable
#define TIMER_CTL_TAEVENT_M     0x0000000C  // GPTM Timer A Event Mode
#define TIMER_CTL_TAEVENT_POS   0x00000000  // Positive edge
#define TIMER_CTL_TAEVENT_NEG   0x00000004  // Negative edge
#define TIMER_CTL_TAEVENT_BOTH  0x0000000C  // Both edges
#define TIMER_CTL_TASTALL       0x00000002  // GPTM Timer A Stall Enable
#define TIMER_CTL_TAEN          0x00000001  // GPTM Timer A Enable

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_SYNC register.
//
//*****************************************************************************
#define TIMER_SYNC_SYNCWT5_M    0x00C00000  // Synchronize GPTM 32/64-Bit Timer
                                            // 5
#define TIMER_SYNC_SYNCWT5_NONE 0x00000000  // GPTM 32/64-Bit Timer 5 is not
                                            // affected
#define TIMER_SYNC_SYNCWT5_TA   0x00400000  // A timeout event for Timer A of
                                            // GPTM 32/64-Bit Timer 5 is
                                            // triggered
#define TIMER_SYNC_SYNCWT5_TB   0x00800000  // A timeout event for Timer B of
                                            // GPTM 32/64-Bit Timer 5 is
                                            // triggered
#define TIMER_SYNC_SYNCWT5_TATB 0x00C00000  // A timeout event for both Timer A
                                            // and Timer B of GPTM 32/64-Bit
                                            // Timer 5 is triggered
#define TIMER_SYNC_SYNCWT4_M    0x00300000  // Synchronize GPTM 32/64-Bit Timer
                                            // 4
#define TIMER_SYNC_SYNCWT4_NONE 0x00000000  // GPTM 32/64-Bit Timer 4 is not
                                            // affected
#define TIMER_SYNC_SYNCWT4_TA   0x00100000  // A timeout event for Timer A of
                                            // GPTM 32/64-Bit Timer 4 is
                                            // triggered
#define TIMER_SYNC_SYNCWT4_TB   0x00200000  // A timeout event for Timer B of
                                            // GPTM 32/64-Bit Timer 4 is
                                            // triggered
#define TIMER_SYNC_SYNCWT4_TATB 0x00300000  // A timeout event for both Timer A
                                            // and Timer B of GPTM 32/64-Bit
                                            // Timer 4 is triggered
#define TIMER_SYNC_SYNCWT3_M    0x000C0000  // Synchronize GPTM 32/64-Bit Timer
                                            // 3
#define TIMER_SYNC_SYNCWT3_NONE 0x00000000  // GPTM 32/64-Bit Timer 3 is not
                                            // affected
#define TIMER_SYNC_SYNCWT3_TA   0x00040000  // A timeout event for Timer A of
                                            // GPTM 32/64-Bit Timer 3 is
                                            // triggered
#define TIMER_SYNC_SYNCWT3_TB   0x00080000  // A timeout event for Timer B of
                                            // GPTM 32/64-Bit Timer 3 is
                                            // triggered
#define TIMER_SYNC_SYNCWT3_TATB 0x000C0000  // A timeout event for both Timer A
                                            // and Timer B of GPTM 32/64-Bit
                                            // Timer 3 is triggered
#define TIMER_SYNC_SYNCWT2_M    0x00030000  // Synchronize GPTM 32/64-Bit Timer
                                            // 2
#define TIMER_SYNC_SYNCWT2_NONE 0x00000000  // GPTM 32/64-Bit Timer 2 is not
                                            // affected
#define TIMER_SYNC_SYNCWT2_TA   0x00010000  // A timeout event for Timer A of
                                            // GPTM 32/64-Bit Timer 2 is
                                            // triggered
#define TIMER_SYNC_SYNCWT2_TB   0x00020000  // A timeout event for Timer B of
                                            // GPTM 32/64-Bit Timer 2 is
                                            // triggered
#define TIMER_SYNC_SYNCWT2_TATB 0x00030000  // A timeout event for both Timer A
                                            // and Timer B of GPTM 32/64-Bit
                                            // Timer 2 is triggered
#define TIMER_SYNC_SYNCT7_M     0x0000C000  // Synchronize GPTM Timer 7
#define TIMER_SYNC_SYNCT7_NONE  0x00000000  // GPT7 is not affected
#define TIMER_SYNC_SYNCT7_TA    0x00004000  // A timeout event for Timer A of
                                            // GPTM7 is triggered
#define TIMER_SYNC_SYNCT7_TB    0x00008000  // A timeout event for Timer B of
                                            // GPTM7 is triggered
#define TIMER_SYNC_SYNCT7_TATB  0x0000C000  // A timeout event for both Timer A
                                            // and Timer B of GPTM7 is
                                            // triggered
#define TIMER_SYNC_SYNCWT1_M    0x0000C000  // Synchronize GPTM 32/64-Bit Timer
                                            // 1
#define TIMER_SYNC_SYNCWT1_NONE 0x00000000  // GPTM 32/64-Bit Timer 1 is not
                                            // affected
#define TIMER_SYNC_SYNCWT1_TA   0x00004000  // A timeout event for Timer A of
                                            // GPTM 32/64-Bit Timer 1 is
                                            // triggered
#define TIMER_SYNC_SYNCWT1_TB   0x00008000  // A timeout event for Timer B of
                                            // GPTM 32/64-Bit Timer 1 is
                                            // triggered
#define TIMER_SYNC_SYNCWT1_TATB 0x0000C000  // A timeout event for both Timer A
                                            // and Timer B of GPTM 32/64-Bit
                                            // Timer 1 is triggered
#define TIMER_SYNC_SYNCWT0_M    0x00003000  // Synchronize GPTM 32/64-Bit Timer
                                            // 0
#define TIMER_SYNC_SYNCWT0_NONE 0x00000000  // GPTM 32/64-Bit Timer 0 is not
                                            // affected
#define TIMER_SYNC_SYNCWT0_TA   0x00001000  // A timeout event for Timer A of
                                            // GPTM 32/64-Bit Timer 0 is
                                            // triggered
#define TIMER_SYNC_SYNCWT0_TB   0x00002000  // A timeout event for Timer B of
                                            // GPTM 32/64-Bit Timer 0 is
                                            // triggered
#define TIMER_SYNC_SYNCWT0_TATB 0x00003000  // A timeout event for both Timer A
                                            // and Timer B of GPTM 32/64-Bit
                                            // Timer 0 is triggered
#define TIMER_SYNC_SYNCT6_M     0x00003000  // Synchronize GPTM Timer 6
#define TIMER_SYNC_SYNCT6_NONE  0x00000000  // GPTM6 is not affected
#define TIMER_SYNC_SYNCT6_TA    0x00001000  // A timeout event for Timer A of
                                            // GPTM6 is triggered
#define TIMER_SYNC_SYNCT6_TB    0x00002000  // A timeout event for Timer B of
                                            // GPTM6 is triggered
#define TIMER_SYNC_SYNCT6_TATB  0x00003000  // A timeout event for both Timer A
                                            // and Timer B of GPTM6 is
                                            // triggered
#define TIMER_SYNC_SYNCT5_M     0x00000C00  // Synchronize GPTM 16/32-Bit Timer
                                            // 5
#define TIMER_SYNC_SYNCT5_NONE  0x00000000  // GPTM 16/32-Bit Timer 5 is not
                                            // affected
#define TIMER_SYNC_SYNCT5_TA    0x00000400  // A timeout event for Timer A of
                                            // GPTM 16/32-Bit Timer 5 is
                                            // triggered
#define TIMER_SYNC_SYNCT5_TB    0x00000800  // A timeout event for Timer B of
                                            // GPTM 16/32-Bit Timer 5 is
                                            // triggered
#define TIMER_SYNC_SYNCT5_TATB  0x00000C00  // A timeout event for both Timer A
                                            // and Timer B of GPTM 16/32-Bit
                                            // Timer 5 is triggered
#define TIMER_SYNC_SYNCT4_M     0x00000300  // Synchronize GPTM 16/32-Bit Timer
                                            // 4
#define TIMER_SYNC_SYNCT4_NONE  0x00000000  // GPTM 16/32-Bit Timer 4 is not
                                            // affected
#define TIMER_SYNC_SYNCT4_TA    0x00000100  // A timeout event for Timer A of
                                            // GPTM 16/32-Bit Timer 4 is
                                            // triggered
#define TIMER_SYNC_SYNCT4_TB    0x00000200  // A timeout event for Timer B of
                                            // GPTM 16/32-Bit Timer 4 is
                                            // triggered
#define TIMER_SYNC_SYNCT4_TATB  0x00000300  // A timeout event for both Timer A
                                            // and Timer B of GPTM 16/32-Bit
                                            // Timer 4 is triggered
#define TIMER_SYNC_SYNCT3_M     0x000000C0  // Synchronize GPTM 16/32-Bit Timer
                                            // 3
#define TIMER_SYNC_SYNCT3_NONE  0x00000000  // GPTM 16/32-Bit Timer 3 is not
                                            // affected
#define TIMER_SYNC_SYNCT3_TA    0x00000040  // A timeout event for Timer A of
                                            // GPTM 16/32-Bit Timer 3 is
                                            // triggered
#define TIMER_SYNC_SYNCT3_TB    0x00000080  // A timeout event for Timer B of
                                            // GPTM 16/32-Bit Timer 3 is
                                            // triggered
#define TIMER_SYNC_SYNCT3_TATB  0x000000C0  // A timeout event for both Timer A
                                            // and Timer B of GPTM 16/32-Bit
                                            // Timer 3 is triggered
#define TIMER_SYNC_SYNCT2_M     0x00000030  // Synchronize GPTM 16/32-Bit Timer
                                            // 2
#define TIMER_SYNC_SYNCT2_NONE  0x00000000  // GPTM 16/32-Bit Timer 2 is not
                                            // affected
#define TIMER_SYNC_SYNCT2_TA    0x00000010  // A timeout event for Timer A of
                                            // GPTM 16/32-Bit Timer 2 is
                                            // triggered
#define TIMER_SYNC_SYNCT2_TB    0x00000020  // A timeout event for Timer B of
                                            // GPTM 16/32-Bit Timer 2 is
                                            // triggered
#define TIMER_SYNC_SYNCT2_TATB  0x00000030  // A timeout event for both Timer A
                                            // and Timer B of GPTM 16/32-Bit
                                            // Timer 2 is triggered
#define TIMER_SYNC_SYNCT1_M     0x0000000C  // Synchronize GPTM 16/32-Bit Timer
                                            // 1
#define TIMER_SYNC_SYNCT1_NONE  0x00000000  // GPTM 16/32-Bit Timer 1 is not
                                            // affected
#define TIMER_SYNC_SYNCT1_TA    0x00000004  // A timeout event for Timer A of
                                            // GPTM 16/32-Bit Timer 1 is
                                            // triggered
#define TIMER_SYNC_SYNCT1_TB    0x00000008  // A timeout event for Timer B of
                                            // GPTM 16/32-Bit Timer 1 is
                                            // triggered
#define TIMER_SYNC_SYNCT1_TATB  0x0000000C  // A timeout event for both Timer A
                                            // and Timer B of GPTM 16/32-Bit
                                            // Timer 1 is triggered
#define TIMER_SYNC_SYNCT0_M     0x00000003  // Synchronize GPTM 16/32-Bit Timer
                                            // 0
#define TIMER_SYNC_SYNCT0_NONE  0x00000000  // GPTM 16/32-Bit Timer 0 is not
                                            // affected
#define TIMER_SYNC_SYNCT0_TA    0x00000001  // A timeout event for Timer A of
                                            // GPTM 16/32-Bit Timer 0 is
                                            // triggered
#define TIMER_SYNC_SYNCT0_TB    0x00000002  // A timeout event for Timer B of
                                            // GPTM 16/32-Bit Timer 0 is
                                            // triggered
#define TIMER_SYNC_SYNCT0_TATB  0x00000003  // A timeout event for both Timer A
                                            // and Timer B of GPTM 16/32-Bit
                                            // Timer 0 is triggered

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_IMR register.
//
//*****************************************************************************
#define TIMER_IMR_WUEIM         0x00010000  // GPTM Write Update Error
                                            // Interrupt Mask
#define TIMER_IMR_DMABIM        0x00002000  // GPTM Timer B DMA Done Interrupt
                                            // Mask
#define TIMER_IMR_TBMIM         0x00000800  // GPTM Timer B Match Interrupt
                                            // Mask
#define TIMER_IMR_CBEIM         0x00000400  // GPTM Timer B Capture Mode Event
                                            // Interrupt Mask
#define TIMER_IMR_CBMIM         0x00000200  // GPTM Timer B Capture Mode Match
                                            // Interrupt Mask
#define TIMER_IMR_TBTOIM        0x00000100  // GPTM Timer B Time-Out Interrupt
                                            // Mask
#define TIMER_IMR_DMAAIM        0x00000020  // GPTM Timer A DMA Done Interrupt
                                            // Mask
#define TIMER_IMR_TAMIM         0x00000010  // GPTM Timer A Match Interrupt
                                            // Mask
#define TIMER_IMR_RTCIM         0x00000008  // GPTM RTC Interrupt Mask
#define TIMER_IMR_CAEIM         0x00000004  // GPTM Timer A Capture Mode Event
                                            // Interrupt Mask
#define TIMER_IMR_CAMIM         0x00000002  // GPTM Timer A Capture Mode Match
                                            // Interrupt Mask
#define TIMER_IMR_TATOIM        0x00000001  // GPTM Timer A Time-Out Interrupt
                                            // Mask

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_RIS register.
//
//*****************************************************************************
#define TIMER_RIS_WUERIS        0x00010000  // GPTM Write Update Error Raw
                                            // Interrupt
#define TIMER_RIS_DMABRIS       0x00002000  // GPTM Timer B DMA Done Raw
                                            // Interrupt Status
#define TIMER_RIS_TBMRIS        0x00000800  // GPTM Timer B Match Raw Interrupt
#define TIMER_RIS_CBERIS        0x00000400  // GPTM Timer B Capture Mode Event
                                            // Raw Interrupt
#define TIMER_RIS_CBMRIS        0x00000200  // GPTM Timer B Capture Mode Match
                                            // Raw Interrupt
#define TIMER_RIS_TBTORIS       0x00000100  // GPTM Timer B Time-Out Raw
                                            // Interrupt
#define TIMER_RIS_DMAARIS       0x00000020  // GPTM Timer A DMA Done Raw
                                            // Interrupt Status
#define TIMER_RIS_TAMRIS        0x00000010  // GPTM Timer A Match Raw Interrupt
#define TIMER_RIS_RTCRIS        0x00000008  // GPTM RTC Raw Interrupt
#define TIMER_RIS_CAERIS        0x00000004  // GPTM Timer A Capture Mode Event
                                            // Raw Interrupt
#define TIMER_RIS_CAMRIS        0x00000002  // GPTM Timer A Capture Mode Match
                                            // Raw Interrupt
#define TIMER_RIS_TATORIS       0x00000001  // GPTM Timer A Time-Out Raw
                                            // Interrupt

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_MIS register.
//
//*****************************************************************************
#define TIMER_MIS_WUEMIS        0x00010000  // GPTM Write Update Error Masked
                                            // Interrupt
#define TIMER_MIS_DMABMIS       0x00002000  // GPTM Timer B DMA Done Masked
                                            // Interrupt
#define TIMER_MIS_TBMMIS        0x00000800  // GPTM Timer B Match Masked
                                            // Interrupt
#define TIMER_MIS_CBEMIS        0x00000400  // GPTM Timer B Capture Mode Event
                                            // Masked Interrupt
#define TIMER_MIS_CBMMIS        0x00000200  // GPTM Timer B Capture Mode Match
                                            // Masked Interrupt
#define TIMER_MIS_TBTOMIS       0x00000100  // GPTM Timer B Time-Out Masked
                                            // Interrupt
#define TIMER_MIS_DMAAMIS       0x00000020  // GPTM Timer A DMA Done Masked
                                            // Interrupt
#define TIMER_MIS_TAMMIS        0x00000010  // GPTM Timer A Match Masked
                                            // Interrupt
#define TIMER_MIS_RTCMIS        0x00000008  // GPTM RTC Masked Interrupt
#define TIMER_MIS_CAEMIS        0x00000004  // GPTM Timer A Capture Mode Event
                                            // Masked Interrupt
#define TIMER_MIS_CAMMIS        0x00000002  // GPTM Timer A Capture Mode Match
                                            // Masked Interrupt
#define TIMER_MIS_TATOMIS       0x00000001  // GPTM Timer A Time-Out Masked
                                            // Interrupt

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_ICR register.
//
//*****************************************************************************
#define TIMER_ICR_WUECINT       0x00010000  // 32/64-Bit GPTM Write Update
                                            // Error Interrupt Clear
#define TIMER_ICR_DMABINT       0x00002000  // GPTM Timer B DMA Done Interrupt
                                            // Clear
#define TIMER_ICR_TBMCINT       0x00000800  // GPTM Timer B Match Interrupt
                                            // Clear
#define TIMER_ICR_CBECINT       0x00000400  // GPTM Timer B Capture Mode Event
                                            // Interrupt Clear
#define TIMER_ICR_CBMCINT       0x00000200  // GPTM Timer B Capture Mode Match
                                            // Interrupt Clear
#define TIMER_ICR_TBTOCINT      0x00000100  // GPTM Timer B Time-Out Interrupt
                                            // Clear
#define TIMER_ICR_DMAAINT       0x00000020  // GPTM Timer A DMA Done Interrupt
                                            // Clear
#define TIMER_ICR_TAMCINT       0x00000010  // GPTM Timer A Match Interrupt
                                            // Clear
#define TIMER_ICR_RTCCINT       0x00000008  // GPTM RTC Interrupt Clear
#define TIMER_ICR_CAECINT       0x00000004  // GPTM Timer A Capture Mode Event
                                            // Interrupt Clear
#define TIMER_ICR_CAMCINT       0x00000002  // GPTM Timer A Capture Mode Match
                                            // Interrupt Clear
#define TIMER_ICR_TATOCINT      0x00000001  // GPTM Timer A Time-Out Raw
                                            // Interrupt

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TAILR register.
//
//*****************************************************************************
#define TIMER_TAILR_M           0xFFFFFFFF  // GPTM Timer A Interval Load
                                            // Register
#define TIMER_TAILR_S           0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TBILR register.
//
//*****************************************************************************
#define TIMER_TBILR_M           0xFFFFFFFF  // GPTM Timer B Interval Load
                                            // Register
#define TIMER_TBILR_S           0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TAMATCHR
// register.
//
//*****************************************************************************
#define TIMER_TAMATCHR_TAMR_M   0xFFFFFFFF  // GPTM Timer A Match Register
#define TIMER_TAMATCHR_TAMR_S   0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TBMATCHR
// register.
//
//*****************************************************************************
#define TIMER_TBMATCHR_TBMR_M   0xFFFFFFFF  // GPTM Timer B Match Register
#define TIMER_TBMATCHR_TBMR_S   0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TAPR register.
//
//*****************************************************************************
#define TIMER_TAPR_TAPSRH_M     0x0000FF00  // GPTM Timer A Prescale High Byte
#define TIMER_TAPR_TAPSR_M      0x000000FF  // GPTM Timer A Prescale
#define TIMER_TAPR_TAPSRH_S     8
#define TIMER_TAPR_TAPSR_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TBPR register.
//
//*****************************************************************************
#define TIMER_TBPR_TBPSRH_M     0x0000FF00  // GPTM Timer B Prescale High Byte
#define TIMER_TBPR_TBPSR_M      0x000000FF  // GPTM Timer B Prescale
#define TIMER_TBPR_TBPSRH_S     8
#define TIMER_TBPR_TBPSR_S      0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TAPMR register.
//
//*****************************************************************************
#define TIMER_TAPMR_TAPSMRH_M   0x0000FF00  // GPTM Timer A Prescale Match High
                                            // Byte
#define TIMER_TAPMR_TAPSMR_M    0x000000FF  // GPTM TimerA Prescale Match
#define TIMER_TAPMR_TAPSMRH_S   8
#define TIMER_TAPMR_TAPSMR_S    0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TBPMR register.
//
//*****************************************************************************
#define TIMER_TBPMR_TBPSMRH_M   0x0000FF00  // GPTM Timer B Prescale Match High
                                            // Byte
#define TIMER_TBPMR_TBPSMR_M    0x000000FF  // GPTM TimerB Prescale Match
#define TIMER_TBPMR_TBPSMRH_S   8
#define TIMER_TBPMR_TBPSMR_S    0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TAR register.
//
//*****************************************************************************
#define TIMER_TAR_M             0xFFFFFFFF  // GPTM Timer A Register
#define TIMER_TAR_S             0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TBR register.
//
//*****************************************************************************
#define TIMER_TBR_M             0xFFFFFFFF  // GPTM Timer B Register
#define TIMER_TBR_S             0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TAV register.
//
//*****************************************************************************
#define TIMER_TAV_M             0xFFFFFFFF  // GPTM Timer A Value
#define TIMER_TAV_S             0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TBV register.
//
//*****************************************************************************
#define TIMER_TBV_M             0xFFFFFFFF  // GPTM Timer B Value
#define TIMER_TBV_S             0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_RTCPD register.
//
//*****************************************************************************
#define TIMER_RTCPD_RTCPD_M     0x0000FFFF  // RTC Predivide Counter Value
#define TIMER_RTCPD_RTCPD_S     0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TAPS register.
//
//*****************************************************************************
#define TIMER_TAPS_PSS_M        0x0000FFFF  // GPTM Timer A Prescaler Snapshot
#define TIMER_TAPS_PSS_S        0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TBPS register.
//
//*****************************************************************************
#define TIMER_TBPS_PSS_M        0x0000FFFF  // GPTM Timer A Prescaler Value
#define TIMER_TBPS_PSS_S        0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TAPV register.
//
//*****************************************************************************
#define TIMER_TAPV_PSV_M        0x0000FFFF  // GPTM Timer A Prescaler Value
#define TIMER_TAPV_PSV_S        0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_TBPV register.
//
//*****************************************************************************
#define TIMER_TBPV_PSV_M        0x0000FFFF  // GPTM Timer B Prescaler Value
#define TIMER_TBPV_PSV_S        0

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_DMAEV register.
//
//*****************************************************************************
#define TIMER_DMAEV_TBMDMAEN    0x00000800  // GPTM Timer B Mode Match DMA
                                            // Trigger Enable
#define TIMER_DMAEV_CBEDMAEN    0x00000400  // GPTM Capture B Event DMA Trigger
                                            // Enable
#define TIMER_DMAEV_CBMDMAEN    0x00000200  // GPTM Capture B Match DMA Trigger
                                            // Enable
#define TIMER_DMAEV_TBTODMAEN   0x00000100  // GPTM Timer B Time-Out DMA
                                            // Trigger Enable
#define TIMER_DMAEV_TAMDMAEN    0x00000010  // GPTM Timer A Mode Match DMA
                                            // Trigger Enable
#define TIMER_DMAEV_RTCDMAEN    0x00000008  // GPTM RTC DMA Trigger Enable
#define TIMER_DMAEV_CAEDMAEN    0x00000004  // GPTM Capture A Event DMA Trigger
                                            // Enable
#define TIMER_DMAEV_CAMDMAEN    0x00000002  // GPTM Capture A Match DMA Trigger
                                            // Enable
#define TIMER_DMAEV_TATODMAEN   0x00000001  // GPTM Timer A Time-Out DMA
                                            // Trigger Enable

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_ADCEV register.
//
//*****************************************************************************
#define TIMER_ADCEV_TBMADCEN    0x00000800  // GPTM Timer B Mode Match ADC
                                            // Trigger Enable
#define TIMER_ADCEV_CBEADCEN    0x00000400  // GPTM Capture B Event ADC Trigger
                                            // Enable
#define TIMER_ADCEV_CBMADCEN    0x00000200  // GPTM Capture B Match ADC Trigger
                                            // Enable
#define TIMER_ADCEV_TBTOADCEN   0x00000100  // GPTM Timer B Time-Out ADC
                                            // Trigger Enable
#define TIMER_ADCEV_TAMADCEN    0x00000010  // GPTM Timer A Mode Match ADC
                                            // Trigger Enable
#define TIMER_ADCEV_RTCADCEN    0x00000008  // GPTM RTC ADC Trigger Enable
#define TIMER_ADCEV_CAEADCEN    0x00000004  // GPTM Capture A Event ADC Trigger
                                            // Enable
#define TIMER_ADCEV_CAMADCEN    0x00000002  // GPTM Capture A Match ADC Trigger
                                            // Enable
#define TIMER_ADCEV_TATOADCEN   0x00000001  // GPTM Timer A Time-Out ADC
                                            // Trigger Enable

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_PP register.
//
//*****************************************************************************
#define TIMER_PP_ALTCLK         0x00000040  // Alternate Clock Source
#define TIMER_PP_SYNCCNT        0x00000020  // Synchronize Start
#define TIMER_PP_CHAIN          0x00000010  // Chain with Other Timers
#define TIMER_PP_SIZE_M         0x0000000F  // Count Size
#define TIMER_PP_SIZE_16        0x00000000  // Timer A and Timer B counters are
                                            // 16 bits each with an 8-bit
                                            // prescale counter
#define TIMER_PP_SIZE_32        0x00000001  // Timer A and Timer B counters are
                                            // 32 bits each with a 16-bit
                                            // prescale counter

//*****************************************************************************
//
// The following are defines for the bit fields in the TIMER_O_CC register.
//
//*****************************************************************************
#define TIMER_CC_ALTCLK         0x00000001  // Alternate Clock Source

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
void HW_Init(void);

#endif /* HW_TM4C129_H */

/*************************** End of file ****************************/
